@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -47,7 +47,8 @@ namespace wb
     boost::signals2::scoped_connection _view_viewport_change_connection;
 
     void render_figure(mdc::CairoCtx *cr, const model_FigureRef &elem);
-    void render_layer(mdc::CairoCtx *cr, const model_LayerRef &layer, bool draw);
+    void render_layer(mdc::CairoCtx *cr, const model_LayerRef &layer);
+    void render_layer_figures(mdc::CairoCtx *cr, const model_LayerRef &layer);
     virtual void draw_contents(mdc::CairoCtx *cr);
 
     void viewport_changed();
