@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include "wb_component_physical.h"
 #include "model/wb_model_diagram_form.h"
 #include "relationship_canvas_floater.h"
@@ -27,13 +25,14 @@
 #include "grts/structs.db.mysql.h"
 #include "base/string_utilities.h"
 
+#include "workbench/wb_context.h"
+#include "grtpp_undo_manager.h"
+
 #include "wbcanvas/workbench_physical_diagram_impl.h"
 #include "wbcanvas/workbench_physical_tablefigure_impl.h"
 
 using namespace wb;
 using namespace base;
-using namespace MySQL::Geometry;
-using namespace MySQL::Drawing;
 
 WBComponentPhysical::RelationshipToolContext::RelationshipToolContext(WBComponentPhysical *owner, 
                                                                       ModelDiagramForm *form,
@@ -50,9 +49,11 @@ WBComponentPhysical::RelationshipToolContext::RelationshipToolContext(WBComponen
     view->add_floater(floater);
     
     scoped_connect(floater->signal_done_clicked(),boost::bind(&RelationshipToolContext::source_picking_done, this));
-    
+
     last_message= _("Select the Table to receive the Foreign Key or the Column(s) to turn into a Foreign Key.");
   }
+  else if (type == RelationshipnmId)
+    last_message= _("Select the first Table to be joined.");
   else
   {
     floater= 0;
@@ -104,8 +105,12 @@ bool WBComponentPhysical::RelationshipToolContext::pick_table(const workbench_ph
   itable= table;
   
   tfig->highlight();
-  
-  last_message= strfmt(_("'%s' selected. Please select the Referenced Table."), 
+
+  if (type == RelationshipnmId)
+    last_message= strfmt(_("'%s' selected. Please select the second Table."),
+                       table->table()->name().c_str());
+  else
+    last_message= strfmt(_("'%s' selected. Please select the Referenced Table."),
                     table->table()->name().c_str());
   
   return true;
@@ -150,9 +155,9 @@ bool WBComponentPhysical::RelationshipToolContext::add_column(const db_ColumnRef
   columns.push_back(column);
   
   std::string name= column->formattedType();
-  if (g_utf8_strlen(name.data(), name.size()) > 20)
+  if (g_utf8_strlen(name.data(), (gssize)name.size()) > 20)
   {
-    gchar *buf= (gchar*)g_malloc(name.size()+1);
+    gchar *buf = (gchar*)g_malloc((gssize)name.size() + 1);
     g_utf8_strncpy(buf, name.data(), 20);
     name = buf;
     g_free(buf);
@@ -296,8 +301,8 @@ bool WBComponentPhysical::RelationshipToolContext::finish()
 
 bool WBComponentPhysical::RelationshipToolContext::finish_for_columns()
 {
-  bool imany, fmany;
-  bool imand= true, fmand= true;
+  bool imany = false, fmany = false;
+  bool imand = true, fmand = true;
   //bool identifying= false;
   
   switch (type)
@@ -322,8 +327,7 @@ bool WBComponentPhysical::RelationshipToolContext::finish_for_columns()
   {
     grt::AutoUndo undo(owner->get_grt());
     
-    bool ok= owner->create_nm_relationship_grt(owner->get_grt(), view, itable, 
-                                               ftable, imand, fmand);
+    bool ok= owner->create_nm_relationship(view, itable, ftable, imand, fmand);
     
     if (ok)
     {
@@ -372,7 +376,7 @@ bool WBComponentPhysical::RelationshipToolContext::finish_for_columns()
 
 bool WBComponentPhysical::RelationshipToolContext::finish_for_tables()
 {
-  bool imany, fmany;
+  bool imany = false, fmany = false;
   bool imand= true, fmand= true;
   bool identifying= false;
   
@@ -397,8 +401,7 @@ bool WBComponentPhysical::RelationshipToolContext::finish_for_tables()
   if (imany && fmany)
   {
     grt::AutoUndo undo(owner->get_grt());
-    bool ok= owner->create_nm_relationship_grt(owner->get_grt(), view, itable, 
-                                               ftable, imand, fmand);
+    bool ok= owner->create_nm_relationship(view, itable, ftable, imand, fmand);
     
     if (ok)
     {
