@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,13 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include <boost/signals2/signal.hpp>
 #include <pcrecpp.h>
 
+#include "wb_sql_editor_form.h"
+#include "wb_sql_editor_panel.h"
 #include "query_side_palette.h"
+
 #include "wb_sql_editor_snippets.h"
 #include "wb_sql_editor_help.h"
 #include "grt/tree_model.h"
@@ -33,6 +34,7 @@
 #include "base/geometry.h"
 #include "base/notifications.h"
 #include "base/drawing.h"
+#include "base/log.h"
 
 #include "mforms/toolbar.h"
 #include "mforms/hypertext.h"
@@ -42,21 +44,24 @@
 #include "mforms/code_editor.h"
 
 
-#define USER_SNIPPETS "My Snippets"
+DEFAULT_LOG_DOMAIN("QuerySidebar");
 
 using namespace mforms;
 using namespace base;
 
-//----------------- SnippetList --------------------------------------------------------------------
+//----------------- SnippetListView --------------------------------------------------------------------
 
 /**
   * Internal class containing a list of snippet entries in a scrollable list.
   */
-class SnippetList : public BaseSnippetList
+class SnippetListView : public BaseSnippetList
 {
 private:
+  friend class QuerySidePalette;
+
   wb::SnippetPopover* _snippet_popover;
   bool _user_snippets_active;
+  bool _shared_snippets_active;
 
 private:
 
@@ -83,8 +88,8 @@ private:
   void prepare_context_menu()
   {
     _context_menu = manage(new Menu());
-    _context_menu->set_handler(boost::bind(&SnippetList::on_action, this, _1));
-    _context_menu->signal_will_show()->connect(boost::bind(&SnippetList::menu_will_show, this));
+    _context_menu->set_handler(boost::bind(&SnippetListView::on_action, this, _1));
+    _context_menu->signal_will_show()->connect(boost::bind(&SnippetListView::menu_will_show, this));
 
     _context_menu->add_item(_("Insert Snippet at Cursor"), "insert_text");
     _context_menu->add_item(_("Replace Editor Content with Snippet"), "replace_text");
@@ -103,13 +108,16 @@ private:
 
   void menu_will_show()
   {
+    bool shared_usable = model()->shared_snippets_usable();
+
     _context_menu->set_item_enabled(0, _selected_index > -1);
     _context_menu->set_item_enabled(1, _selected_index > -1);
     _context_menu->set_item_enabled(2, _selected_index > -1);
     _context_menu->set_item_enabled(4, _selected_index > -1);
-    _context_menu->set_item_enabled(6, _selected_index > -1);
-    _context_menu->set_item_enabled(8, _selected_index > -1);
-    _context_menu->set_item_enabled(10, !_user_snippets_active);
+    _context_menu->set_item_enabled(6, _selected_index > -1 && (!_shared_snippets_active || shared_usable));
+    _context_menu->set_item_enabled(7, (!_shared_snippets_active || shared_usable));
+    _context_menu->set_item_enabled(8, _selected_index > -1 && (!_shared_snippets_active || shared_usable));
+    _context_menu->set_item_enabled(10, !_user_snippets_active && !_shared_snippets_active);
   }
 
   //------------------------------------------------------------------------------------------------
@@ -132,30 +140,47 @@ private:
   //------------------------------------------------------------------------------------------------
 
 public:
-  SnippetList(const std::string& icon_name)
+  SnippetListView(const std::string& icon_name)
   : BaseSnippetList(icon_name, DbSqlEditorSnippets::get_instance())
   {
     _user_snippets_active = false;
+    _shared_snippets_active = false;
 
     _snippet_popover = new wb::SnippetPopover();
     _snippet_popover->set_size(376, 257);
-    _snippet_popover->signal_closed()->connect(boost::bind(&SnippetList::popover_closed, this));
+    _snippet_popover->signal_closed()->connect(boost::bind(&SnippetListView::popover_closed, this));
 
     prepare_context_menu();
   }
 
   //------------------------------------------------------------------------------------------------
 
-  ~SnippetList()
+  ~SnippetListView()
   {
     delete _snippet_popover;
     _context_menu->release();
   }
 
+
+  //------------------------------------------------------------------------------------------------
+
+  void edit_new_snippet()
+  {
+    if (!_snippets.empty())
+    {
+      _selected_index = (int)_snippets.size() - 1;
+      _selected_snippet = _snippets.back();
+      edit_snippet(_selected_snippet);
+      _snippet_popover->set_read_only(false);
+    }
+  }
+
   //------------------------------------------------------------------------------------------------
 
   std::string selected_category() { return model()->selected_category(); }
 
+  bool shared_snippets_active() const { return _shared_snippets_active; }
+
   //------------------------------------------------------------------------------------------------
 
   /**
@@ -164,7 +189,15 @@ public:
   void show_category(std::string category)
   {
     _user_snippets_active = (category == USER_SNIPPETS);
-    model()->select_category(category);
+    _shared_snippets_active = (category == SHARED_SNIPPETS);
+    try
+    {
+      model()->select_category(category);
+    }
+    catch (std::exception &exc)
+    {
+      log_warning("Error switching snippet category: %s\n", exc.what());
+    }
     refresh_snippets();
   }
 
@@ -174,13 +207,9 @@ public:
   {
     base::Rect bounds = snippet_bounds(snippet);
 
-    int left = (int) bounds.left();
-    int dummy = left;
-    int top = (int) bounds.top();
-    int bottom = (int) bounds.bottom();
-    client_to_screen(left, top);
-    client_to_screen(dummy, bottom);
-    top = (top + bottom) / 2; // Don't change this to top + height / 2, on OS X coordinates are flipped.
+    std::pair<int, int> left_top = client_to_screen((int) bounds.left(), (int) bounds.top());
+    std::pair<int, int> bottom = client_to_screen(0, (int) bounds.bottom());
+    left_top.second = (left_top.second + bottom.second) / 2;
 
     std::string title, description;
     get_snippet_info(snippet, title, description);
@@ -189,27 +218,28 @@ public:
     _snippet_popover->set_read_only(false);
     _snippet_popover->set_text(description);
     _snippet_popover->set_read_only(true);
-    _snippet_popover->show(left, top, mforms::Left);
+    _snippet_popover->show(left_top.first, left_top.second, mforms::StartLeft);
   }
 
   //------------------------------------------------------------------------------------------------
 
-  virtual void mouse_double_click(int button, int x, int y)
+  virtual bool mouse_double_click(mforms::MouseButton button, int x, int y)
   {
-    BaseSnippetList::mouse_double_click(button, x, y);
+    bool result = BaseSnippetList::mouse_double_click(button, x, y);
 
-    switch (button)
+    if (!result)
     {
-    case MouseButtonLeft:
+      if (button == MouseButtonLeft)
       {
         Snippet* snippet = snippet_from_point(x, y);
         if (snippet != NULL && snippet == _selected_snippet)
         {
           edit_snippet(snippet);
+          result = true;
         }
-        break;
       }
     }
+    return result;
   }
 
   //------------------------------------------------------------------------------------------------
@@ -221,7 +251,7 @@ public:
 
   //------------------------------------------------------------------------------------------------
 
-  // End of internal class SnippetList.
+  // End of internal class SnippetListView.
 };
 
 //----------------- QuerySidePalette ---------------------------------------------------------------
@@ -238,10 +268,12 @@ QuerySidePalette::QuerySidePalette(const SqlEditorForm::Ref &owner)
   _help_timer = NULL;
   _grtm = owner->grt_manager();
   _no_help = true;
-  _enable_help = true;
+  _automatic_help = _grtm->get_app_option_int("DbSqlEditor:DisableAutomaticContextHelp", 1) == 0;
   _switching_help = false;
+  _help_task = GrtThreadedTask::create(_grtm);
+  _help_task->desc("Context Help Task");
 
-  scoped_connect(signal_tab_changed(), boost::bind(&QuerySidePalette::tab_changed, this));
+  _pending_snippets_refresh = true;
 
   mforms::Box *help_page = manage(new Box(false));
   _help_toolbar = prepare_help_toolbar();
@@ -250,7 +282,7 @@ QuerySidePalette::QuerySidePalette(const SqlEditorForm::Ref &owner)
   // Separate box since we need a border around the content, but not the toolbar.
   Box* content_border = manage(new Box(false));
 
-  // No scoped_connect needed since _help_text is member variable.
+  // No scoped_connect needed since _help_text is a member variable.
   scoped_connect(_help_text->signal_link_click(), boost::bind(&QuerySidePalette::click_link, this, _1));
 
 #if _WIN32
@@ -262,7 +294,7 @@ QuerySidePalette::QuerySidePalette(const SqlEditorForm::Ref &owner)
 #endif
 
   _help_text->set_markup_text("");
-  _current_topic = -1;
+  _current_topic_index = -1;
 
   help_page->add(_help_toolbar, false, true);
   content_border->add(_help_text, true, true);
@@ -272,7 +304,7 @@ QuerySidePalette::QuerySidePalette(const SqlEditorForm::Ref &owner)
   Box* snippet_page = manage(new Box(false));
 
   content_border = manage(new Box(false));
-  _snippet_list = manage(new SnippetList("snippet_sql.png"));
+  _snippet_list = manage(new SnippetListView("snippet_sql.png"));
 #ifdef _WIN32
   content_border->set_padding(3, 3, 3, 3);
   _snippet_list->set_back_color(base::Color::get_application_color_as_string(AppColorPanelContentArea, false));
@@ -307,6 +339,7 @@ QuerySidePalette::QuerySidePalette(const SqlEditorForm::Ref &owner)
   }
 
   snippet_selection_changed();
+  show_help_hint_or_update();
 
   base::NotificationCenter::get()->add_observer(this, "GNTextSelectionChanged");
 }
@@ -318,9 +351,8 @@ QuerySidePalette::~QuerySidePalette()
   base::NotificationCenter::get()->remove_observer(this);
 
   cancel_timer();
-  _back_item->release();
-  _forward_item->release();
-  _quick_jump_item->release();
+  if (_help_task->is_busy() && _help_task->task())
+    _help_task->task()->cancel();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -333,132 +365,244 @@ void QuerySidePalette::cancel_timer()
 
 //--------------------------------------------------------------------------------------------------
 
-void QuerySidePalette::handle_notification(const std::string &name, void *sender, base::NotificationInfo &info)
+static bool contains_editor(SqlEditorForm::Ref form, MySQLEditor *ed)
 {
-  if (_enable_help)
+  for (int c = form->sql_editor_count(), i = 0; i < c; i++)
   {
-    if (name == "GNTextSelectionChanged") // Selection and caret changes.
-    {
-      mforms::Object *object = (mforms::Object*)sender;
-      mforms::CodeEditor *code_editor = dynamic_cast<mforms::CodeEditor*>(object);
-      if (code_editor == NULL)
-        return;
-
-      Sql_editor *editor = static_cast<Sql_editor*>(code_editor->get_host());
-      // XXX This event is sent for any code editor in the app, not only the ones in this editor.. so we need a better check here
-      if (editor && editor->grtobj().is_valid())
-      {
-        check_format_structures(editor);
-        cancel_timer();
-        _help_timer = _grtm->run_every(boost::bind(&QuerySidePalette::update_context_help, this, editor), 0.7);
-      }
-    }
+    SqlEditorPanel *panel = form->sql_editor_panel(i);
+    if (panel && panel->editor_be().get() == ed)
+      return true;
   }
-} 
-
-//--------------------------------------------------------------------------------------------------
-
-void QuerySidePalette::tab_changed()
-{
-  _enable_help = get_active_tab() == 0; // Only show help if the help page is actually active.
+  return false;
 }
 
 //--------------------------------------------------------------------------------------------------
 
-void QuerySidePalette::show_help_topic(std::string topic)
+void QuerySidePalette::handle_notification(const std::string &name, void *sender, base::NotificationInfo &info)
+{
+  // Selection and caret changes notification.
+  // Only act if this side palette is actually visible.
+  if ((name == "GNTextSelectionChanged") && _automatic_help && (get_active_tab() == 0) && is_fully_visible())
+  {
+    mforms::Object *object = (mforms::Object*)sender;
+    mforms::CodeEditor *code_editor = dynamic_cast<mforms::CodeEditor*>(object);
+    if (code_editor == NULL)
+      return;
+
+    MySQLEditor *editor = static_cast<MySQLEditor*>(code_editor->get_host());
+    if (editor != NULL && editor->grtobj().is_valid())
+    {
+      // See if this editor instance is actually from the IDE this palette sits in.
+      SqlEditorForm::Ref form = _owner.lock();
+      if (form && contains_editor(form, editor))
+      {
+        check_format_structures(editor);
+        cancel_timer();
+        _help_timer = _grtm->run_every(boost::bind(&QuerySidePalette::find_context_help, this, editor), 0.7);
+      }
+    }
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
+void QuerySidePalette::show_help_text_for_topic(const std::string &topic)
 {
   std::string title, text, html_text;
 
-  topic = base::toupper(topic);
-  if (!topic.empty())
+  if (topic.empty())
   {
-    if (_topic_cache.find(topic) != _topic_cache.end())
-    {
-      std::pair<std::string, std::string> entry = _topic_cache[topic];
-      html_text = entry.second;
-      _help_text->set_markup_text(html_text);
-      _no_help = false;
-    }
+    _last_topic = "";
+    update_help_ui();
+    return;
   }
 
-  if (html_text.empty() && !topic.empty())
+  std::string topic_upper = base::toupper(topic);
+  if (_topic_cache.find(topic_upper) != _topic_cache.end())
+  {
+    std::pair<std::string, std::string> entry = _topic_cache[topic_upper];
+    html_text = entry.second;
+    _help_text->set_markup_text(html_text);
+    _no_help = false;
+
+    return;
+  }
+
+  // Add a new task to retrieve the actual help text in the background, but only
+  // if the help task wasn't canceled, which indicates we are probably going down right now.
+  if (_help_task->task() && _help_task->task()->is_cancelled())
+    return;
+
+  _last_topic = topic_upper;
+  _help_task->exec(false, boost::bind(&QuerySidePalette::get_help_text_threaded, this, _1));
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Runs in the background to find the text for the last stored topic. Never called if there's no topic.
+ */
+grt::StringRef QuerySidePalette::get_help_text_threaded(grt::GRT *)
+{
+  SqlEditorForm::Ref form = _owner.lock();
+  if (!form)
+    return "";
+
+  std::string title, text, html_text;
+
+  if (DbSqlEditorContextHelp::get_help_text(form, _last_topic, title, text))
   {
-    SqlEditorForm::Ref form = _owner.lock();
-    if (DbSqlEditorContextHelp::get_help_text(form, topic, title, text))
-    {
 #ifdef _WIN32
-      std::string additional_space = "<div style=\"font-size:4pt\"> </div>";
+    std::string additional_space = "<div style=\"font-size:4pt\"> </div>";
 #else
-      std::string additional_space;
+    std::string additional_space;
 #endif
-      html_text = std::string("<html><body style=\"font-family:") + DEFAULT_FONT_FAMILY + "; font-size: 8pt\">"
-        "<b style=\"font-size: 11pt\">Topic: <span style=\"color:#688b5e\">" + title +
-        "</span></b><br>" + additional_space + format_help_as_html(text) + "</body></html>";
-      _help_text->set_markup_text(html_text);
-      _no_help = false;
-      _topic_cache[topic] = std::make_pair(text, html_text);
-    }
+    html_text = std::string("<html><body style=\"font-family:") + DEFAULT_FONT_FAMILY + "; font-size: 8pt\">"
+      "<b style=\"font-size: 11pt\">Topic: <span style=\"color:#688b5e\">" + title +
+      "</span></b><br>" + additional_space + format_help_as_html(text) + "</body></html>";
+    _no_help = false;
+    _topic_cache[_last_topic] = std::make_pair(text, html_text);
   }
-
-  if (html_text.empty())
+  else
   {
     _no_help = true;
+    _last_topic = "";
+  }
+
+  // At this point the previous task has already finished (it's the one that triggered this function).
+  _help_task->execute_in_main_thread(boost::bind(&QuerySidePalette::update_help_ui, this), false, false);
+
+  return "";
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Runs on the main thread for updating UI elements. Called by the help background task.
+ */
+void QuerySidePalette::update_help_ui()
+{
+  if (_last_topic.empty())
+  {
     _help_text->set_markup_text(
       std::string("<hmtl><body style=\"font-family:") + DEFAULT_FONT_FAMILY + "; font-size: 8pt\">"
       "<div style=\"width: 100%\"><b style=\"font-size: 10pt; color:#B0B0B0\">"
       "No Context Help<b><br><br><hr></div></body></html>");
   }
+  else
+  {
+    _help_text->set_markup_text(_topic_cache[_last_topic].second);
 
-  _switching_help = true;
-  _quick_jump_item->set_text(topic);
-  _switching_help = false;
+    _switching_help = true;
+    _quick_jump_item->set_text(_last_topic);
+    _switching_help = false;
+  }
 }
 
 //--------------------------------------------------------------------------------------------------
 
-bool QuerySidePalette::update_context_help(Sql_editor *editor)
+void QuerySidePalette::show_help_hint_or_update()
+{
+  if (!_automatic_help)
+  {
+    _help_text->set_markup_text(
+      std::string("<hmtl><body style=\"font-family:") + DEFAULT_FONT_FAMILY + "; font-size: 8pt\">"
+      "<div style=\"width: 100%\"><b style=\"font-size: 10pt; color:#B0B0B0\">"
+      "Automatic context help is disabled. Use the toolbar to manually get help for the current caret "
+      "position or to toggle automatic help.<b><br><br><hr></div></body></html>");
+  }
+  else
+  {
+    if (_current_topic_index > 0)
+      _last_topic = _topic_history[_current_topic_index]; // Restore the last displayed topic.
+    update_help_ui();
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
+/**
+ * Triggered by timer or manually to find a help topic from the given editor's text + position.
+ */
+bool QuerySidePalette::find_context_help(MySQLEditor *editor)
 {
   _help_timer = NULL;
 
-  std::string text, title;
+  if (_help_task->is_busy())
+    return false;
 
-   // Caret position as <column, row>.
-  std::pair<int, int> caret = editor->cursor_pos_row_column(true);
+  // If no editor was given use the currently active one in the SQL editor form.
+  if (editor == NULL)
+  {
+    SqlEditorForm::Ref form = _owner.lock();
+    SqlEditorPanel *panel = form->active_sql_editor_panel();
+    if (panel)
+      editor = panel->editor_be().get();
+    else
+      return false;
+  }
+
+  // Caret position as <column, row>.
+  std::pair<size_t, size_t> caret = editor->cursor_pos_row_column(true);
+
+  _help_task->exec(false, boost::bind(&QuerySidePalette::get_help_topic_threaded, this, _1, 
+    editor->current_statement(), caret));
 
-  SqlEditorForm::Ref form = _owner.lock();
-  std::string topic = DbSqlEditorContextHelp::find_help_topic_from_position(form,
-    editor->current_statement(), caret);
-  if (update_help_history(topic))
-    show_help_topic(topic);
-  
   return false; // Don't re-run this task, it's a single-shot.
 }
 
 //--------------------------------------------------------------------------------------------------
 
+/**
+ * Get a help topic from the current editor position. This might involve server access already
+ * to resolve ambiguities, hence it is a threaded task. Once we got the topic we run another task
+ * to get the actual help text from it.
+ */
+grt::StringRef QuerySidePalette::get_help_topic_threaded(grt::GRT *, const std::string &query,
+  std::pair<ssize_t, ssize_t> caret)
+{
+  SqlEditorForm::Ref form = _owner.lock();
+  if (!form)
+    return "";
+
+  std::string topic = DbSqlEditorContextHelp::find_help_topic_from_position(form, query, caret);
+
+  if (!_help_task->task()->is_cancelled())
+    _help_task->execute_in_main_thread(boost::bind(&QuerySidePalette::process_help_topic, this, topic), false, false);
+
+  return "";
+}
+
+//--------------------------------------------------------------------------------------------------
+
+void QuerySidePalette::process_help_topic(const std::string &topic)
+{
+  update_help_history(topic);
+  show_help_text_for_topic(topic);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 /**
  * Adds the given topic to the topic history if the current topic is not the same and updates
  * the forward/backward buttons.
- *
- * @returns True if the topic was added to the history, otherwise false.
  */
-bool QuerySidePalette::update_help_history(std::string topic)
+void QuerySidePalette::update_help_history(const std::string &topic)
 {
-  topic = base::toupper(topic);
-  if (_current_topic > 0 && _topic_history[_current_topic] == topic)
-    return _no_help;
+  std::string topic_upper = base::toupper(topic);
+  if (_current_topic_index > 0 && _topic_history[_current_topic_index] == topic_upper)
+    return;
 
   if (!topic.empty())
   {
-    _current_topic++;
+    _current_topic_index++;
 
     // Remove everything after the new topic position.
-    _topic_history.erase(_topic_history.begin() + _current_topic, _topic_history.end());
-    _topic_history.push_back(topic);
-    _back_item->set_enabled(_current_topic > 0);
+    _topic_history.erase(_topic_history.begin() + _current_topic_index, _topic_history.end());
+    _topic_history.push_back(topic_upper);
+    _back_item->set_enabled(_current_topic_index > 0);
     _forward_item->set_enabled(false);
   }
-  return true;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -472,8 +616,9 @@ void QuerySidePalette::click_link(const std::string &link)
     base::replace(topic, "%20", " ");
     while (topic.find("  ") != std::string::npos)
       base::replace(topic, "  ", " ");
-    if (update_help_history(topic))
-      show_help_topic(topic);
+    
+    update_help_history(topic);
+    show_help_text_for_topic(topic);
   }
   else
     mforms::Utilities::open_url(link);
@@ -483,35 +628,15 @@ void QuerySidePalette::click_link(const std::string &link)
 
 ToolBar* QuerySidePalette::prepare_snippet_toolbar()
 {
-  ToolBar* toolbar = manage(new ToolBar(mforms::PaletteToolBar));
+  ToolBar* toolbar = manage(new ToolBar(mforms::SecondaryToolBar));
   toolbar->set_name("snippet_toolbar");
 #ifndef __APPLE__
   toolbar->set_padding(0, 0, 0, 0);
   toolbar->set_size(-1, 27);
 #endif
-  ToolBarItem* item = manage(new ToolBarItem(mforms::ActionItem));
-  item->set_name("add_snippet");
-  item->set_icon(App::get()->get_resource_path("snippet_add.png"));
-  item->set_tooltip(_("Add the current editor content as new snippet"));
-  scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::snippet_toolbar_item_activated, this, _1));
-  toolbar->add_item(item);
-  item->release();
+  ToolBarItem* item;
 
-  /* not needed in toolbar
-  item = manage(new ToolBarItem(mforms::ActionItem));
-  item->set_name("del_snippet");
-  item->set_icon(App::get()->get_resource_path("snippet_del.png"));
-  item->set_tooltip(_("Delete the currently selected snippet"));
-  scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::snippet_toolbar_item_activated, this, _1));
-  toolbar->add_item(item);
-  item->release();
-   */
-
-  item = manage(new ToolBarItem(mforms::SeparatorItem));
-  toolbar->add_item(item);
-  item->release();
-
-  item = manage(new ToolBarItem(mforms::SelectorItem));
+  item = mforms::manage(new ToolBarItem(mforms::SelectorItem));
   item->set_name("select_category");
 
   DbSqlEditorSnippets* snippets_model = DbSqlEditorSnippets::get_instance();
@@ -520,28 +645,24 @@ ToolBar* QuerySidePalette::prepare_snippet_toolbar()
   item->set_text(USER_SNIPPETS);
   item->set_tooltip(_("Select a snippet category for display"));
   toolbar->add_item(item);
-  item->release();
 
-  item = manage(new ToolBarItem(mforms::SeparatorItem));
+  item = mforms::manage(new ToolBarItem(mforms::SeparatorItem));
   toolbar->add_item(item);
-  item->release();
 
 
-  item = manage(new ToolBarItem(mforms::ActionItem));
+  item = mforms::manage(new ToolBarItem(mforms::ActionItem));
   item->set_name("replace_text");
   item->set_icon(App::get()->get_resource_path("snippet_use.png"));
   item->set_tooltip(_("Replace the current text by this snippet"));
   scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::snippet_toolbar_item_activated, this, _1));
   toolbar->add_item(item);
-  item->release();
 
-  item = manage(new ToolBarItem(mforms::ActionItem));
+  item = mforms::manage(new ToolBarItem(mforms::ActionItem));
   item->set_name("insert_text");
   item->set_icon(App::get()->get_resource_path("snippet_insert.png"));
   item->set_tooltip(_("Insert the snippet text at the current caret position replacing selected text if there is any"));
   scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::snippet_toolbar_item_activated, this, _1));
   toolbar->add_item(item);
-  item->release();
 
   item = manage(new ToolBarItem(mforms::ActionItem));
   item->set_name("copy_to_clipboard");
@@ -549,7 +670,6 @@ ToolBar* QuerySidePalette::prepare_snippet_toolbar()
   item->set_tooltip(_("Copy the snippet text to the clipboard"));
   scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::snippet_toolbar_item_activated, this, _1));
   toolbar->add_item(item);
-  item->release();
 
   return toolbar;
 }
@@ -575,7 +695,6 @@ void QuerySidePalette::snippet_toolbar_item_activated(ToolBarItem* item)
   }
 }
 
-
 //--------------------------------------------------------------------------------------------------
 
 void QuerySidePalette::snippet_selection_changed()
@@ -603,7 +722,7 @@ void QuerySidePalette::close_popover()
 
 ToolBar* QuerySidePalette::prepare_help_toolbar()
 {
-  ToolBar* toolbar = manage(new ToolBar(mforms::PaletteToolBar));
+  ToolBar* toolbar = manage(new ToolBar(mforms::SecondaryToolBar));
   toolbar->set_name("help_toolbar");
 #ifndef __APPLE__
   toolbar->set_padding(0, 0, 0, 0);
@@ -626,9 +745,26 @@ ToolBar* QuerySidePalette::prepare_help_toolbar()
   scoped_connect(_forward_item->signal_activated(), boost::bind(&QuerySidePalette::help_toolbar_item_activated, this, _1));
   toolbar->add_item(_forward_item);
 
-  ToolBarItem* item = manage(new ToolBarItem(mforms::SeparatorItem));
+  toolbar->add_item(manage(new ToolBarItem(mforms::SeparatorItem)));
+
+  ToolBarItem *item = manage(new ToolBarItem(mforms::ToggleItem));
+  item->set_name("toggle-auto-context-help");
+  item->set_icon(App::get()->get_resource_path("wb-toolbar_automatic-help-off.png"));
+  item->set_alt_icon(App::get()->get_resource_path("wb-toolbar_automatic-help-on.png"));
+  item->set_tooltip(_("Toggle automatic context help"));
+  item->set_checked(_automatic_help);
+  scoped_connect(item->signal_activated(), boost::bind(&QuerySidePalette::help_toolbar_item_activated, this, _1));
   toolbar->add_item(item);
-  item->release();
+
+  _manual_help_item = manage(new ToolBarItem(mforms::ActionItem));
+  _manual_help_item->set_name("manual-context-help");
+  _manual_help_item->set_icon(App::get()->get_resource_path("wb-toolbar_manual-help.png"));
+  _manual_help_item->set_tooltip(_("Get context help for the item at the current caret position"));
+  _manual_help_item->set_enabled(!_automatic_help);
+  scoped_connect(_manual_help_item->signal_activated(), boost::bind(&QuerySidePalette::help_toolbar_item_activated, this, _1));
+  toolbar->add_item(_manual_help_item);
+
+  toolbar->add_item(manage(new ToolBarItem(mforms::SeparatorItem)));
 
   _quick_jump_item = manage(new ToolBarItem(mforms::SelectorItem));
   _quick_jump_item->set_name("quick_jump");
@@ -660,42 +796,56 @@ void QuerySidePalette::help_toolbar_item_activated(ToolBarItem* item)
     return;
 
   std::string action = item->get_name();
-  if (action == "back" && _current_topic > 0)
+  if (action == "back" && _current_topic_index > 0)
   {
-    std::string topic = _topic_history[--_current_topic];
-    _back_item->set_enabled(_current_topic > 0);
+    std::string topic = _topic_history[--_current_topic_index];
+    _back_item->set_enabled(_current_topic_index > 0);
     _forward_item->set_enabled(true);
-    show_help_topic(topic);
+    show_help_text_for_topic(topic);
     return;
   }
 
-  if (action == "forward" && _current_topic < (int)_topic_history.size() - 1)
+  if (action == "forward" && _current_topic_index < (int)_topic_history.size() - 1)
   {
-    std::string topic = _topic_history[++_current_topic];
+    std::string topic = _topic_history[++_current_topic_index];
     _back_item->set_enabled(true);
-    _forward_item->set_enabled(_current_topic < (int)_topic_history.size() - 1);
-    show_help_topic(topic);
+    _forward_item->set_enabled(_current_topic_index < (int)_topic_history.size() - 1);
+    show_help_text_for_topic(topic);
     return;
   }
 
   if (action == "quick_jump")
   {
     std::string topic = _quick_jump_item->get_text();
-    if (update_help_history(topic))
-      show_help_topic(topic);
+    update_help_history(topic);
+    show_help_text_for_topic(topic);
     return;
   }
 
-  if (_current_topic >= 0)
+  if (action == "toggle-auto-context-help")
+  {
+    _automatic_help = item->get_checked();
+    _manual_help_item->set_enabled(!_automatic_help);
+    _grtm->set_app_option("DbSqlEditor:DisableAutomaticContextHelp", grt::IntegerRef(_automatic_help ? 0 : 1));
+
+    show_help_hint_or_update();
+
+    return;
+  }
+
+  if (action == "manual-context-help")
+    find_context_help(NULL);
+
+  if (_current_topic_index >= 0)
   {
     if (action == "copy_to_clipboard")
     {
-      std::pair<std::string, std::string> entry = _topic_cache[_topic_history[_current_topic]];
+      std::pair<std::string, std::string> entry = _topic_cache[_topic_history[_current_topic_index]];
       mforms::Utilities::set_clipboard_text(entry.first);
     }
     if (action == "copy_html_to_clipboard")
     {
-      std::pair<std::string, std::string> entry = _topic_cache[_topic_history[_current_topic]];
+      std::pair<std::string, std::string> entry = _topic_cache[_topic_history[_current_topic_index]];
       mforms::Utilities::set_clipboard_text(entry.second);
     }
   }
@@ -710,7 +860,7 @@ bool compare_lengths(const std::pair<std::string, std::string> &l, const std::pa
 
 //--------------------------------------------------------------------------------------------------
 
-void QuerySidePalette::check_format_structures(Sql_editor *editor)
+void QuerySidePalette::check_format_structures(MySQLEditor *editor)
 {
   mforms::CodeEditorConfig *config = editor->get_editor_settings();
 
@@ -894,3 +1044,30 @@ std::string QuerySidePalette::format_help_as_html(const std::string &text)
 }
 
 //--------------------------------------------------------------------------------------------------
+
+void QuerySidePalette::refresh_snippets()
+{
+  if (_pending_snippets_refresh && _snippet_list->shared_snippets_active())
+  {
+    SqlEditorForm::Ref owner(_owner.lock());
+
+    try
+    {
+      _snippet_list->model()->load_from_db(owner.get());
+      _pending_snippets_refresh = false;
+    }
+    catch (std::exception &exc)
+    {
+      log_error("Error loading DB snippets: %s\n", exc.what());
+    }
+  }
+  _snippet_list->refresh_snippets();
+}
+
+
+//--------------------------------------------------------------------------------------------------
+
+void QuerySidePalette::edit_last_snippet()
+{
+  _snippet_list->edit_new_snippet();
+}
