@@ -38,7 +38,7 @@ namespace wb
     
   protected:
     void repaint(cairo_t *cr, int x, int y, int w, int h);
-    void mouse_up(int button, int x, int y);
+    bool mouse_up(mforms::MouseButton button, int x, int y);
 
     static void closed();
   public:
