@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,26 +17,25 @@
  * 02110-1301  USA
  */
 
-#ifndef _STDAFX_H_
-#define _STDAFX_H_
+#pragma once
+
+#define HAVE_ROUND
+#include <Python/Python.h>
 
-// Common headers.
 #include <stack>
 #include <pcre.h>
 #include <ctime>
 
-#ifdef _WIN32
-
-#define snprintf _snprintf
 #define NOMINMAX
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
-#include <float.h>
-#define INFINITY FLT_MAX
 
 #include <list>
 #include <vector>
+#include <hash_set>
 
+#include <stdio.h>
+#include <float.h>
 #include <string>
 #include <map>
 #include <set>
@@ -46,15 +45,17 @@
 #include <typeinfo>
 #include <fstream>
 #include <stdint.h>
-
-#include <boost/function.hpp>
-#include <boost/signals2.hpp>
-
-#include <stdio.h>
+#include <sstream>
 
 #define _USE_MATH_DEFINES
 #include <math.h>
 
+#include <boost/function.hpp>
+#include <boost/signals2.hpp>
+#include <boost/enable_shared_from_this.hpp>
+#include <boost/optional.hpp>
+#include <boost/cstdint.hpp>
+
 #include <cairo/cairo.h>
 #include <cairo/cairo-pdf.h>
 
@@ -62,8 +63,9 @@
 #include <gl/glu.h>
 
 #include <glib.h>
-#include <glib/gthread.h>
 
-#endif // _WIN32
-
-#endif // _STDAFX_H_
+#include "grts/structs.db.mgmt.h"
+#include "grts/structs.db.mysql.h"
+#include "grts/structs.model.h"
+#include "grts/structs.workbench.physical.h"
+#include "grts/structs.db.query.h"
