@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014 Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "tut_stdafx.h"
-
 #include "wb_helpers.h"
 #include "model/wb_history_tree.h"
 #include "grtdb/db_object_helpers.h"
@@ -78,7 +76,7 @@ TEST_FUNCTION(1)
   
   schema = tester.get_catalog()->schemata()[0];
 
-  _rdbms = db_mgmt_RdbmsRef::cast_from(tester.grt->unserialize("../../modules/db.mysql/res/mysql_rdbms_info.xml"));
+  _rdbms = db_mgmt_RdbmsRef::cast_from(tester.grt->unserialize("data/res/mysql_rdbms_info.xml"));
   
   // make sure the loaded model contains expected number of things
   ensure_equals("tables", schema->tables().count(), 2U);
@@ -93,7 +91,7 @@ TEST_FUNCTION(2) // General
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
   const std::string old_name = table->name();
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   
   // Rename
   be->set_name("new_name");
@@ -114,14 +112,14 @@ TEST_FUNCTION(2) // General
 TEST_FUNCTION(3) // Table (general)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   
   // Change Collation
   std::string old_value = be->get_table_option_by_name("CHARACTER SET - COLLATE");
   std::vector<std::string> collations(be->get_charset_collation_list());
   if ( collations.size() > 2 )
   {
-    int new_coll_idx = collations.size() / 2;
+    size_t new_coll_idx = collations.size() / 2;
     if ( collations[new_coll_idx] != old_value )
     {
       be->set_table_option_by_name("CHARACTER SET - COLLATE", collations[new_coll_idx]);
@@ -141,7 +139,7 @@ TEST_FUNCTION(3) // Table (general)
   std::vector<std::string> engines(be->get_engines_list());
   if ( engines.size() > 2 )
   {
-    int new_eng_idx = engines.size() / 2;
+    size_t new_eng_idx = engines.size() / 2;
     if ( engines[new_eng_idx] != old_value )
     {
       be->set_table_option_by_name("ENGINE", engines[new_eng_idx]);
@@ -161,7 +159,7 @@ TEST_FUNCTION(3) // Table (general)
 TEST_FUNCTION(4) // Table (add column)
 {   
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   // Add 
   const size_t existing_cols_nr = table->columns().count();
@@ -180,7 +178,7 @@ TEST_FUNCTION(4) // Table (add column)
 TEST_FUNCTION(5) // Table (rename column)
 {   
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   
   const std::string old_name = table->columns()[0]->name();
   // Rename 
@@ -196,7 +194,7 @@ TEST_FUNCTION(5) // Table (rename column)
 TEST_FUNCTION(6) // Table (Column type change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   bec::TableColumnsListBE* cols = be->get_columns();
 
@@ -227,7 +225,7 @@ TEST_FUNCTION(6) // Table (Column type change)
 TEST_FUNCTION(7) // Table (Column flag change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   bec::TableColumnsListBE* cols = be->get_columns();
 
@@ -245,18 +243,18 @@ TEST_FUNCTION(7) // Table (Column flag change)
 TEST_FUNCTION(8) // Table (column NN change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   bec::TableColumnsListBE* cols = be->get_columns();
 
   // Change NN, get original flag and revert it
-  int nn = -1;
+  ssize_t nn = -1;
   cols->get_field(bec::NodeId(0), MySQLTableColumnsListBE::IsNotNull, nn);
   cols->set_field(bec::NodeId(0), MySQLTableColumnsListBE::IsNotNull, !nn);
   check_only_one_undo_added();
   
   // get value and check that it was changed, they should match
-  int nn2 = -1;  
+  ssize_t nn2 = -1;  
   cols->get_field(bec::NodeId(0), MySQLTableColumnsListBE::IsNotNull, nn2);
   ensure("NN was not set", nn2 == !nn);
 
@@ -269,7 +267,7 @@ TEST_FUNCTION(8) // Table (column NN change)
 TEST_FUNCTION(9) // Table (column default change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   bec::TableColumnsListBE* cols = be->get_columns();
   
@@ -289,7 +287,7 @@ TEST_FUNCTION(9) // Table (column default change)
 TEST_FUNCTION(10) // Table (column remove)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t ncols = table->columns().count();
   ensure_equals("tables", ncols, 2U);
@@ -305,7 +303,7 @@ TEST_FUNCTION(10) // Table (column remove)
 TEST_FUNCTION(11) // Table (index add)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t nidx = table->indices().count();
   // Add
@@ -324,7 +322,7 @@ TEST_FUNCTION(11) // Table (index add)
 TEST_FUNCTION(12) // Table (index rename)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t nidx = table->indices().count();
   be->add_index("idx");
@@ -332,7 +330,7 @@ TEST_FUNCTION(12) // Table (index rename)
   
   // Rename
   MySQLTableIndexListBE* indices = be->get_indexes();
-  indices->set_field(bec::NodeId(nidx), bec::IndexListBE::Name, "idx_new");
+  indices->set_field(bec::NodeId((int)nidx), bec::IndexListBE::Name, "idx_new");
   check_only_one_undo_added();
   check_undo();
   ensure("Index rename undo failed", table->indices()[nidx]->name() == "idx");
@@ -344,14 +342,14 @@ TEST_FUNCTION(12) // Table (index rename)
 TEST_FUNCTION(13) // Table (index remove)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t nidx = table->indices().count();
   be->add_index("idx");
   check_only_one_undo_added();
 
   // Remove
-  be->remove_index(bec::NodeId(nidx));
+  be->remove_index(bec::NodeId((int)nidx), false);
   check_only_one_undo_added();
   check_undo();
   ensure("Index removal undo failed", table->indices().count() == nidx+1);
@@ -363,7 +361,7 @@ TEST_FUNCTION(13) // Table (index remove)
 TEST_FUNCTION(14) // Table (index type change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   // set engine to something that supports FULLTEXT and RTREE index options
   table->tableEngine("MyISAM");
@@ -374,9 +372,9 @@ TEST_FUNCTION(14) // Table (index type change)
   
   MySQLTableIndexListBE *indices = be->get_indexes();
   
-  indices->select_index(bec::NodeId(nidx));
+  indices->select_index(bec::NodeId((int)nidx));
 
-  indices->set_field(bec::NodeId(nidx), bec::IndexListBE::Type, "FULLTEXT");
+  indices->set_field(bec::NodeId((int)nidx), bec::IndexListBE::Type, "FULLTEXT");
   check_only_one_undo_added();
   check_undo();
   ensure("Index type change undo failed", table->indices()[nidx]->indexType() == "INDEX");
@@ -388,7 +386,7 @@ TEST_FUNCTION(14) // Table (index type change)
 TEST_FUNCTION(15) // Table (index storage change)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t nidx = table->indices().count();
   be->add_index("idx");
@@ -396,10 +394,10 @@ TEST_FUNCTION(15) // Table (index storage change)
   
   MySQLTableIndexListBE *indices = be->get_indexes();
   
-  indices->select_index(bec::NodeId(nidx));
+  indices->select_index(bec::NodeId((int)nidx));
 
   // Change Storage Type
-  indices->set_field(bec::NodeId(nidx), MySQLTableIndexListBE::StorageType, "RTREE");
+  indices->set_field(bec::NodeId((int)nidx), MySQLTableIndexListBE::StorageType, "RTREE");
   check_only_one_undo_added();
   check_undo();
   ensure("Index storage type change undo failed", table->indices()[nidx]->indexKind() == "");
@@ -411,20 +409,20 @@ TEST_FUNCTION(15) // Table (index storage change)
 TEST_FUNCTION(16) // Table (index column add)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
 
   const size_t nidx = table->indices().count();
   be->add_index("idx");
   check_only_one_undo_added();
   
   MySQLTableIndexListBE *indices = be->get_indexes();
-  indices->select_index(bec::NodeId(nidx));
+  indices->select_index(bec::NodeId((int)nidx));
 
   bec::IndexColumnsListBE *icols = indices->get_columns();
   icols->set_column_enabled(bec::NodeId(icols->count() - 1), true);
   check_only_one_undo_added();
   check_undo();
-  ensure("Undo adding column to index failed", 0 == icols->get_column_enabled(bec::NodeId(bec::NodeId(table->columns().count() - 1))));
+  ensure("Undo adding column to index failed", 0 == icols->get_column_enabled(bec::NodeId(bec::NodeId((int)table->columns().count() - 1))));
   check_redo();
   check_undo();
 
@@ -440,7 +438,7 @@ TEST_FUNCTION(16) // Table (index column add)
 TEST_FUNCTION(17) // Table (fk add)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   const size_t nfks = table->foreignKeys().count();
 
   be->add_fk("fk1");
@@ -456,13 +454,13 @@ TEST_FUNCTION(17) // Table (fk add)
 TEST_FUNCTION(18) // Table (fk remove)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   const size_t nfks = table->foreignKeys().count();
 
   be->add_fk("fk1");
   check_only_one_undo_added();
   ensure_equals("FK was added", nfks+1, table->foreignKeys().count());
-  be->remove_fk(bec::NodeId(nfks));
+  be->remove_fk(bec::NodeId((int)nfks));
   check_only_one_undo_added();
   ensure_equals("FK was removed", nfks, table->foreignKeys().count());
   check_undo();  
@@ -475,14 +473,14 @@ TEST_FUNCTION(18) // Table (fk remove)
 TEST_FUNCTION(19) // Table (fk rename)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   const size_t              nfks = table->foreignKeys().count();
   bec::FKConstraintListBE*  fks  = be->get_fks();
 
   be->add_fk("fk1");
   check_only_one_undo_added();
   
-  fks->set_field(bec::NodeId(nfks), bec::FKConstraintListBE::Name, "fk_new");
+  fks->set_field(bec::NodeId((int)nfks), bec::FKConstraintListBE::Name, "fk_new");
   check_only_one_undo_added();
   check_undo();
   ensure("Index rename undo failed", table->foreignKeys()[nfks]->name() == "fk1");
@@ -497,15 +495,15 @@ TEST_FUNCTION(19) // Table (fk rename)
 TEST_FUNCTION(20) // Table (fk set ref table)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   const size_t              nfks = table->foreignKeys().count();
   bec::FKConstraintListBE*  fks  = be->get_fks();
 
   be->add_fk("fk1");
   check_only_one_undo_added();
-  fks->select_fk(bec::NodeId(nfks));
+  fks->select_fk(bec::NodeId((int)nfks));
   
-  fks->set_field(bec::NodeId(nfks), bec::FKConstraintListBE::RefTable, "table2");
+  fks->set_field(bec::NodeId((int)nfks), bec::FKConstraintListBE::RefTable, "table2");
   check_only_one_undo_added();
   ensure("FK ref table was not set",  fks->get_selected_fk()->referencedTable()->name() == "table2");
   check_undo();
@@ -518,15 +516,15 @@ TEST_FUNCTION(21) // Table (fk set ref column)
 {
   db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
   db_mysql_TableRef table2(db_mysql_TableRef::cast_from(schema->tables()[1]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
+  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table));
   const size_t              nfks = table->foreignKeys().count();
   bec::FKConstraintListBE*  fks  = be->get_fks();
 
   be->add_fk("fk1");
   check_only_one_undo_added();
-  fks->select_fk(bec::NodeId(nfks));
+  fks->select_fk(bec::NodeId((int)nfks));
   
-  fks->set_field(bec::NodeId(nfks), bec::FKConstraintListBE::RefTable, "table2");
+  fks->set_field(bec::NodeId((int)nfks), bec::FKConstraintListBE::RefTable, "table2");
   check_only_one_undo_added();
   ensure("FK ref table was not set",  fks->get_selected_fk()->referencedTable()->name() == "table2");
 
@@ -549,21 +547,6 @@ TEST_FUNCTION(21) // Table (fk set ref column)
 }
 
 //------------------------------------------------------------------------------
-TEST_FUNCTION(22) // Table (Triggers)
-{
-  db_mysql_TableRef table(db_mysql_TableRef::cast_from(schema->tables()[0]));
-  std::auto_ptr<MySQLTableEditorBE> be(new MySQLTableEditorBE(tester.wb->get_grt_manager(), table, _rdbms));
-
-  const std::string trig_sql = be->get_all_triggers_sql();
-  be->set_triggers_sql("create trigger tr1 before insert on table1 for each row set new.idtable1 = 1", true);
-  check_only_one_undo_added();
-  std::string expected = "-- Full Trigger DDL Statements\n-- Note: Only CREATE TRIGGER statements are allowed\n"
-    "DELIMITER $$\n\nUSE `mydb`$$\n\ncreate trigger tr1 before insert on table1 for each row set new.idtable1 = 1$$\n\n";
-
-  ensure_equals("Triggers sql set", be->get_all_triggers_sql(), expected);
-  check_undo();
-  ensure_equals("Triggers sql undo", be->get_all_triggers_sql(), trig_sql);
-}
 
 /*
 
