@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,7 @@
  * 02110-1301  USA
  */
 
-#ifndef _WB_CONTEXT_H_
-#define _WB_CONTEXT_H_
+#pragma once
 
 #ifndef _WIN32
 #include <vector>
@@ -37,12 +36,16 @@
 
 #include "mforms/utilities.h"
 #include "base/trackable.h"
+#include "base/threading.h"
 
 
 #include "wb_version.h"
 
 #define WBContext_VERSION 5
 
+#define WB_DBOBJECT_DRAG_TYPE "mysql-wb.DatabaseObject"
+#define WB_CONTROL_DRAG_TYPE "mysql-wb.control"
+
 namespace mdc {
   class CanvasView;
   class CanvasItem;
@@ -70,7 +73,6 @@ namespace wb {
   {
     RefreshNeeded, // Front end should schedule a refresh flush asap (usually called in worker thread).
     RefreshNothing,
-    RefreshSchemaList,
     RefreshSchemaNoReload,
     RefreshNewDiagram,
     RefreshSelection,
@@ -86,7 +88,7 @@ namespace wb {
     RefreshZoom,
     RefreshTimer,
 
-    RefreshFinishEdits // Force all ongoing edit operations (eg in TreeView cells) to be commited
+    RefreshFinishEdits // Force all ongoing edit operations (eg in TreeView cells) to be committed
   };
 
   struct MYSQLWBBACKEND_PUBLIC_FUNC WBPaperSize
@@ -134,9 +136,6 @@ namespace wb {
     // Show some text in the application's status bar: must be thread-safe
     boost::function<void (std::string)> show_status_text;
 
-    // ok/cancel, title, flags, returnval
-    boost::function<bool (std::string, int, std::string&)> request_input;
-
     // Open an editor
     // Args: grtmanager, module containing plugin, editor dll, editor class, edited object
     boost::function<NativeHandle (bec::GRTManager*, grt::Module*, std::string, std::string, grt::BaseListRef, bec::GUIPluginFlags)> open_editor;
@@ -192,6 +191,7 @@ namespace wb {
     bool quit_when_done;
     bool testing;     // True if we are currently running unit tests.
     bool init_python; // True by default. Can be switched off for testing.
+    bool full_init; // True by default. Should be switched off when the options are created for an already running instance of WB.
 
     WBOptions();
     bool parse_args(char **argv, int argc, int *retval = NULL);
@@ -249,7 +249,8 @@ namespace wb {
     void update_plugin_arguments_pool(bec::ArgumentPool &args);
 
     // DB Querying
-    boost::shared_ptr<SqlEditorForm> add_new_query_window(const db_mgmt_ConnectionRef &target);
+    boost::shared_ptr<SqlEditorForm> add_new_query_window(const db_mgmt_ConnectionRef &target, bool restore_session = true);
+    boost::shared_ptr<SqlEditorForm> add_new_query_window();
     
     // Admin
     void add_new_admin_window(const db_mgmt_ConnectionRef &target);
@@ -377,9 +378,25 @@ namespace wb {
       double timestamp;
     };
 
-    std::list<RefreshRequest> _pending_refreshes;
-    GMutex *_pending_refresh_mutex;
+    // Predicate for pending refresh removal on close.
+    struct CancelRefreshCandidate
+    {
+      bool operator() (RefreshRequest request)
+      {
+        return (request.type == RefreshNewModel ||
+          request.type == RefreshNewDiagram ||
+          request.type == RefreshOverviewNodeChildren ||
+          request.type == RefreshZoom ||
+          request.type == RefreshDocument ||
+          request.type == RefreshOverviewNodeInfo);
+      }
+    };
 
+    std::list<RefreshRequest> _pending_refreshes;
+    base::Mutex _pending_refresh_mutex;
+
+    base::RecMutex _block_user_interaction_mutex;
+    
     WBContextUI *_uicontext;
     WBContextModel *_model_context;
     WBContextSQLIDE *_sqlide_context;
@@ -404,6 +421,7 @@ namespace wb {
 
     grt::ListRef<app_PaperType> get_paper_types(grt::GRT *grt, boost::shared_ptr<grt::internal::Unserializer> unserializer);
 
+    bool _other_connections_loaded;
     // setup
     void init_grt_tree(grt::GRT *grt, WBOptions *options, boost::shared_ptr<grt::internal::Unserializer> unserializer);
     void run_init_scripts_grt(grt::GRT *grt, WBOptions *options);
@@ -465,9 +483,12 @@ namespace wb {
   private:
     bool find_connection_password(const db_mgmt_ConnectionRef &conn, std::string &password);
 
-    void *do_request_password(const std::string &title, const std::string &service, std::string &account, bool reset_password, std::string *ret_password);
+    void *do_request_password(const std::string &title, const std::string &service, bool reset_password,
+      std::string *account, std::string *ret_password);
     void *do_find_connection_password(const std::string &hostId, const std::string &username, std::string *ret_password);
 
+    void load_other_connections();
+
     void attempt_options_upgrade(xmlDocPtr xmldoc, const std::string &version);
 
     bool show_error(const std::string& title, const std::string& message);
@@ -477,11 +498,7 @@ namespace wb {
 
   public: // front end callbacks
     boost::function<std::string (std::string,std::string,std::string)> show_file_dialog;
-
     boost::function<void (std::string)> show_status_text;
-
-    boost::function<bool (std::string,int,std::string&)> request_input;
-
     boost::function<void (std::string,void*)> show_gui_plugin;
 
     boost::function<mdc::CanvasView* (const model_DiagramRef&)> create_diagram;
@@ -519,6 +536,3 @@ namespace wb {
   };
   
 };
-
-
-#endif /* _WB_CONTEXT_H_ */
