@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -298,9 +298,9 @@ void WBContextUI::show_home_screen()
 
   _initializing_home_screen = (_home_screen == NULL);
   if (_home_screen == NULL)
-  {    
+  {
+    // The home screen and its content is freed in AppView::close() during undock_view(...).
     _home_screen = mforms::manage(new HomeScreen(_command_ui, _wb->get_root()->rdbmsMgmt()));
-    _home_screen->set_on_close(boost::bind(&WBContextUI::home_screen_closing, this));
     _home_screen->set_callback((home_screen_action_callback)&WBContextUI::home_action_callback, this);
     _home_screen->handle_context_menu = boost::bind(&WBContextUI::handle_home_context_menu, this, _1, _2);
 
@@ -466,14 +466,6 @@ void WBContextUI::show_home_screen()
 
 //--------------------------------------------------------------------------------------------------
 
-bool WBContextUI::home_screen_closing()
-{  
-  _home_screen = NULL;
-  return true;
-}
-
-//--------------------------------------------------------------------------------------------------
-
 void WBContextUI::home_action_callback(HomeScreenAction action, const grt::ValueRef &object, WBContextUI *self)
 {
   try
@@ -598,7 +590,7 @@ void WBContextUI::handle_home_context_menu(const grt::ValueRef &object, const st
   }
   else if (action == "delete_connection_group" || action == "internal_delete_connection_group")
   {
-    std::string group = object.repr();
+    std::string group = object.toString();
     int answer = mforms::ResultOk;
     
 
