@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -95,7 +95,7 @@ std::string WorkbenchImpl::getSystemInfo(bool indent)
       #endif
   #elif defined(__APPLE__)
     #define PLATFORM_NAME "Mac OS X"
-    #define ARCHITECTURE "32 bit"
+    #define ARCHITECTURE "64 bit"
   #else
     #define PLATFORM_NAME "Linux/Unix"
     #define ARCHITECTURE "64 bit"
@@ -105,9 +105,9 @@ std::string WorkbenchImpl::getSystemInfo(bool indent)
   app_InfoRef info(app_InfoRef::cast_from(_wb->get_grt()->get("/wb/info")));
 
   const char* tab = indent ? "\t" : "";
-  std::string result = strfmt("%s%s %s (%s) for " PLATFORM_NAME " version %i.%i.%i %s revision %i build %i (%s)\n",
+  std::string result = strfmt("%s%s %s (%s) for " PLATFORM_NAME " version %i.%i.%i %s build %i (%s)\n",
     tab, info->name().c_str(), APP_EDITION_NAME, APP_LICENSE_TYPE, APP_MAJOR_NUMBER, APP_MINOR_NUMBER, APP_RELEASE_NUMBER,
-                              APP_RELEASE_TYPE, APP_REVISION_NUMBER, APP_BUILD_NUMBER, ARCHITECTURE);
+                              APP_RELEASE_TYPE, APP_BUILD_NUMBER, ARCHITECTURE);
   result += strfmt("%sConfiguration Directory: %s\n", tab, _wb->get_grt_manager()->get_user_datadir().c_str());
   result += strfmt("%sData Directory: %s\n", tab, _wb->get_grt_manager()->get_basedir().c_str());
 
@@ -1337,23 +1337,6 @@ int WorkbenchImpl::refreshHomeConnections()
 
 //--------------------------------------------------------------------------------------------------
 
-std::string WorkbenchImpl::request_input_m(const std::string &caption)
-{
-  std::string result;
-
-  if (_wb->request_input(caption, 0, result))
-    return result;
-  return "";
-}
-
-
-std::string WorkbenchImpl::input(const std::string &caption)
-{
-  return _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<std::string>(
-    boost::bind(&WorkbenchImpl::request_input_m, this, caption), true, false);
-}
-
-
 int WorkbenchImpl::confirm(const std::string &title, const std::string &caption)
 {
   return _wb->get_grt_manager()->get_dispatcher()->call_from_main_thread<int>(
@@ -1364,14 +1347,14 @@ int WorkbenchImpl::confirm(const std::string &title, const std::string &caption)
 std::string WorkbenchImpl::requestFileOpen(const std::string &caption, const std::string &extensions)
 {
   return _wb->get_grt_manager()->get_dispatcher()->
-  call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "open", caption, extensions), true, false);
+    call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "open", caption, extensions), true, false);
 }
 
 
 std::string WorkbenchImpl::requestFileSave(const std::string &caption, const std::string &extensions)
 {
   return _wb->get_grt_manager()->get_dispatcher()->
-  call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "save", caption, extensions), true, false);
+    call_from_main_thread<std::string>(boost::bind(_wb->show_file_dialog, "save", caption, extensions), true, false);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -1857,7 +1840,12 @@ grt::DictListRef WorkbenchImpl::getLocalServerList()
     char *ster = NULL;
     int rc=0;
     GError *err = NULL;
-    if (g_spawn_command_line_sync("/bin/sh -c \"ps -ec | grep \\\"mysqld\\b\\\" | awk '{ print $1 }' | xargs -r ps -ww -o args= -p \"", &stdo, &ster, &rc, &err) && stdo)
+#ifdef __APPLE__
+    std::string cmd = "/bin/sh -c \"ps -ec | grep \\\"mysqld\\b\\\" | awk '{ print $1 }' | xargs ps -ww -o args= -p \"";
+#else
+    std::string cmd = "/bin/sh -c \"ps -ec | grep \\\"mysqld\\b\\\" | awk '{ print $1 }' | xargs -r ps -ww -o args= -p \"";
+#endif
+    if (g_spawn_command_line_sync(cmd.c_str(), &stdo, &ster, &rc, &err) && stdo)
     {
       std::string processes(stdo);
       
