@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include <iostream>
 #include <sstream>
 
@@ -185,7 +183,7 @@ WmiMonitor::WmiMonitor(IWbemServices* services, const std::string& parameter)
   hr = _refresher->QueryInterface(IID_IWbemConfigureRefresher, (void**) &config);
   if (FAILED(hr))
   {
-    log_error("QueryInterface for wbem configure refersher failed with error: %d\n", hr);
+    log_error("QueryInterface for wbem configure refresher failed with error: %d\n", hr);
 
     // _refersher is a smart pointer and is automatically freed.
     throw std::runtime_error(_("WMI - Could not create monitor object.\n\n") + wmiResultToString(hr));
@@ -332,7 +330,7 @@ std::string WmiMonitor::readValue()
 
 //----------------- WmiServices --------------------------------------------------------------------
 
-static GStaticMutex _locator_mutex = G_STATIC_MUTEX_INIT;
+static base::Mutex _locator_mutex;
 static IWbemLocator* _locator = NULL;
 static int _locator_refcount = 0;
 
@@ -419,7 +417,7 @@ void WmiServices::allocate_locator()
 {
   log_debug("Allocating wbem locator\n");
 
-  base::GStaticMutexLock lock(_locator_mutex);
+  base::MutexLock lock(_locator_mutex);
   if (_locator_refcount == 0)
   {
     HRESULT hr = CoCreateInstance(CLSID_WbemLocator, NULL, CLSCTX_INPROC_SERVER, IID_IWbemLocator,
@@ -442,7 +440,7 @@ void WmiServices::deallocate_locator()
 {
   log_debug("Deallocating wbem locator\n");
 
-  base::GStaticMutexLock lock(_locator_mutex);
+  base::MutexLock lock(_locator_mutex);
   if (_locator_refcount > 0)
   {
     _locator_refcount--;
@@ -474,7 +472,7 @@ grt::DictListRef WmiServices::query(grt::GRT* grt, const std::string& query)
   // Making this function explicitly thread-safe might be unnecessary as we don't have
   // any data which is allocated/deallocated concurrently. But since we know we will be called
   // from different threads we play safe here, as it does not harm either.
-  base::GStaticMutexLock lock(_locator_mutex);
+  base::MutexLock lock(_locator_mutex);
 
   grt::DictListRef queryResult(grt);
 
@@ -570,7 +568,7 @@ std::string WmiServices::serviceControl(const std::string& service, const std::s
 {
   log_debug3("Running wmi service control query for service: %s (action: %s)\n", service.c_str(), action.c_str());
 
-  base::GStaticMutexLock lock(_locator_mutex);
+  base::MutexLock lock(_locator_mutex);
 
   CComBSTR instancePath = string2Bstr("Win32_Service.Name='" + service + "'");
 
@@ -770,7 +768,7 @@ std::string WmiServices::systemStat(const std::string& what)
 {
   log_debug3("Running wmi system stat call (what: %s)\n", what.c_str());
 
-  base::GStaticMutexLock lock(_locator_mutex);
+  base::MutexLock lock(_locator_mutex);
 
   CComBSTR instancePath = string2Bstr("Win32_OperatingSystem");
 
