@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014 Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,8 @@
  * 02110-1301  USA
  */
 
-#include "tut_stdafx.h"
-
-// tests ValueInspectorBE
-
 #include "grt/grt_value_inspector.h"
-#include "grtpp_value.h"
+#include "wb_helpers.h"
 
 using namespace grt;
 using namespace bec;
@@ -61,14 +57,16 @@ TEST_FUNCTION(1)
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, list, false, false);
 
   // test listing
-  int c= vinsp->count();
-  ensure_equals("begin listing", c, 10);
+  size_t c = vinsp->count();
+  ensure_equals("begin listing", c, 10U);
 
   std::string name, value;
   Type type;
   NodeId node;
   
-  std::vector<int> columns;
+  g_mkdir_with_parents("output", 0700);
+  
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
   dump_tree_model("output/grt_inspector_value_test1.txt", vinsp, columns, true);
@@ -97,6 +95,9 @@ TEST_FUNCTION(1)
   ensure_equals("7) value", value, "{item1 = 1, item2 = 2.2, item3 = test}");
   ensure_equals("7) type", type, DictType);
 
+  NodeId nd;
+  ensure("bad get", !nd.is_valid());
+
   node= vinsp->get_node(-1);
   ensure("bad get", !node.is_valid());
 
@@ -104,7 +105,7 @@ TEST_FUNCTION(1)
   ensure("bad get", !node.is_valid());
 
   // test change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag= vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set 1", flag);
 
   flag= vinsp->get_field(0, ValueInspectorBE::Value, value);
@@ -113,7 +114,7 @@ TEST_FUNCTION(1)
   type= vinsp->get_field_type(0, ValueInspectorBE::Value);
   ensure_equals("get/set 1", type, IntegerType);
 
-  flag= vinsp->set_field(9, ValueInspectorBE::Value, 8888);
+  flag = vinsp->set_field(9, ValueInspectorBE::Value, (ssize_t)8888);
   ensure("set 9", flag);
 
   // test change string value
@@ -145,17 +146,17 @@ TEST_FUNCTION(1)
   NodeId nkey;
   flag= vinsp->add_item(nkey);
   ensure("add ok", flag);
-  ensure_equals("add", nkey[0], 10);
+  ensure_equals("add", nkey[0], 10U);
   flag= vinsp->set_field(nkey, ValueInspectorBE::Value, "new value");
   ensure("set item", flag);
 
-  ensure_equals("new count", (int)list.count(), 11);
+  ensure_equals("new count", list.count(), 11U);
 
   // test delete value
   flag= vinsp->delete_item(3);
   ensure("del", flag);
   
-  ensure_equals("count", (int)list.count(), 10);
+  ensure_equals("count", list.count(), 10U);
 
   dump_tree_model("output/grt_inspector_value_test1.2.txt", vinsp, columns, true);
   ensure_files_equal("list delete", "output/grt_inspector_value_test1.2.txt", "data/be/grt_inspector_value_test1.2.txt");
@@ -170,7 +171,7 @@ TEST_FUNCTION(1)
 TEST_FUNCTION(2)
 {
   bool flag;
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
 
@@ -179,15 +180,15 @@ TEST_FUNCTION(2)
   // create a test list
   BaseListRef list(create_string_list(&grt, 10));
 
-  ensure_equals("initial list size", (int)list.count(), 10);
+  ensure_equals("initial list size", list.count(), 10U);
   ensure_equals("list type", list.type(), ListType);
   ensure_equals("list content type", list.content_type(), StringType);
 
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, list, false, false);
 
   // test listing
-  int c= vinsp->count();
-  ensure_equals("begin listing", c, 10);
+  size_t c = vinsp->count();
+  ensure_equals("begin listing", c, 10U);
 
   dump_tree_model("output/grt_inspector_value_test2.txt", vinsp, columns, true);
   ensure_files_equal("typed list check", "output/grt_inspector_value_test2.txt", "data/be/grt_inspector_value_test2.txt");
@@ -205,7 +206,7 @@ TEST_FUNCTION(2)
   ensure("bad get", !flag);
 
   // test change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set 1", !flag);
 
   // test change string value
@@ -236,7 +237,7 @@ TEST_FUNCTION(2)
 TEST_FUNCTION(3)
 {
   bool flag;
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
   
@@ -245,15 +246,15 @@ TEST_FUNCTION(3)
   // create a test list
   BaseListRef list(create_int_list(&grt, 10));
 
-  ensure_equals("initial list size", (int)list.count(), 10);
+  ensure_equals("initial list size", list.count(), 10U);
   ensure_equals("list type", list.type(), ListType);
   ensure_equals("list content type", list.content_type(), IntegerType);
 
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, list, false, false);
 
   // test listing
-  int c= vinsp->count();
-  ensure_equals("begin listing", c, 10);
+  size_t c = vinsp->count();
+  ensure_equals("begin listing", c, 10U);
 
   std::string name, value;
 
@@ -276,11 +277,11 @@ TEST_FUNCTION(3)
   //node= vinsp->get_child(1, 1);
   //ensure("bad get", !node.is_valid());
 
-  flag= vinsp->set_field(0, ValueInspectorBE::Name, 123);
+  flag = vinsp->set_field(0, ValueInspectorBE::Name, (ssize_t)123);
   ensure("bad set", !flag);
 
   // test change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set 1", flag);
 
   // test change string value
@@ -310,7 +311,7 @@ TEST_FUNCTION(3)
 TEST_FUNCTION(10)
 {
   bool flag;
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
   
@@ -319,14 +320,14 @@ TEST_FUNCTION(10)
   // create a test dict
   DictRef dict(create_dict_with_varied_data(&grt));
 
-  ensure_equals("initial dict size", (int)dict.count(), 6);
+  ensure_equals("initial dict size", dict.count(), 6U);
   ensure_equals("dict type", dict.type(), DictType);
 
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, dict, false, false);
 
   // test listing
-  int c= vinsp->count();
-  ensure_equals("begin listing", c, 6);
+  size_t c = vinsp->count();
+  ensure_equals("begin listing", c, 6U);
 
   std::string name, value;
 
@@ -341,11 +342,11 @@ TEST_FUNCTION(10)
 //  ensure("bad get", !node.is_valid());
 
   // test change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set 1", flag);
 
 
-  flag= vinsp->set_field(4, ValueInspectorBE::Value, 8888);
+  flag = vinsp->set_field(4, ValueInspectorBE::Value, (ssize_t)8888);
   ensure("set k5", flag);
 
   // test change string value
@@ -365,20 +366,20 @@ TEST_FUNCTION(10)
 
   // item count still ok?
 
-  ensure_equals("item count after changes", (int)dict.count(), 6);
+  ensure_equals("item count after changes", dict.count(), 6U);
   
   // test add new value
   NodeId nkey;
   flag= vinsp->add_item(nkey);
   ensure("add ok", flag);
-  ensure_equals("add", nkey[0], 6);
+  ensure_equals("add", nkey[0], 6U);
 
   flag= vinsp->set_field(nkey, ValueInspectorBE::Name, "newk");
   ensure("set item name", flag);
   flag= vinsp->set_field(nkey, ValueInspectorBE::Value, "new value");
   ensure("set item", flag);
 
-  ensure_equals("new count", (int)dict.count(), 7);
+  ensure_equals("new count", dict.count(), 7U);
 
   dump_tree_model("output/grt_inspector_value_test10.2.txt", vinsp, columns, true);
   ensure_files_equal("dict check add", "output/grt_inspector_value_test10.2.txt", "data/be/grt_inspector_value_test10.2.txt")
@@ -387,7 +388,7 @@ TEST_FUNCTION(10)
   flag= vinsp->delete_item(3);
   ensure("del", flag);
   
-  ensure_equals("count", (int)dict.count(), 6);
+  ensure_equals("count", dict.count(), 6U);
 
   //ensure_equals("get/del value", value, "[ 1, 2, 3, 4, 5 ]");
   
@@ -399,7 +400,7 @@ TEST_FUNCTION(10)
 
   delete vinsp;
   
-  ensure_equals("final count", (int)dict.count(), 6);
+  ensure_equals("final count", dict.count(), 6U);
 }
 
 
@@ -407,7 +408,7 @@ TEST_FUNCTION(10)
 TEST_FUNCTION(11)
 {
   bool flag;
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
   
@@ -416,7 +417,7 @@ TEST_FUNCTION(11)
   // create a test dict
   DictRef dict(create_dict_with_int_data(&grt));
 
-  ensure_equals("initial dict size", (int)dict.count(), 9);
+  ensure_equals("initial dict size", dict.count(), 9U);
   ensure_equals("dict type", dict.type(), DictType);
   ensure_equals("dict content type", dict.content_type(), IntegerType);
 
@@ -426,8 +427,8 @@ TEST_FUNCTION(11)
   ensure_files_equal("object check", "output/grt_inspector_value_test11.txt", "data/be/grt_inspector_value_test11.txt");
   
   // test listing
-  int c= vinsp->count();
-  ensure_equals("begin listing", c, 9);
+  size_t c = vinsp->count();
+  ensure_equals("begin listing", c, 9U);
 
   std::string name, value;
   NodeId node;
@@ -440,10 +441,10 @@ TEST_FUNCTION(11)
   ensure("bad get", !node.is_valid());
 
   // test change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set 1", flag);
 
-  flag= vinsp->set_field(4, ValueInspectorBE::Value, 8888);
+  flag = vinsp->set_field(4, ValueInspectorBE::Value, (ssize_t)8888);
   ensure("set k5", flag);
 
   // test change string value
@@ -470,7 +471,7 @@ TEST_FUNCTION(11)
   NodeId nkey;
   flag= vinsp->add_item(nkey);
   ensure("add ok", flag);
-  ensure_equals("add", nkey[0], 9);
+  ensure_equals("add", nkey[0], 9U);
 
   flag= vinsp->set_field(nkey, ValueInspectorBE::Value, "new value");
   ensure("set item", !flag);
@@ -481,7 +482,7 @@ TEST_FUNCTION(11)
   flag= vinsp->set_field(nkey, ValueInspectorBE::Name, "anewk");
   ensure("set item", flag);
 
-  flag= vinsp->set_field(nkey, ValueInspectorBE::Value, 1234);
+  flag = vinsp->set_field(nkey, ValueInspectorBE::Value, (ssize_t)1234);
   ensure("set item", flag);
 
   ensure_equals("new count", (int)dict.count(), 10);
@@ -515,7 +516,7 @@ TEST_FUNCTION(11)
   flag= vinsp->delete_item(3);
   ensure("del", flag);
 
-  ensure_equals("count", (int)dict.count(), 10);
+  ensure_equals("count", dict.count(), 10U);
 
   flag= vinsp->delete_item(10);
   ensure("bad del", !flag);
@@ -529,7 +530,7 @@ TEST_FUNCTION(11)
   
   delete vinsp;
   
-  ensure_equals("final count", (int)dict.count(), 9);
+  ensure_equals("final count", dict.count(), 9U);
 }
 
 
@@ -538,7 +539,7 @@ TEST_FUNCTION(11)
 
 TEST_FUNCTION(20)
 {
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
 
@@ -555,11 +556,10 @@ TEST_FUNCTION(20)
 
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, book, false, false);
   bool flag;
-  int c;
 
   // test listing
-  c= vinsp->count();
-  ensure_equals("begin listing", c, 6);
+  size_t c= vinsp->count();
+  ensure_equals("begin listing", c, 6U);
   
   std::string name, value;
 
@@ -574,7 +574,7 @@ TEST_FUNCTION(20)
   ensure("bad get", !node.is_valid());
 
   // test bad change int value
-  flag= vinsp->set_field(5, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(5, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set invalid 1", !flag);
 
   flag= vinsp->set_field(5, ValueInspectorBE::Value, "The Illiad");
@@ -585,7 +585,7 @@ TEST_FUNCTION(20)
   ensure_equals("get/set title", value, "The Illiad");
 
   // test change int value
-  flag= vinsp->set_field(2, ValueInspectorBE::Value, 123);
+  flag = vinsp->set_field(2, ValueInspectorBE::Value, (ssize_t)123);
   ensure("set pages", flag);
 
   // test change double value
@@ -623,7 +623,7 @@ TEST_FUNCTION(20)
 
 TEST_FUNCTION(21)
 {
-  std::vector<int> columns;
+  std::vector<ssize_t> columns;
   columns.push_back(ValueInspectorBE::Name);
   columns.push_back(ValueInspectorBE::Value);
 
@@ -635,8 +635,8 @@ TEST_FUNCTION(21)
   ValueInspectorBE *vinsp= ValueInspectorBE::create(&grt, book, true, true);
 
   // test listing
-  int c= vinsp->count();
-  ensure_equals("top listing", c, 3);
+  size_t c = vinsp->count();
+  ensure_equals("top listing", c, 3U);
 
   std::string name, value;
   bool flag;
@@ -656,7 +656,7 @@ TEST_FUNCTION(21)
   }
 
   // test bad change int value
-  flag= vinsp->set_field(0, ValueInspectorBE::Value, 112211);
+  flag = vinsp->set_field(0, ValueInspectorBE::Value, (ssize_t)112211);
   ensure("set invalid 1", !flag);
 
   node= vinsp->get_child(0, 0);
@@ -666,7 +666,7 @@ TEST_FUNCTION(21)
 
   // test change int value
   node= vinsp->get_child(1, 1);
-  flag= vinsp->set_field(node, ValueInspectorBE::Value, 123);
+  flag = vinsp->set_field(node, ValueInspectorBE::Value, (ssize_t)123);
   ensure("set pages", flag);
 
   // test change double value
