@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,13 +17,10 @@
  * 02110-1301  USA
  */
 
-#ifndef _DBOBJECT_ROLES_H_
-#define _DBOBJECT_ROLES_H_
+#pragma once
 
 #include "editor_dbobject.h"
 
-#include "wbpublic_public_interface.h"
-
 namespace bec {
 
   class ObjectRoleListBE;
@@ -36,24 +33,21 @@ namespace bec {
       Enabled
     };
 
-    ObjectPrivilegeListBE(const db_mgmt_RdbmsRef &rdbms);
+    ObjectPrivilegeListBE(ObjectRoleListBE* owner, const db_mgmt_RdbmsRef &rdbms);
 
     virtual void refresh();
+    virtual size_t count();
 
-    virtual int count();
-
-    virtual bool set_field(const NodeId &node, int column, int value);
-    void set_owner(ObjectRoleListBE* owner) { _owner= owner; };
+    virtual bool set_field(const NodeId &node, ColumnId column, ssize_t value);
 
   protected:
     ObjectRoleListBE *_owner;
     db_mgmt_RdbmsRef _rdbms;
     grt::StringListRef _privileges;
 
-    virtual bool get_field_grt(const NodeId &node, int column, grt::ValueRef &value);
+    virtual bool get_field_grt(const NodeId &node, ColumnId column, grt::ValueRef &value);
   };
 
-
   
   class WBPUBLICBACKEND_PUBLIC_FUNC ObjectRoleListBE : public ListModel
   {
@@ -62,9 +56,9 @@ namespace bec {
       Name
     };
 
-    ObjectRoleListBE(DBObjectEditorBE *owner);
+    ObjectRoleListBE(DBObjectEditorBE *owner, const db_mgmt_RdbmsRef &rdbms);
 
-    virtual int count();
+    virtual size_t count();
     virtual void refresh();
 
     void select_role(const NodeId &node);
@@ -73,21 +67,18 @@ namespace bec {
     void remove_role_from_privileges(const db_RoleRef &role);
 
     ObjectPrivilegeListBE *get_privilege_list() { return &_privilege_list; }
-
     db_RolePrivilegeRef get_selected();
-
     DBObjectEditorBE *get_owner() { return _owner; }
 
   protected:
     DBObjectEditorBE *_owner;
+    db_mgmt_RdbmsRef _rdbms;
     std::vector<db_RolePrivilegeRef> _role_privs;
 
     ObjectPrivilegeListBE _privilege_list;
 
     NodeId _selected_node;
     
-    virtual bool get_field_grt(const NodeId &node, int column, grt::ValueRef &value);
+    virtual bool get_field_grt(const NodeId &node, ColumnId column, grt::ValueRef &value);
   };
 };
-
-#endif /* _DBOBJECT_ROLES_H_ */
