@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,9 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
-#include "wb_config.h"
-
 #include "editor_user_role.h"
 #include "db_object_helpers.h"
+
 #include "base/string_utilities.h"
 
 using namespace grt;
@@ -35,10 +32,10 @@ RolePrivilegeListBE::RolePrivilegeListBE(RoleEditorBE *owner)
 }
 
 
-int RolePrivilegeListBE::count()
+size_t RolePrivilegeListBE::count()
 {
   if (_privileges.is_valid())
-    return (int)_privileges.count();
+    return _privileges.count();
   return 0;
 }
 
@@ -47,25 +44,47 @@ void RolePrivilegeListBE::refresh()
 {
   _role_privilege= _owner->get_object_list()->get_selected_object_info();
 
-  _privileges.clear();
+  _privileges = grt::StringListRef();
   if (_role_privilege.is_valid())
   {
     grt::ListRef<db_mgmt_PrivilegeMapping> mappings(_owner->get_rdbms()->privilegeNames());
 
     for (size_t c= mappings.count(), i= 0; i < c; i++)
     {
-      if (_role_privilege->databaseObject().is_valid() &&
-        _role_privilege->databaseObject().is_instance(mappings[i]->structName()))
+      if (_role_privilege->databaseObject().is_valid())
       {
-        _privileges= mappings[i]->privileges();
-        break;
+        if (_role_privilege->databaseObject().is_instance(mappings[i]->structName()))
+        {
+          _privileges= mappings[i]->privileges();
+          break;
+        }
+      }
+      else if (!_role_privilege->databaseObjectType().empty())
+      {
+        std::string objectType;
+        if (_role_privilege->databaseObjectType() == "SCHEMA")
+          objectType = "db.mysql.Schema";
+        else if (_role_privilege->databaseObjectType() == "TABLE")
+          objectType = "db.mysql.Table";
+        else if (_role_privilege->databaseObjectType() == "ROUTINE")
+          objectType = "db.mysql.Routine";
+        else if (_role_privilege->databaseObjectType() == "FUNCTION")
+          objectType = "db.mysql.Routine";
+        else if (_role_privilege->databaseObjectType() == "PROCEDURE")
+          objectType = "db.mysql.Routine";
+        
+        if (objectType == *mappings[i]->structName())
+        {
+          _privileges= mappings[i]->privileges();
+          break;
+        }
       }
     }
   }
 }
 
 
-bool RolePrivilegeListBE::get_field_grt(const NodeId &node, int column, grt::ValueRef &value)
+bool RolePrivilegeListBE::get_field_grt(const NodeId &node, ColumnId column, grt::ValueRef &value)
 {
   if (node[0] >= count() || !_role_privilege.is_valid())
     return false;
@@ -86,7 +105,7 @@ bool RolePrivilegeListBE::get_field_grt(const NodeId &node, int column, grt::Val
 }
 
 
-bool RolePrivilegeListBE::set_field(const NodeId &node, int column, int value)
+bool RolePrivilegeListBE::set_field(const NodeId &node, ColumnId column, ssize_t value)
 {
   size_t index;
 
@@ -129,6 +148,21 @@ bool RolePrivilegeListBE::set_field(const NodeId &node, int column, int value)
 }
 
 
+void RolePrivilegeListBE::add_all()
+{
+  if (_role_privilege.is_valid())
+  {
+    AutoUndoEdit undo(_owner);
+
+    for (size_t c = _privileges.count(), i = 0; i < c; i++)
+      _role_privilege->privileges().insert(_privileges[i]);
+
+    undo.end(strfmt(_("Add All Privileges for '%s' to Role '%s'"),
+                    _role_privilege->databaseObject().is_valid() ? _role_privilege->databaseObject()->name().c_str() : "*",
+                    _owner->get_name().c_str()));
+  }
+}
+
 
 void RolePrivilegeListBE::remove_all()
 {
@@ -138,7 +172,7 @@ void RolePrivilegeListBE::remove_all()
     AutoUndoEdit undo(_owner);
     _role_privilege->privileges().remove_all();
     undo.end(strfmt(_("Remove Privileges for '%s' from Role '%s'"), 
-                    _role_privilege->databaseObject()->name().c_str(),
+                    _role_privilege->databaseObject().is_valid() ? _role_privilege->databaseObject()->name().c_str() : "*",
                     _owner->get_name().c_str()));
   }
 }
@@ -170,10 +204,10 @@ db_RolePrivilegeRef RoleObjectListBE::get_selected_object_info()
 }
 
 
-int RoleObjectListBE::count()
+size_t RoleObjectListBE::count()
 {
   if (_owner->get_role().is_valid())
-    return (int)_owner->get_role()->privileges().count();
+    return _owner->get_role()->privileges().count();
   return 0;
 }
 
@@ -183,6 +217,34 @@ MenuItemList RoleObjectListBE::get_popup_items_for_nodes(const std::vector<NodeI
   MenuItemList items;
   
   MenuItem item;
+
+  item.enabled = true;
+  item.type    = MenuAction;
+  
+  db_RoleRef role(_owner->get_role());
+  if (role.is_valid() && role->owner().is_valid())
+  {
+    db_CatalogRef catalog(db_CatalogRef::cast_from(role->owner()));
+    
+    GRTLIST_FOREACH(db_Schema, catalog->schemata(), schema)
+    {
+      item.caption = base::strfmt(_("Add Schema '%s'"), (*schema)->name().c_str());
+      item.name    = base::strfmt("adds:%s", (*schema)->name().c_str());
+      items.push_back(item);
+      item.caption = base::strfmt(_("Add Tables Wildcard for '%s.*'"), (*schema)->name().c_str());
+      item.name    = base::strfmt("addt:%s", (*schema)->name().c_str());
+      items.push_back(item);
+      item.caption = base::strfmt(_("Add All Tables in '%s'"), (*schema)->name().c_str());
+      item.name    = base::strfmt("allt:%s", (*schema)->name().c_str());
+      items.push_back(item);
+    }
+  }
+  item.caption = "";
+  item.name    = "sep";
+  item.type    = MenuSeparator;
+  items.push_back(item);
+
+  item.type    = MenuAction;
   item.caption = _("Delete Selected");
   item.name    = "deleteObject";
   item.enabled = nodes.size() > 0;
@@ -199,6 +261,26 @@ bool RoleObjectListBE::activate_popup_item_for_nodes(const std::string &name, co
     for (std::vector<NodeId>::const_reverse_iterator node= nodes.rbegin(); node != nodes.rend(); ++node)
       _owner->remove_object(*node);
   }
+  else if (name.substr(0, 5) == "adds:")
+    _owner->add_object("SCHEMA", name.substr(5)+".*");
+  else if (name.substr(0, 5) == "addt:")
+    _owner->add_object("TABLE", name.substr(5)+".*");
+  else if (name.substr(0, 5) == "allt:")
+  {
+    db_RoleRef role(_owner->get_role());
+    if (role.is_valid() && role->owner().is_valid())
+    {
+      db_CatalogRef catalog(db_CatalogRef::cast_from(role->owner()));
+      std::string wanted_schema = name.substr(5);
+
+      db_SchemaRef schema = grt::find_named_object_in_list(catalog->schemata(), wanted_schema);
+      if (schema.is_valid())
+      {
+        GRTLIST_FOREACH(db_Table, schema->tables(), table)
+          _owner->add_object(*table);
+      }
+    }
+  }
   else
     return false;
   
@@ -206,7 +288,7 @@ bool RoleObjectListBE::activate_popup_item_for_nodes(const std::string &name, co
 }
 
 
-bool RoleObjectListBE::get_field_grt(const NodeId &node, int column, grt::ValueRef &value)
+bool RoleObjectListBE::get_field_grt(const NodeId &node, ColumnId column, grt::ValueRef &value)
 {
   if (node[0] >= count())
     return false;
@@ -218,18 +300,37 @@ bool RoleObjectListBE::get_field_grt(const NodeId &node, int column, grt::ValueR
     if (priv.is_valid() && priv->databaseObject().is_valid())
       value= priv->databaseObject()->name();
     else
-      value= grt::StringRef("");
+      value= grt::StringRef(base::strfmt("%s", priv->databaseObjectName().c_str()));
     return true;
   }
   return false;
 }
 
 
-IconId RoleObjectListBE::get_field_icon(const NodeId &node, int column, IconSize size)
+IconId RoleObjectListBE::get_field_icon(const NodeId &node, ColumnId column, IconSize size)
 {
   db_RolePrivilegeRef priv(_owner->get_role()->privileges().get(node[0]));
-  if (priv.is_valid() && priv->databaseObject().is_valid())
-    return IconManager::get_instance()->get_icon_id(priv->databaseObject());
+  if (priv.is_valid())
+  {
+    if (priv->databaseObject().is_valid())
+      return IconManager::get_instance()->get_icon_id(priv->databaseObject());
+    else
+      if (priv->databaseObjectType().is_valid())
+      {
+        if (priv->databaseObjectType() == "TABLE")
+          return IconManager::get_instance()->get_icon_id("db.Table.many.$.png", Icon16, "");
+        if (priv->databaseObjectType() == "SCHEMA")
+          return IconManager::get_instance()->get_icon_id("db.Schema.$.png", Icon16, "");
+        if (priv->databaseObjectType() == "ROUTINE")
+          return IconManager::get_instance()->get_icon_id("db.Routine.many.$.png", Icon16, "");
+        if (priv->databaseObjectType() == "VIEW")
+          return IconManager::get_instance()->get_icon_id("db.View.many.$.png", Icon16, "");
+
+        return 0;
+      }
+      else
+        return 0;
+  }
   else
     return 0;
 }
@@ -261,6 +362,11 @@ std::string RoleEditorBE::get_name()
 }
 
 
+std::string RoleEditorBE::get_title()
+{
+  return strfmt("%s - Role", get_name().c_str());
+}
+                
 void RoleEditorBE::set_parent_role(const std::string &name)
 {
   if (name != get_parent_role())
@@ -349,6 +455,22 @@ bool RoleEditorBE::add_dropped_objectdata(const std::string &data)
 }
 
 
+bool RoleEditorBE::add_object(const std::string &type, const std::string &name)
+{
+  db_RolePrivilegeRef priv(_grtm->get_grt());
+  priv->databaseObjectType(type);
+  priv->databaseObjectName(name);
+  priv->owner(get_role());
+  
+  AutoUndoEdit undo(this);
+  
+  get_role()->privileges().insert(priv);
+  
+  undo.end(strfmt(_("Add Object %s '%s' to Role '%s'"), type.c_str(), name.c_str(), get_name().c_str()));
+  return true;
+}
+
+
 bool RoleEditorBE::add_object(db_DatabaseObjectRef object)
 {
   grt::ListRef<db_mgmt_PrivilegeMapping> mappings(get_rdbms()->privilegeNames());
