@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,14 +17,13 @@
  * 02110-1301  USA
  */
 
-#include "tut_stdafx.h"
-
 #include "grtpp.h"
 
 #include "grtdb/editor_table.h"
 #include "grtdb/db_object_helpers.h"
 #include "base/string_utilities.h"
 #include "sqlide/recordset_be.h"
+#include "wb_helpers.h"
 
 using namespace grt;
 using namespace bec;
@@ -48,13 +47,17 @@ class TestTableEditor : public TableEditorBE
   IndexListBE _indexes;
 
 public:
-#pragma warning(push)
-#pragma warning(disable:4355)
+#ifdef _WIN32
+# pragma warning(push)
+# pragma warning(disable:4355)
+#endif
   TestTableEditor(GRTManager *grtm, db_TableRef table, db_mgmt_RdbmsRef rdbms)
-    : TableEditorBE(grtm, table, rdbms), _table(table), _columns(this), _indexes(this)
+    : TableEditorBE(grtm, table), _table(table), _columns(this), _indexes(this)
     {
     }
-#pragma warning(pop)
+#ifdef _WIN32
+# pragma warning(pop)
+#endif
 
   db_TableRef get_table() { return _table; }
   
@@ -137,22 +140,6 @@ END_TEST_DATA_CLASS
 
 TEST_MODULE(editor_table_tests, "Table Editor backend");
 
-
-static grt::ValueRef get_app_option(const std::string &option)
-{
-  if (option == "DefaultPkColumnType")
-    return grt::StringRef("INT(11)");
-  else if (option == "DefaultColumnType")
-    return grt::StringRef("VARCHAR(40)");
-  else
-    g_warning("get_app_option(%s) unhandled", option.c_str());
-}
-
-
-static void set_app_option_dummy(const std::string &option, grt::ValueRef)
-{
-}
-
 TEST_FUNCTION(1)
 {
   wbt.create_new_document();
@@ -203,7 +190,7 @@ TEST_FUNCTION(3)
   NodeId node;
   std::string name;
   std::string type;
-  int ispk;
+  ssize_t ispk;
   bool notnull;
   std::string flags;
   std::string defvalue;
@@ -211,12 +198,12 @@ TEST_FUNCTION(3)
   bool flag;
 
   // count is always +1 because of placeholder
-  ensure_equals("initial column count", clist->count(), 1);
+  ensure_equals("initial column count", clist->count(), 1U);
 
   // create column
   node= editor->add_column("id");
-  ensure_equals("new column id", node[0], 0);
-  ensure_equals("column count", clist->count(), 2);
+  ensure_equals("new column id", node[0], 0U);
+  ensure_equals("column count", clist->count(), 2U);
 
   ensure("new column", table->columns().get(0).is_valid());
 
@@ -229,8 +216,8 @@ TEST_FUNCTION(3)
 
   // create column
   node= editor->add_column("name");
-  ensure_equals("new column id", node[0], 1);
-  ensure_equals("column count", clist->count(), 3);
+  ensure_equals("new column id", node[0], 1U);
+  ensure_equals("column count", clist->count(), 3U);
 
   flag= clist->get_field(node, TableColumnsListBE::Name, name);
   ensure("name column name get", flag);
@@ -280,7 +267,7 @@ TEST_FUNCTION(3)
   // create column  
   node= editor->add_column("email");
 
-  ensure_equals("column count", clist->count(), 6);
+  ensure_equals("column count", clist->count(), 6U);
 
 
   /// full column listing
@@ -458,11 +445,11 @@ TEST_FUNCTION(4)
   TableColumnsListBE *clist= editor->get_columns();
   bool flag;
   
-  ensure_equals("column count", clist->count(), 6);
+  ensure_equals("column count", clist->count(), 6U);
 
   editor->remove_column(3);
 
-  ensure_equals("new column count", clist->count(), 5);
+  ensure_equals("new column count", clist->count(), 5U);
   
   std::string name;
 
@@ -506,16 +493,16 @@ TEST_FUNCTION(10)
   std::string name, type, comment;
   bool flag;
 
-  ensure_equals("column count", editor->get_columns()->count(), 5);
+  ensure_equals("column count", editor->get_columns()->count(), 5U);
 
-  ensure_equals("index count", editor->get_indexes()->count(), 2);
+  ensure_equals("index count", editor->get_indexes()->count(), 2U);
 
   NodeId node= editor->add_index("idx1");
 
   index->select_index(node);
 //  index->set_field(0, IndexListBE::Name, "id");
 
-  ensure_equals("index count", index->count(), 3);
+  ensure_equals("index count", index->count(), 3U);
 
   flag= index->get_field(1, IndexListBE::Name, name);
   ensure("get index name", flag);
@@ -578,19 +565,19 @@ TEST_FUNCTION(10)
   for (size_t i= 0; i < table->columns().count(); i++)
   {
     flag= icolumns->get_field(i, IndexColumnsListBE::Name, name);
-    ensure(strfmt("index column[%i] name",i), flag);
-    ensure_equals(strfmt("index column[%i] name",i), name, *table->columns()[i]->name());
+    ensure(strfmt("index column[%lu] name",i), flag);
+    ensure_equals(strfmt("index column[%lu] name",i), name, *table->columns()[i]->name());
     flag= icolumns->get_field(i, IndexColumnsListBE::Descending, buf);
-    ensure(strfmt("index column[%i] desc",i), flag);
-    ensure_equals(strfmt("index column[%i] desc",i), buf, "0");
+    ensure(strfmt("index column[%lu] desc",i), flag);
+    ensure_equals(strfmt("index column[%lu] desc",i), buf, "0");
     flag= icolumns->get_field(i, IndexColumnsListBE::Length, buf);
-    ensure(strfmt("index column[%i] length",i), flag);
-    ensure_equals(strfmt("index column[%i] length",i), buf, "0");
+    ensure(strfmt("index column[%lu] length",i), flag);
+    ensure_equals(strfmt("index column[%lu] length",i), buf, "0");
     flag= icolumns->get_column_enabled(i);
     if (name == "id")
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, true);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, true);
     else
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, false);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, false);
   }
 
   // ** the idx we added
@@ -609,38 +596,38 @@ TEST_FUNCTION(10)
   for (size_t i= 0; i < table->columns().count(); i++)
   {
     flag= icolumns->get_field(i, IndexColumnsListBE::Name, name);
-    ensure(strfmt("index column[%i] name",i), flag);
-    ensure_equals(strfmt("index column[%i] name",i), name, *table->columns()[i]->name());
+    ensure(strfmt("index column[%lu] name",i), flag);
+    ensure_equals(strfmt("index column[%lu] name",i), name, *table->columns()[i]->name());
     if (name == "name")
     {
       flag= icolumns->get_field(i, IndexColumnsListBE::Descending, buf);
-      ensure(strfmt("index column[%i] desc",i), flag);
-      ensure_equals(strfmt("index column[%i] desc",i), buf, "1");
+      ensure(strfmt("index column[%lu] desc",i), flag);
+      ensure_equals(strfmt("index column[%lu] desc",i), buf, "1");
       flag= icolumns->get_field(i, IndexColumnsListBE::Length, buf);
-      ensure(strfmt("index column[%i] length",i), flag);
-      ensure_equals(strfmt("index column[%i] length",i), buf, "20");
+      ensure(strfmt("index column[%lu] length",i), flag);
+      ensure_equals(strfmt("index column[%lu] length",i), buf, "20");
       flag= icolumns->get_column_enabled(i);
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, true);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, true);
     }
     else
     {
       flag= icolumns->get_field(i, IndexColumnsListBE::Descending, buf);
-      ensure(strfmt("index column[%i] desc",i), flag);
-      ensure_equals(strfmt("index column[%i] desc",i), buf, "0");
+      ensure(strfmt("index column[%lu] desc",i), flag);
+      ensure_equals(strfmt("index column[%lu] desc",i), buf, "0");
       flag= icolumns->get_field(i, IndexColumnsListBE::Length, buf);
-      ensure(strfmt("index column[%i] length",i), flag);
-      ensure_equals(strfmt("index column[%i] length",i), buf, "0");
+      ensure(strfmt("index column[%lu] length",i), flag);
+      ensure_equals(strfmt("index column[%lu] length",i), buf, "0");
       flag= icolumns->get_column_enabled(i);
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, false);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, false);
     }
   }
 
 
   // remove index
-  editor->remove_index(1);
+  editor->remove_index(1, false);
 
 
-  ensure_equals("index count", index->count(), 2);
+  ensure_equals("index count", index->count(), 2U);
 
   // add new one with convenience func
   std::vector<NodeId> columns;
@@ -648,9 +635,9 @@ TEST_FUNCTION(10)
   columns.push_back(NodeId(3)); // email
   node= editor->add_index_with_columns(columns);
 
-  ensure_equals("new index", node[0], 1);
+  ensure_equals("new index", node[0], 1U);
 
-  ensure_equals("index count", index->count(), 3);
+  ensure_equals("index count", index->count(), 3U);
   
   index->set_field(1, IndexListBE::Name, "namemail_index");
 
@@ -669,24 +656,24 @@ TEST_FUNCTION(10)
   for (size_t i= 0; i < (size_t)icolumns->count(); i++)
   {
     flag= icolumns->get_field(i, IndexColumnsListBE::Name, name);
-    ensure(strfmt("index column[%i] name",i), flag);
-    ensure_equals(strfmt("index column[%i] name",i), name, *table->columns()[i]->name());
+    ensure(strfmt("index column[%lu] name",i), flag);
+    ensure_equals(strfmt("index column[%lu] name",i), name, *table->columns()[i]->name());
     flag= icolumns->get_field(i, IndexColumnsListBE::Descending, buf);
-    ensure(strfmt("index column[%i] desc",i), flag);
-    ensure_equals(strfmt("index column[%i] desc",i), buf, "0");
+    ensure(strfmt("index column[%lu] desc",i), flag);
+    ensure_equals(strfmt("index column[%lu] desc",i), buf, "0");
     flag= icolumns->get_field(i, IndexColumnsListBE::Length, buf);
-    ensure(strfmt("index column[%i] length",i), flag);
-    ensure_equals(strfmt("index column[%i] length",i), buf, "0");
+    ensure(strfmt("index column[%lu] length",i), flag);
+    ensure_equals(strfmt("index column[%lu] length",i), buf, "0");
 
     if (name == "name" || name == "email")
     {
       flag= icolumns->get_column_enabled(i);
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, true);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, true);
     }
     else
     {
       flag= icolumns->get_column_enabled(i);
-      ensure_equals(strfmt("index column[%i] enabled",i), flag, false);
+      ensure_equals(strfmt("index column[%lu] enabled",i), flag, false);
     }
   }
 }
@@ -703,9 +690,9 @@ TEST_FUNCTION(11)
   columns.push_back(NodeId(3)); // email
   editor->add_index_with_columns(columns);
 
-  ensure_equals("index count", index->count(), 4);
+  ensure_equals("index count", index->count(), 4U);
 
-  ensure_equals("column count", editor->get_columns()->count(), 5);
+  ensure_equals("column count", editor->get_columns()->count(), 5U);
 
   std::string name;
   bool flag;
@@ -720,7 +707,7 @@ TEST_FUNCTION(11)
 
   ensure_equals("column count", table->indices().get(1)->columns().count(), 1U);
 
-  ensure_equals("index count", index->count(), 3);
+  ensure_equals("index count", index->count(), 3U);
 
 
   flag= index->get_field(0, IndexListBE::Name, name);
@@ -757,7 +744,9 @@ TEST_FUNCTION(12)
   ensure("table editor !NULL", editor != NULL);
 
   // bug: unsetting an index column is wrong (and may crash)
-  db_TableRef table= db_mysql_TableRef(grtm->get_grt());
+  db_TableRef table = db_mysql_TableRef(grtm->get_grt());
+  table->owner(wbt.get_schema());
+
   ensure("table ok", table.is_valid());
 
   db_ColumnRef column(grtm->get_grt());
@@ -777,15 +766,15 @@ TEST_FUNCTION(12)
 
   TestTableEditor ed(grtm, table,  wbt.get_rdbms());
 
-  ensure_equals("column count", ed.get_columns()->count(), 4);
+  ensure_equals("column count", ed.get_columns()->count(), 4U);
 
   ed.add_index("hello");
 
-  ensure_equals("index count", ed.get_indexes()->count(), 2);
+  ensure_equals("index count", ed.get_indexes()->count(), 2U);
 
   ed.get_indexes()->select_index(0);
 
-  ensure_equals("index column item count", ed.get_indexes()->get_columns()->count(), 3);
+  ensure_equals("index column item count", ed.get_indexes()->get_columns()->count(), 3U);
   
   
   IndexColumnsListBE *ic= ed.get_indexes()->get_columns();
@@ -875,14 +864,14 @@ TEST_FUNCTION(20)
   db_mysql_ColumnRef column(grtm->get_grt());
   column->owner(table);
   column->name("id");
-  column->setParseType("int", editor.get_rdbms()->simpleDatatypes());
+  column->setParseType("int", wbt.get_rdbms()->simpleDatatypes());
   //bec::ColumnHelper::parse_column_type(editor.get_rdbms(), userTypes, "int", column);
   table->columns().insert(column);
 
   column= db_mysql_ColumnRef(grtm->get_grt());
   column->owner(table);
   column->name("fk");
-  column->setParseType("int", editor.get_rdbms()->simpleDatatypes());
+  column->setParseType("int", wbt.get_rdbms()->simpleDatatypes());
   //bec::ColumnHelper::parse_column_type(editor.get_rdbms(), userTypes, "int", column);
   table->columns().insert(column);
 
