@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,7 @@
  * 02110-1301  USA
  */
 
-#ifndef __BINARY_DATA_EDITOR_H__
-#define __BINARY_DATA_EDITOR_H__
+#pragma once
 
 #include "wbpublic_public_interface.h"
 
@@ -27,6 +26,7 @@
 #include "mforms/tabview.h"
 #include "mforms/label.h"
 #include "mforms/button.h"
+#include "mforms/jsonview.h"
 
 namespace bec {
   class GRTManager;
@@ -61,11 +61,13 @@ public:
   
 public:
   void add_viewer(BinaryDataViewer *viewer, const std::string &title);
+  void add_json_viewer(bool read_only, const std::string &text_encoding, const std::string &title);
 
   void assign_data(const char *data, size_t length, bool steal_pointer=false);
   void notify_edit();
   
   bool read_only() { return _read_only; }
+  bool isJson() { return _type == "JSON"; }
 
 protected:
   bec::GRTManager *_grtm;
@@ -73,8 +75,9 @@ protected:
   size_t _length;
   std::string _type;
 
-  // editor, needs-update
-  std::vector<std::pair<BinaryDataViewer*, bool> > _viewers;
+  std::vector<BinaryDataViewer*> _viewers;
+  std::set<BinaryDataViewer*> _pendingUpdates;
+  bool _updating;
 
   mforms::Box _box;
   mforms::Box _hbox;
@@ -84,7 +87,7 @@ protected:
   mforms::Button _close;
   mforms::Button _export;
   mforms::Button _import;
-  
+
   bool _read_only;
   
   void setup();
@@ -94,6 +97,3 @@ protected:
   void import_value();
   void export_value();
 };
-
-
-#endif /* __BINARY_DATA_EDITOR_H__ */
\ No newline at end of file
