@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -421,7 +421,7 @@ void DbDriverParams::init(
       {
         unknown_options_text.append(*k);
         unknown_options_text.append("=");
-        unknown_options_text.append(stored_conn->parameterValues().get(*k).repr());
+        unknown_options_text.append(stored_conn->parameterValues().get(*k).toString());
         unknown_options_text.append("\n");
       }
     }
@@ -546,7 +546,7 @@ grt::DictRef DbDriverParams::get_params() const
       {
         if (param_handle->object()->name() == "$others")
         {
-          std::vector<std::string> options(base::split(param_handle->get_value().repr(), "\n"));
+          std::vector<std::string> options(base::split(param_handle->get_value().toString(), "\n"));
           for (std::vector<std::string>::const_iterator op = options.begin(); op != options.end(); ++op)
           {
             std::string name, value;
