@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,13 +17,14 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
-#include "inserts_export_form.h"
-#include "sqlide/recordset_text_storage.h"
-#include "sqlide/recordset_sql_storage.h"
 #include "base/string_utilities.h"
 #include "base/file_utilities.h"
+#include "base/util_functions.h"
+
+#include "inserts_export_form.h"
+
+#include "sqlide/recordset_text_storage.h"
+#include "sqlide/recordset_sql_storage.h"
 
 #include "mforms/simpleform.h"
 #include "mforms/utilities.h"
@@ -41,7 +42,7 @@ InsertsExportForm::InsertsExportForm(mforms::Form *owner, Recordset::Ref rset, c
   {
     extlist.append("|").append(_storage_types[i].description);
     extlist.append("|").append(_storage_types[i].extension);
-    _storage_type_index[_storage_types[i].description] = i;
+    _storage_type_index[_storage_types[i].description] = (int)i;
   }
   
   if (extlist.empty())
@@ -65,22 +66,18 @@ std::string InsertsExportForm::run()
     std::string format= get_selector_option_value("format");
     int i = _storage_type_index[format];
     const Recordset_storage_info &info(_storage_types[i]);
-    std::string format_ext = info.extension;
-    std::string format_name = info.name;
-    if (ext != format_ext)
-      path.append(".").append(format_ext);
  
-    Recordset_data_storage::Ref dataStorage= _record_set->data_storage_for_export(format_name);
+    Recordset_data_storage::Ref dataStorage= _record_set->data_storage_for_export(info.name);
     
     if (dynamic_cast<Recordset_text_storage*>(dataStorage.get()))
     {
       Recordset_text_storage *textStorage= dynamic_cast<Recordset_text_storage*>(dataStorage.get());
-      textStorage->data_format(format_name);
+      textStorage->data_format(info.name);
       textStorage->file_path(path);
 
       Recordset_sql_storage* storage = dynamic_cast<Recordset_sql_storage*>(_record_set->data_storage().get());
       textStorage->parameter_value("GENERATOR_QUERY", _record_set->generator_query());
-      textStorage->parameter_value("GENERATE_DATE", bec::fmttime(time(NULL), DATETIME_FMT));
+      textStorage->parameter_value("GENERATE_DATE", base::fmttime(time(NULL), DATETIME_FMT));
       textStorage->parameter_value("TABLE_NAME", storage->table_name().empty() ? "TABLE" : storage->table_name());
     
       if (!info.arguments.empty())
