@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,13 @@
  * 02110-1301  USA
  */
 
+#include <sqlite/execute.hpp>
+#include <sqlite/query.hpp>
+
 #include "recordset_table_inserts_storage.h"
 #include "recordset_be.h"
 #include "base/string_utilities.h"
 
-#include <sqlite/execute.hpp>
-#include <sqlite/query.hpp>
 #include <boost/foreach.hpp>
 #include <algorithm>
 #include <list>
@@ -54,7 +55,7 @@ void Recordset_table_inserts_storage::do_unserialize(Recordset *recordset, sqlit
   Recordset::Column_names &column_names= get_column_names(recordset);
   Recordset::Column_types &column_types= get_column_types(recordset);
   Recordset::Column_types &real_column_types= get_real_column_types(recordset);
-  Recordset::Column_quoting &column_quoting= get_column_quoting(recordset);
+  Recordset::Column_flags &column_flags= get_column_flags(recordset);
 
   reinit(_mapped_colnames);
   _mapped_table_name= _table->id();
@@ -87,7 +88,7 @@ void Recordset_table_inserts_storage::do_unserialize(Recordset *recordset, sqlit
       known_typegroups["com.mysql.rdbms.common.typegroup.userdefined"]= std::string();
       known_typegroups["com.mysql.rdbms.common.typegroup.structured"]= std::string();
 
-      long double ld;
+      long double ld = 0;
       known_real_typegroups= known_typegroups;
       known_real_typegroups["com.mysql.rdbms.common.typegroup.numeric"]= ld;
     }
@@ -149,7 +150,12 @@ void Recordset_table_inserts_storage::do_unserialize(Recordset *recordset, sqlit
 
     column_types.push_back(known_types.map_simple_datatype(stype, false));
     real_column_types.push_back(known_types.map_simple_datatype(stype, true));
-    column_quoting.push_back(stype.is_valid() ? (*stype->needsQuotes() != 0 ? 1 : 0) : 0);
+    int flags = 0;
+    if (stype.is_valid())
+      flags = *stype->needsQuotes() != 0 ? Recordset::NeedsQuoteFlag : 0;
+    if (*column->isNotNull())
+      flags = flags | (int)Recordset::NotNullFlag;
+    column_flags.push_back(flags);
   }
 
   // column names
