@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -63,7 +63,7 @@ class MySQLRecognizer;
 #define AC_SCHEMA_IMAGE         2
 #define AC_TABLE_IMAGE          3
 #define AC_ROUTINE_IMAGE        4 // For SQL stored procedures + functions.
-#define AC_FUNCTION_IMAGE       5 // For MySQL library (runtime) functions.
+#define AC_FUNCTION_IMAGE       5 // For MySQL library (runtime) functions and UDFs.
 #define AC_VIEW_IMAGE           6
 #define AC_COLUMN_IMAGE         7
 #define AC_OPERATOR_IMAGE       8
@@ -170,6 +170,8 @@ public:
   void focus();
 
   void register_file_drop_for(mforms::DropDelegate *target);
+  
+  void set_continue_on_error(bool value);
 
 protected:
   MySQLEditor(grt::GRT *grt, parser::ParserContext::Ref syntax_check_context,
@@ -222,4 +224,5 @@ private:
   std::string _current_schema;
 
   std::string _sql_mode;
+  bool _continue_on_error;
 };
