@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,9 +17,10 @@
  * 02110-1301  USA
  */
 
+#include "sqlide_generics_private.h"
+
 #include "var_grid_model_be.h"
 #include "base/string_utilities.h"
-#include "sqlide_generics_private.h"
 #include <sqlite/execute.hpp>
 #include <sqlite/query.hpp>
 #include <boost/foreach.hpp>
@@ -95,6 +96,7 @@ VarGridModel::~VarGridModel()
 
 void VarGridModel::reset()
 {
+  base::RecMutexLock data_mutex UNUSED (_data_mutex);
   _data_swap_db.reset();
   if (_data_swap_db_path.empty())
   {
@@ -110,14 +112,11 @@ void VarGridModel::reset()
     sqlite::execute(*data_swap_db, "create table `changes` (`id` integer primary key autoincrement, `record` integer, `action` integer, `column` integer)", true);
   }
 
-  {
-    base::RecMutexLock data_mutex UNUSED (_data_mutex);
-    reinit(_data);
-  }
+  reinit(_data);
   reinit(_column_names);
   reinit(_column_types);
   reinit(_real_column_types);
-  reinit(_column_quoting);
+  reinit(_column_flags);
 
   _column_count= 0;
   _row_count= 0;
