@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include "model_layer_impl.h"
 #include "model_diagram_impl.h"
 #include "model_model_impl.h"
@@ -265,7 +263,7 @@ bool model_Layer::ImplData::realize()
     _area_group->set_background_color(color);
     _area_group->set_draw_background(true);
     std::string font= self()->owner()->owner()->get_data()->get_string_option(base::strfmt("%s:TitleFont", self()->class_name().c_str()), "");
-    dynamic_cast<wbfig::LayerAreaGroup*>(_area_group)->set_font(parse_font_spec(font));
+    dynamic_cast<wbfig::LayerAreaGroup*>(_area_group)->set_font(mdc::FontSpec::from_string(font));
 
     dynamic_cast<wbfig::LayerAreaGroup*>(_area_group)->set_title(*self()->_name);
 
