@@ -24,16 +24,38 @@
 #include "base/log.h"
 DEFAULT_LOG_DOMAIN("notebook_dockingpoint")
 
+NotebookDockingPoint::NotebookDockingPoint(Gtk::Notebook *note, const std::string &type)
+  : _notebook(note), _type(type) 
+{
+  if (_notebook)
+    _notebook->signal_switch_page().connect(sigc::hide(sigc::hide(sigc::mem_fun(_dpoint, &mforms::DockingPoint::view_switched))));
+}
+
+void NotebookDockingPoint::set_notebook(Gtk::Notebook *note)
+{
+  _notebook = note;
+  _notebook->signal_switch_page().connect(sigc::hide(sigc::hide(sigc::mem_fun(_dpoint, &mforms::DockingPoint::view_switched))));
+}
+
 void NotebookDockingPoint::close_appview_page(mforms::AppView *view)
 {
-  _dpoint->close_view(view);
+  if (view->on_close())
+    view->close();
 }
 
 bool NotebookDockingPoint::close_page(Gtk::Widget *w)
 {
   mforms::AppView *aview = dynamic_cast<mforms::AppView*>(mforms::gtk::ViewImpl::get_view_for_widget(w));
   if (aview)
-    return _dpoint->close_view(aview);
+  {
+    if (aview->on_close())
+    {
+      aview->close();
+      return true;
+    }
+    else
+      return false;
+  }
   return true;
 }
 
@@ -45,6 +67,12 @@ void NotebookDockingPoint::dock_view(mforms::AppView *view, const std::string &a
   {
     ActiveLabel *l = Gtk::manage(new ActiveLabel("mforms", sigc::bind(sigc::mem_fun(this, &NotebookDockingPoint::close_appview_page), view)));
     int i = _notebook->append_page(*w, *l);
+
+    if (view->release_on_add())
+      view->set_release_on_add(false);
+    else
+      view->retain();
+
     _notebook->set_current_page(i);
     w->set_data("NotebookDockingPoint:label", l);
 
@@ -75,6 +103,7 @@ void NotebookDockingPoint::undock_view(mforms::AppView *view)
     //before remove, unset menu if it was set
     _notebook->remove_page(*w);
     notebook_changed_signal.emit(false);
+    view->release();
   }
 }
 
@@ -105,87 +134,24 @@ std::pair<int, int> NotebookDockingPoint::get_size()
 }
 
 
-void NotebookDockingPoint::set_notebook(Gtk::Notebook *note)
+mforms::AppView *NotebookDockingPoint::selected_view()
 {
-  _notebook = note;
+  int i = _notebook->get_current_page();
+  if (i >= 0)
+    return view_at_index(i);
+  return NULL;
 }
 
-
-void ActionAreaNotebookDockingPoint::set_notebook(ActionAreaNotebook *note)
+int NotebookDockingPoint::view_count()
 {
-  _notebook = note;
+  return _notebook->get_n_pages();
 }
 
-
-void ActionAreaNotebookDockingPoint::close_page(mforms::AppView *view)
+mforms::AppView *NotebookDockingPoint::view_at_index(int index)
 {
-  _dpoint->close_view(view);
-}
-
-
-void ActionAreaNotebookDockingPoint::dock_view(mforms::AppView *view, const std::string &arg1, int arg2)
-{
-  Gtk::Widget *w = mforms::widget_for_view(view);
+  Gtk::Widget *w = _notebook->get_nth_page(index);
   if (w)
-  {
-    ActiveLabel *l = Gtk::manage(new ActiveLabel("mforms", sigc::bind(sigc::mem_fun(this, &ActionAreaNotebookDockingPoint::close_page), view)));
-    int num = _notebook->append_page(*w, *l);
-    _notebook->set_current_page(num);
-    w->set_data("ActionAreaNotebookDockingPoint:label", l);
-
-    notebook_changed_signal.emit(true);
-  }
+    return dynamic_cast<mforms::AppView*>(mforms::gtk::ViewImpl::get_view_for_widget(w));
+  return NULL;
 }
 
-bool ActionAreaNotebookDockingPoint::select_view(mforms::AppView *view)
-{
-  Gtk::Widget *w = mforms::widget_for_view(view);
-  if (w)
-  {
-    int p = _notebook->page_num(*w);
-    if (p >= 0)
-    {
-      _notebook->set_current_page(p);
-      return true;
-    }
-  }
-  return false;
-}
-
-void ActionAreaNotebookDockingPoint::undock_view(mforms::AppView *view)
-{
-  Gtk::Widget *w = mforms::widget_for_view(view);
-  if (w)
-  {
-    _notebook->remove_page(*w);
-    notebook_changed_signal.emit(false);
-  }
-}
-
-void ActionAreaNotebookDockingPoint::set_view_title(mforms::AppView *view, const std::string &title)
-{
-  Gtk::Widget *w = mforms::widget_for_view(view);
-  if (w)
-  {
-    int idx = _notebook->page_num(*w);
-    if (idx >=0)
-    {
-      Gtk::Widget *page = _notebook->get_nth_page(idx);
-      if (page)
-      {
-        ActiveLabel *label = reinterpret_cast<ActiveLabel*>(page->get_data("ActionAreaNotebookDockingPoint:label"));
-        if (label)
-          label->set_text(title);
-      }
-    }
-    else
-      log_warning("Can't set title of unknown view to %s\n", title.c_str());
-  }
-}
-
-std::pair<int, int> ActionAreaNotebookDockingPoint::get_size()
-{
-  return std::pair<int, int>(_notebook->get_width(), _notebook->get_height());
-}
-
-
