@@ -24,10 +24,7 @@ namespace gtk
 {
 
 void save_settings(bec::GRTManager* m, Gtk::Paned* paned, const bool right_side = false);
-void load_settings(bec::GRTManager* m, Gtk::Paned* paned, const sigc::slot<void> defaults_slot = sigc::slot<void>(), const bool right_side = false, const int min_size = 0);
-
-void save_toolbar_state(bec::GRTManager* m, mforms::ToolBar* tb);
-void load_toolbar_state(bec::GRTManager* m, mforms::ToolBar* tb);
+sigc::connection load_settings(bec::GRTManager* m, Gtk::Paned* paned, const sigc::slot<void> defaults_slot = sigc::slot<void>(), const bool right_side = false, const int min_size = 0);
 
 } // ns gtk
 } // ns utils
