@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,7 @@
 
 #include "base/threaded_timer.h"
 #include "base/log.h"
+#include "base/threading.h"
 
 // 30 fps should ensure smooth animations. Higher values are better, but put higher load on a system.
 #define BASE_FREQUENCY 30
@@ -44,8 +45,7 @@ ThreadedTimer* ThreadedTimer::get()
   G_LOCK(_timer);
   if (_timer == NULL)
   {
-    if (!g_thread_supported())
-      g_thread_init(NULL);
+    base::threading_init();
     _timer= new ThreadedTimer(BASE_FREQUENCY);
   }
   G_UNLOCK(_timer);
@@ -75,13 +75,11 @@ void ThreadedTimer::stop()
  *              - A time span (given in seconds).
  * @param single_shot True, if this event must be triggered only once.
  * @param callback_ What to call when a timer event fires.
- * @param user_data A pointer which is transparently passed to the callback.
  * @result The id of the new task (can be used in the callback) or -1 if the task could not be added.
  */
-int ThreadedTimer::add_task(TimerUnit unit, double value, bool single_shot, timer_function callback_,
-                            void* user_data)
+int ThreadedTimer::add_task(TimerUnit unit, double value, bool single_shot, TimerFunction callback)
 {
-  TimerTask task= {0, 0.0, 0.0, callback_, false, single_shot, user_data, false};
+  TimerTask task = {0, 0.0, 0.0, callback, false, single_shot, false};
   
   if (value <= 0)
     throw std::logic_error("The given timer value is invalid.");
@@ -107,15 +105,12 @@ int ThreadedTimer::add_task(TimerUnit unit, double value, bool single_shot, time
   if (task.wait_time > 0)
   {
     ThreadedTimer* timer= ThreadedTimer::get();
-    g_mutex_lock(timer->_timer_lock);
+    base::MutexLock lock(timer->_timer_lock);
     
     // We have the lock acquired so it is save to increment the id counter.
     task.task_id= timer->_next_id++;
-    task.user_data= user_data;
     timer->_tasks.push_back(task);
     
-    g_mutex_unlock(timer->_timer_lock);
-    
     return task.task_id;
   }
   return -1;
@@ -131,7 +126,7 @@ int ThreadedTimer::add_task(TimerUnit unit, double value, bool single_shot, time
  */
 void ThreadedTimer::remove_task(int task_id)
 {
-  ThreadedTimer* timer= ThreadedTimer::get();
+  ThreadedTimer *timer = ThreadedTimer::get();
   timer->remove(task_id);
 }
 
@@ -141,8 +136,7 @@ ThreadedTimer::ThreadedTimer(int base_frequency): _terminate(false), _next_id(1)
 {
   // Wait time in microseconds.
   _wait_time= 1000 * 1000 / base_frequency;
-  _timer_lock= g_mutex_new();
-  _thread= g_thread_create(start, this, TRUE, NULL);
+  _thread= base::create_thread(start, this);
   _pool= g_thread_pool_new((GFunc) pool_function, this, WORKER_THREAD_COUNT, FALSE, NULL);
 }
 
@@ -158,13 +152,12 @@ ThreadedTimer::~ThreadedTimer()
   log_debug2("Threaded timer shutdown...\n");
 
   // Don't lock the mutex or we might deadlock here if the mutex is currently held by the work loop.
-  _terminate= true;
+  _terminate = true;
 
   // Wait for the timer thread to terminate.
   g_thread_join(_thread);
   
   g_thread_pool_free(_pool, TRUE, TRUE);
-  g_mutex_free(_timer_lock);
 
   log_debug2("Threaded timer shutdown done\n");
 }
@@ -176,7 +169,7 @@ ThreadedTimer::~ThreadedTimer()
  */
 gpointer ThreadedTimer::start(gpointer data)
 {
-  ThreadedTimer *thread= static_cast<ThreadedTimer*>(data);
+  ThreadedTimer *thread = static_cast<ThreadedTimer *>(data);
   thread->main_loop();
   return NULL;
 }
@@ -188,36 +181,33 @@ gpointer ThreadedTimer::start(gpointer data)
  */
 gpointer ThreadedTimer::pool_function(gpointer data, gpointer user_data)
 {
-  ThreadedTimer* timer= static_cast<ThreadedTimer*>(user_data);
-  TimerTask* task= static_cast<TimerTask*>(data);
+  ThreadedTimer *timer = static_cast<ThreadedTimer *>(user_data);
+  TimerTask *task = static_cast<TimerTask *>(data);
   
   try
   {
-    bool do_stop= task->callback(task->task_id, task->user_data);
+    bool do_stop = task->callback(task->task_id);
    
-    g_mutex_lock(timer->_timer_lock);
+    base::MutexLock lock(timer->_timer_lock);
     task->stop= do_stop || task->single_shot;
     task->scheduled= false;
-    g_mutex_unlock(timer->_timer_lock);
   }
   catch (std::exception& e)
   {
     // In the case of an exception we remove the task silently.
-    g_mutex_lock(timer->_timer_lock);
+    base::MutexLock lock(timer->_timer_lock);
     task->stop= true;
     task->scheduled= false;
     log_warning("Threaded timer: exception in pool function: %s\n", e.what());
-    g_mutex_unlock(timer->_timer_lock);
   }
   catch (...)
   {
     // Most exceptions should be caught by the part above. Just to be on the safe side
     // do this extra branch.
-    g_mutex_lock(timer->_timer_lock);
+    base::MutexLock(timer->_timer_lock);
     task->stop= true;
     task->scheduled= false;
     log_warning("Threaded timer: unknown exception in pool function\n");
-    g_mutex_unlock(timer->_timer_lock);
   }
 
   return NULL;
@@ -235,10 +225,12 @@ public:
   }
 };
 
+//--------------------------------------------------------------------------------------------------
+
 void ThreadedTimer::main_loop()
 {
   // Provides a high-quality clock which is used to compute execution times of tasks.
-  GTimer* clock= g_timer_new();
+  GTimer *clock = g_timer_new();
   g_timer_start(clock);
   while (!_terminate)
   {
@@ -249,17 +241,17 @@ void ThreadedTimer::main_loop()
       break;
     
     // 1. Compute next execution time for new tasks.
-    g_mutex_lock(_timer_lock);
+    base::MutexLock lock(_timer_lock);
     for (std::list<TimerTask>::iterator iterator= _tasks.begin(); iterator != _tasks.end(); iterator++)
     {
       if (iterator->next_time == 0)
-        iterator->next_time= g_timer_elapsed(clock, NULL) + iterator->wait_time;
+        iterator->next_time = g_timer_elapsed(clock, NULL) + iterator->wait_time;
     }
     
     // 2. Execute all tasks which are due now.
     // Processing of the task entries should be very fast here. No need to make a copy of them.
-    gdouble current_time= g_timer_elapsed(clock, NULL);
-    for (std::list<TimerTask>::iterator iterator= _tasks.begin(); iterator != _tasks.end(); iterator++)
+    gdouble current_time = g_timer_elapsed(clock, NULL);
+    for (std::list<TimerTask>::iterator iterator = _tasks.begin(); iterator != _tasks.end(); ++iterator)
     {
       if (_terminate)
         break;
@@ -269,8 +261,8 @@ void ThreadedTimer::main_loop()
         // When the task is due push it to our thread pool. It will then get one of the
         // free threads assigned to run in and pool_function is called in this thread's context.
         // Do it only if it isn't already scheduled.
-        TimerTask& task= *iterator;
-        task.scheduled= true;
+        TimerTask& task = *iterator;
+        task.scheduled = true;
         task.next_time += task.wait_time;
         g_thread_pool_push(_pool, &task, NULL);
       }
@@ -278,10 +270,8 @@ void ThreadedTimer::main_loop()
     
     // 3. Remove stopped task.
     _tasks.remove_if(IsStopped());
-                     
-    g_mutex_unlock(_timer_lock);
+
   }
-  // printf("timer thread ended\n");
   g_timer_destroy(clock);
 }
 
@@ -292,16 +282,15 @@ void ThreadedTimer::main_loop()
  */
 void ThreadedTimer::remove(int task_id)
 {
-  g_mutex_lock(_timer_lock);
+  base::MutexLock lock(_timer_lock);
   for (std::list<TimerTask>::iterator iterator= _tasks.begin(); iterator != _tasks.end(); iterator++)
   {
     if (iterator->task_id == task_id)
     {
-      iterator->stop= true;
+      iterator->stop = true;
       break;
     }
   }
-  g_mutex_unlock(_timer_lock);
 }
 
 //--------------------------------------------------------------------------------------------------
