@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,10 +17,9 @@
  * 02110-1301  USA
  */
 
-#include "tut_stdafx.h"
-
 #include "base/sqlstring.h"
 #include "base/string_utilities.h"
+#include "wb_helpers.h"
 
 #include <boost/lexical_cast.hpp>
 
