@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,9 +21,13 @@
 #include "base/drawing.h"
 #include "base/string_utilities.h"
 #include "base/notifications.h"
+#include "base/drawing.h"
+
 #include "tinyxml.h"
 #include "SciLexer.h"
+
 #include "mforms/mforms.h"
+#include "mdc_image.h"
 
 DEFAULT_LOG_DOMAIN(DOMAIN_MFORMS_BE)
 
@@ -34,11 +38,13 @@ using namespace base;
 
 // Marker ID assignments. Markers with higher number overlay lower ones.
 // Note: the order here matches the LineMarkup enum, so we can directly use the enum as marker flags.
+//       The LineMarkup is a bitmask (so we can create what Scintilla calls a marker set).
 #define CE_STATEMENT_MARKER      0
 #define CE_ERROR_MARKER          1
 #define CE_BREAKPOINT_MARKER     2
 #define CE_BREAKPOINT_HIT_MARKER 3
 #define CE_CURRENT_LINE_MARKER   4
+#define CE_ERROR_CONTINUE_MARKER 5
 
 #define AC_LIST_SEPARATOR '\x19' // Unused codes as separators.
 #define AC_TYPE_SEPARATOR '\x18'
@@ -95,6 +101,16 @@ CodeEditorConfig::CodeEditorConfig(SyntaxHighlighterLanguage language)
     lexer = "SCLEX_CPP";
     break;
 
+  case mforms::LanguageJS:
+    lexer = "SCLEX_CPP";
+    override_lexer = "SCLEX_CPP_JS";
+    break;
+
+  case mforms::LanguageJson:
+    lexer = "SCLEX_CPP";
+    override_lexer = "SCLEX_CPP_JSON";
+    break;
+
   default:
     return;
   }
@@ -104,7 +120,7 @@ CodeEditorConfig::CodeEditorConfig(SyntaxHighlighterLanguage language)
   if (!g_file_test(config_file.c_str(), G_FILE_TEST_EXISTS))
     config_file = App::get()->get_resource_path("") + "/data/code_editor.xml";
 
-  _document = new TiXmlDocument(config_file);
+  _document = new TiXmlDocument(config_file.c_str()); // Remove c_str() as soon as we compile against libc++ on Mac.
   if (!_document->LoadFile())
   {
     log_error("Code Editor Config: cannot load configuration file \"%s\":\n\t%s (row: %d, column: %d)\n",
@@ -123,7 +139,7 @@ CodeEditorConfig::CodeEditorConfig(SyntaxHighlighterLanguage language)
   for (TiXmlElement *language_element = element->FirstChildElement(); language_element != NULL;
     language_element = language_element->NextSiblingElement())
   {
-    std::string language_name = *language_element->Attribute(std::string("name"));
+    std::string language_name = language_element->Attribute("name");
     if (language_name == lexer)
       _language_element = language_element;
     _languages.push_back(language_name);
@@ -149,7 +165,7 @@ CodeEditorConfig::CodeEditorConfig(SyntaxHighlighterLanguage language)
     for (TiXmlElement *language_element = element->FirstChildElement(); language_element != NULL;
          language_element = language_element->NextSiblingElement())
     {
-      std::string language_name = *language_element->Attribute(std::string("name"));
+      std::string language_name = language_element->Attribute("name");
       if (language_name == override_lexer)
       {
         _language_element = language_element;
@@ -228,7 +244,7 @@ void CodeEditorConfig::parse_keywords()
   for (TiXmlElement* entry = _language_element->FirstChildElement("keywords"); entry != NULL;
     entry = entry->NextSiblingElement("keywords"))
   {
-    std::string property_name = *entry->Attribute(std::string("name"));
+    std::string property_name = entry->Attribute("name");
     std::string text = collect_text(entry);
     _keywords[property_name] = text;
   }
@@ -278,6 +294,8 @@ CodeEditor::CodeEditor(void *host)
 
 CodeEditor::~CodeEditor()
 {
+  delete _find_panel;
+  
   auto_completion_cancel();
   for (std::map<int, void*>::iterator iterator = _images.begin(); iterator != _images.end(); ++iterator)
     free(iterator->second);
@@ -340,6 +358,7 @@ void CodeEditor::setup()
   setup_marker(CE_BREAKPOINT_MARKER, "editor_breakpoint");
   setup_marker(CE_BREAKPOINT_HIT_MARKER, "editor_breakpoint_hit");
   setup_marker(CE_CURRENT_LINE_MARKER, "editor_current_pos");
+  setup_marker(CE_ERROR_CONTINUE_MARKER, "editor_continue_on_error");
 
   // Other settings.
   Color color = App::get()->get_system_color(mforms::SystemColorHighlight);
@@ -633,19 +652,19 @@ void CodeEditor::load_configuration(SyntaxHighlighterLanguage language)
   {
     if (iterator->first == "usetabs")
     {
-      int int_value = atoi(iterator->second.c_str());
+      int int_value = base::atoi<int>(iterator->second, 0);
       _code_editor_impl->send_editor(this, SCI_SETUSETABS, int_value, 0);
     }
     else
       if (iterator->first == "tabwidth")
       {
-        int int_value = atoi(iterator->second.c_str());
+        int int_value = base::atoi<int>(iterator->second, 0);
         _code_editor_impl->send_editor(this, SCI_SETTABWIDTH, int_value, 0);
       }
       else
         if (iterator->first == "indentation")
         {
-          int int_value = atoi(iterator->second.c_str());
+          int int_value = base::atoi<int>(iterator->second, 0);
           _code_editor_impl->send_editor(this, SCI_SETINDENT, int_value, 0);
         }
   }
@@ -715,6 +734,8 @@ void CodeEditor::set_language(SyntaxHighlighterLanguage language)
     break;
 
   case mforms::LanguageCpp:
+  case mforms::LanguageJS:
+  case mforms::LanguageJson:
     _code_editor_impl->send_editor(this, SCI_SETLEXER, SCLEX_CPP, 0);
     break;
 
@@ -741,6 +762,11 @@ void CodeEditor::show_markup(LineMarkup markup, size_t line)
     if ((marker_mask & LineMarkupStatement) == 0)
       new_marker_mask |= LineMarkupStatement;
   }
+  if ((markup & mforms::LineMarkupErrorContinue) != 0)
+  {
+    if ((marker_mask & LineMarkupErrorContinue) == 0)
+      new_marker_mask |= LineMarkupErrorContinue;
+  }
   if ((markup & mforms::LineMarkupError) != 0)
   {
     if ((marker_mask & LineMarkupError) == 0)
@@ -783,6 +809,8 @@ void CodeEditor::remove_markup(LineMarkup markup, ssize_t line)
       _code_editor_impl->send_editor(this, SCI_MARKERDELETE, line, CE_STATEMENT_MARKER);
     if ((markup & mforms::LineMarkupError) != 0)
       _code_editor_impl->send_editor(this, SCI_MARKERDELETE, line, CE_ERROR_MARKER);
+    if ((markup & mforms::LineMarkupErrorContinue) != 0)
+      _code_editor_impl->send_editor(this, SCI_MARKERDELETE, line, CE_ERROR_CONTINUE_MARKER);
     if ((markup & mforms::LineMarkupBreakpoint) != 0)
       _code_editor_impl->send_editor(this, SCI_MARKERDELETE, line, CE_BREAKPOINT_MARKER);
     if ((markup & mforms::LineMarkupBreakpointHit) != 0)
@@ -1612,7 +1640,7 @@ void CodeEditor::auto_completion_register_images(const std::vector<std::pair<int
     {
       if (g_str_has_suffix(path.c_str(), ".png"))
       {
-        cairo_surface_t *image = cairo_image_surface_create_from_png(path.c_str());
+        cairo_surface_t *image = mdc::surface_from_png_image(path.c_str());
         if (image == NULL)
           continue;
         if (cairo_surface_status(image) != CAIRO_STATUS_SUCCESS)
