@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,12 +21,15 @@
 
 using namespace mforms;
 
+//--------------------------------------------------------------------------------------------------
+
 DockingPoint::DockingPoint(DockingPointDelegate *delegate, bool delete_on_destroy)
   : _delegate(delegate), _delete_delegate(delete_on_destroy)
 {
   _delegate->_dpoint = this;
 }
 
+//--------------------------------------------------------------------------------------------------
 
 DockingPoint::~DockingPoint()
 {
@@ -34,18 +37,14 @@ DockingPoint::~DockingPoint()
     delete _delegate;
 }
 
-
-//std::string DockingPoint::get_name()
-//{
-//  return _delegate->get_name();
-//}
-
+//--------------------------------------------------------------------------------------------------
 
 std::string DockingPoint::get_type()
 {
   return _delegate->get_type();
 }
 
+//--------------------------------------------------------------------------------------------------
 
 void DockingPoint::dock_view(AppView *view, const std::string &arg1, int arg2)
 {
@@ -53,13 +52,15 @@ void DockingPoint::dock_view(AppView *view, const std::string &arg1, int arg2)
   _delegate->dock_view(view, arg1, arg2);
 }
  
+//--------------------------------------------------------------------------------------------------
 
 bool DockingPoint::select_view(AppView *view)
 {
   return _delegate->select_view(view);
 }
 
-    
+//--------------------------------------------------------------------------------------------------
+
 void DockingPoint::undock_view(AppView *view)
 {
   view->retain();
@@ -69,65 +70,81 @@ void DockingPoint::undock_view(AppView *view)
   view->release();
 }
  
+//--------------------------------------------------------------------------------------------------
 
 void DockingPoint::set_view_title(AppView *view, const std::string &title)
 {
   _delegate->set_view_title(view, title);
 }
  
+//--------------------------------------------------------------------------------------------------
 
 std::pair<int, int> DockingPoint::get_size()
 {
   return _delegate->get_size();
 }
 
+//--------------------------------------------------------------------------------------------------
 
-bool DockingPoint::close_view(AppView *view)
+void DockingPoint::close_view_at_index(int index)
 {
-  if (view->on_close())
-  {
+  AppView *view = _delegate->view_at_index(index);
+  if (view != NULL)
     view->close();
-// the close call should do the undocking
-//    undock_view(view);
-//    if (view->is_managed())
-//      view->release();
-    return true;
-  }
-  return false;
 }
 
+//--------------------------------------------------------------------------------------------------
 
 bool DockingPoint::close_all_views()
 {
+  // Two loops here. First determine if all views accept to close before you actually close any.
+  // Otherwise we might end up with some views closed and some not if one refuses to close.
   for (int i = view_count() - 1; i >= 0; --i)
   {
-    AppView *v = view_at_index(i);
-    if (v && !close_view(v))
+    AppView *view = _delegate->view_at_index(i);
+    if (view == NULL)
+      continue;
+
+    if (!view->on_close())
       return false;
   }
+
+  for (int i = view_count() - 1; i >= 0;  --i)
+  {
+    AppView *view = _delegate->view_at_index(i);
+    if (view != NULL)
+      view->close();
+  }
+
   return true;
 }
 
+//--------------------------------------------------------------------------------------------------
 
 AppView *DockingPoint::selected_view()
 {
   return _delegate->selected_view();
 }
 
+//--------------------------------------------------------------------------------------------------
 
 int DockingPoint::view_count()
 {
   return _delegate->view_count();
 }
 
+//--------------------------------------------------------------------------------------------------
 
 AppView *DockingPoint::view_at_index(int index)
 {
   return _delegate->view_at_index(index);
 }
 
+//--------------------------------------------------------------------------------------------------
 
 void DockingPoint::view_switched()
 {
   _view_switched();
 }
+
+//--------------------------------------------------------------------------------------------------
