@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, 2013 Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,7 +30,6 @@
 namespace mforms{
 namespace gtk{
 
-static TextListColumnsModel    steps_model;
 static std::string icon_path;
 
 
@@ -133,7 +132,7 @@ WizardImpl::WizardImpl(::mforms::Wizard *wiz, ::mforms::Form* owner)
   _fwd_label.set_use_underline(true);
   _extra_btn.hide();
 
-  get_window()->set_size_request(-1, 600);
+  get_window()->set_size_request(-1, 650);
 
   if (owner)
   {
@@ -148,9 +147,11 @@ void WizardImpl::cancel(::mforms::Wizard* wiz)
 {
   WizardImpl* wiz_impl = wiz->get_data<WizardImpl>();
 
-  wiz->_cancel_slot();
-  wiz_impl->get_window()->hide();
-  Gtk::Main::quit();
+  if (wiz->_cancel_slot())
+  {
+    wiz_impl->get_window()->hide();
+    Gtk::Main::quit();
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -358,7 +359,6 @@ void WizardImpl::init()
   f->_wizard_impl.run_modal = &WizardImpl::run_modal;
   f->_wizard_impl.close = &WizardImpl::close;
 
-  f->_wizard_impl.flush_events = &WizardImpl::flush_events;
   
   f->_wizard_impl.set_content = &WizardImpl::set_content;
   f->_wizard_impl.set_heading = &WizardImpl::set_heading;
