@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,10 +17,11 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
+#include "mforms/mforms.h"
 
 using namespace mforms;
 
+//--------------------------------------------------------------------------------------------------
 
 HyperText::HyperText()
 {
@@ -29,12 +30,27 @@ HyperText::HyperText()
   _hypertext_impl->create(this);
 }
 
+//--------------------------------------------------------------------------------------------------
+
 void HyperText::handle_url_click(const std::string &url)
 {
   _url_click_signal(url);
 }
 
+//--------------------------------------------------------------------------------------------------
+
 void HyperText::set_markup_text(const std::string &text)
 {
   _hypertext_impl->set_markup_text(this, text);
 }
+
+//--------------------------------------------------------------------------------------------------
+
+void HyperText::set_padding(int left, int top, int right, int bottom)
+{
+  set_layout_dirty(true);
+  if (_view_impl->set_padding)
+    (*_view_impl->set_padding)(this, left, top, right, bottom);
+}
+
+//--------------------------------------------------------------------------------------------------
