@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include "mforms/mforms.h"
 
 using namespace mforms;
@@ -37,6 +35,12 @@ void ImageBox::set_image(const std::string &file)
 }
 
 
+void ImageBox::set_image_data(const char *data, size_t length)
+{
+  _imagebox_impl->set_image_data(this, data, length);
+}
+
+
 void ImageBox::set_scale_contents(bool flag)
 {
   _imagebox_impl->set_scale_contents(this, flag);
