@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,11 +16,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-#ifndef _MFORMS_BASE_H_
-#define _MFORMS_BASE_H_
+
+#pragma once
 
 #include <string>
 #include <list>
+#include "base/threading.h"
 
 #ifdef _WIN32
 # ifdef DECL_MFORMS_EXPORT
@@ -32,10 +33,6 @@
 # define MFORMS_EXPORT
 #endif
 
-#ifndef _WIN32
-#define __stdcall 
-#endif
-
 #if defined(__APPLE__) && !defined(MFORMS_STUB)
 #ifdef nil
 #undef nil
@@ -54,11 +51,13 @@ namespace mforms {
     Object *retain();
     void release();    
     virtual void set_managed();    
-    void set_release_on_add();    
+    void set_release_on_add(bool flag = true);    
     bool is_managed();    
     bool release_on_add();
 
-    int retain_count();
+    // Below code is used for debugging
+    inline base::refcount_t retain_count() const { return _refcount; }
+
     void set_destroying();
     bool is_destroying();
 
@@ -92,7 +91,10 @@ namespace mforms {
     void *_data;
     FreeDataFn _data_free_fn;
 #endif // !__APPLE__
-    int _refcount;
+    volatile mutable base::refcount_t _refcount;
+    //We use only ptr's in mforms.
+    Object(Object const& o) { throw std::logic_error("Copy c-tor unsupported in mforms::Object"); }
+    Object& operator= (Object const& o) { throw std::logic_error("Assignment operator not supported in mforms::Object"); return *this; }
   protected:
     bool _managed;
     bool _release_on_add;
@@ -115,4 +117,3 @@ namespace mforms {
 };
 
 #endif  // !DOXYGEN_SHOULD_SKIP_THIS
-#endif
