@@ -17,8 +17,7 @@
  * 02110-1301  USA
  */
 
-#ifndef _MFORMS_CHECKBOX_H_
-#define _MFORMS_CHECKBOX_H_
+#pragma once
 
 #include <mforms/base.h>
 #include <mforms/button.h>
@@ -31,9 +30,9 @@ namespace mforms {
 #ifndef SWIG
   struct CheckBoxImplPtrs
   {
-    bool (__stdcall *create)(CheckBox *self, bool square);
-    void (__stdcall *set_active)(CheckBox *self, bool flag);
-    bool (__stdcall *get_active)(CheckBox *self);
+    bool (*create)(CheckBox *self, bool square);
+    void (*set_active)(CheckBox *self, bool flag);
+    bool (*get_active)(CheckBox *self);
   };
 #endif
 #endif
@@ -59,5 +58,3 @@ namespace mforms {
     CheckBoxImplPtrs *_checkbox_impl;
   };
 };
-
-#endif
