@@ -17,8 +17,7 @@
  * 02110-1301  USA
  */
 
-#ifndef _MFORMS_MENUBAR_H_
-#define _MFORMS_MENUBAR_H_
+#pragma once
 
 #include "base/trackable.h"
 #include <mforms/box.h>
@@ -27,9 +26,6 @@
 
 namespace mforms {
   class MenuBase;
-}
-
-namespace mforms {
   class MenuItem;
   class MenuBar;
   class View;
@@ -61,6 +57,8 @@ namespace mforms {
 
     void (*insert_item)(MenuBase *menu, int index, MenuItem *item);
     void (*remove_item)(MenuBase *menu, MenuItem *item); // NULL item to remove all
+
+    void (*popup_at)(ContextMenu *menu, View *owner, base::Point location);
   };
 #endif
 #endif
@@ -89,6 +87,7 @@ namespace mforms {
 
 #ifndef SWIG
     MenuItem *add_item_with_title(const std::string &title, boost::function<void ()> action, const std::string &name="");
+    MenuItem *add_check_item_with_title(const std::string &title, boost::function<void ()> action, const std::string &name="");
 #endif
     MenuItem *add_separator();
 
@@ -122,6 +121,7 @@ namespace mforms {
     std::string get_title();
     
     void set_shortcut(const std::string &shortcut);
+    std::string get_shortcut() { return _shortcut; }
         
     void set_checked(bool flag);
     bool get_checked();
@@ -142,6 +142,7 @@ namespace mforms {
 
   private:
     std::string _name;
+    std::string _shortcut;
     boost::function<bool ()> _validate;
     boost::signals2::signal<void ()> _clicked_signal;
     MenuItemType _type;
@@ -183,9 +184,10 @@ namespace mforms {
     void will_show();
     void will_show_submenu_from(MenuItem *item);
 
+    void popup_at(View *owner, base::Point location);
+
   private:
     boost::signals2::signal<void (MenuItem*)> _signal_will_show;
   };
 };
 
-#endif
