@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,9 +16,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-#ifndef _MFORMS_H_
-#define _MFORMS_H_
 
+#pragma once
 
 /*! \mainpage MForms - mini forms library
  * 
@@ -34,18 +33,18 @@
  * with simple to moderately complex GUIs.
  * 
  * \section Layouting
- * Because each platform has widget of different sizes, with different layout characteristics,
+ * Because each platform has widgets of different sizes, with different layout characteristics,
  * using absolute coordinates and sizes for layouting would not work very well. A dialog written
  * in Windows containing text and a couple of buttons could look fine in the OS where it was written in, 
- * but would look cluttered and probably too small Mac OS X. To workaround that, MForms uses dynamic 
+ * but would look cluttered and probably too small on Mac OS X. To work around that, MForms uses dynamic 
  * layouting containers instead of static coordinates to place and size controls, similar to what GTK uses.
  * Basically, there are several types of containers where you can place one or more controls inside, each 
- * having a specific layouting behaviour.
+ * having a specific layouting behavior.
  * \li Form - A top level window which can contain a single control (usually another container). 
  * The window will be sized automatically to fit its contents,  but can also be set to a size by hand.
  * \li Box - A container that can be filled with one or more controls in a vertical or horizontal layout. 
  * Each child control can be set to either use only the minimal space required by it or to fill up all space available 
- * to the box in the direction of the layout. In the direction perpendicular to the layout (ie vertical 
+ * in the box in the direction of the layout. In the direction perpendicular to the layout (ie vertical 
  * in a horizontal box and vice-versa), the smallest possible size that can accommodate all child controls
  * will be applied to all its contents.
  * \li Table - A container that can organize one or more controls in a grid. You may set the number of rows
@@ -94,8 +93,10 @@
 #include <mforms/popover.h>
 #include <mforms/fs_object_selector.h>
 #include <mforms/simpleform.h>
-#include <mforms/grid.h>
 #include <mforms/find_panel.h>
+#include <mforms/native.h>
+#include <mforms/canvas.h>
+#include <mforms/record_grid.h>
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 namespace mforms
@@ -133,13 +134,14 @@ namespace mforms
     CodeEditorImplPtrs _code_editor_impl;
     MenuItemImplPtrs _menu_item_impl;
     ToolBarImplPtrs _tool_bar_impl;
-    GridImplPtrs _grid_impl;
     HyperTextImplPtrs _hypertext_impl;
     PopoverImplPtrs _popover_impl;
-    
+    CanvasImplPtrs _canvas_impl;
+
     AppImplPtrs _app_impl;
     AppViewImplPtrs _app_view_impl;
     UtilitiesImplPtrs _utilities_impl;
+  public:
     
     TreeNodeViewImplPtrs _treenodeview_impl;
     FindPanelImplPtrs _findpanel_impl;
@@ -158,5 +160,3 @@ namespace mforms
 };
 
 #endif
-
-#endif
