@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,12 +16,11 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-#ifndef _MFORMS_PANEL_H_
-#define _MFORMS_PANEL_H_
+
+#pragma once
 
 #include <mforms/container.h>
 
-
 namespace mforms {
   enum PanelType {
     // TODO: re-arrange names so that the all begin with Panel.., as this sorts much better
@@ -32,7 +31,6 @@ namespace mforms {
     LineBorderPanel,    // container with a solid line border
     TitledBoxPanel,     // native grouping box with a title with border
     TitledGroupPanel,   // native grouping container with a title (may have no border) 
-    CheckBoxTitlePanel, // container with 
     FilledHeaderPanel,  // Just like a filled panel but additionally has a header bar with a title.
     StyledHeaderPanel   // Panel which has top round corners for win, rect + gradient fill for osx, plain filled rect for linux
   };
@@ -43,15 +41,15 @@ namespace mforms {
 #ifndef SWIG
   struct MFORMS_EXPORT PanelImplPtrs
   {
-    bool (__stdcall *create)(Panel*, PanelType type);
-    void (__stdcall *set_back_color)(Panel*, const std::string &);
-    void (__stdcall *set_title)(Panel*, const std::string&);
+    bool (*create)(Panel*, PanelType type);
+    void (*set_back_color)(Panel*, const std::string &);
+    void (*set_title)(Panel*, const std::string&);
 
-    void (__stdcall *set_active)(Panel*, bool);
-    bool (__stdcall *get_active)(Panel*);
+    void (*set_active)(Panel*, bool);
+    bool (*get_active)(Panel*);
 
-    void (__stdcall *add)(Panel *self,View*);
-    void (__stdcall *remove)(Panel *self,View*);
+    void (*add)(Panel *self,View*);
+    void (*remove)(Panel *self,View*);
   };
 #endif
 #endif
@@ -69,7 +67,6 @@ namespace mforms {
      LineBorderPanel     container with a solid line border
      TitledBoxPanel      native grouping box with a title with border
      TitledGroupPanel    native grouping container with a title (may have no border) 
-     CheckBoxTitlePanel  container with checkbox
      */     
     Panel(PanelType type);
 
@@ -88,17 +85,7 @@ namespace mforms {
     /** Removes the content view of the panel. */
     virtual void remove(View *subview);
 
-#ifndef SWIG
-    /** Signal emitted when checkbox is toggled for CheckBoxTitlePanel */
-    boost::signals2::signal<void ()>* signal_toggled() { return &_signal_toggled; }    
-#ifndef DOXYGEN_SHOULD_SKIP_THIS  
-    void check_toggled();
-#endif
-#endif
   protected:
-    boost::signals2::signal<void ()> _signal_toggled;
     PanelImplPtrs *_panel_impl;
   };
 };
-
-#endif
