@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -188,10 +188,13 @@ namespace mforms {
     virtual TreeNodeRef get_child(int index) const = 0;
     virtual int get_child_index(TreeNodeRef child) const = 0;
     virtual TreeNodeRef get_parent() const = 0;
-    virtual TreeNodeRef find_child_with_tag(const std::string &tag); // this will search the subnodes sequentially
+    virtual TreeNodeRef find_child_with_tag(const std::string &tag); // This will search the sub nodes sequentially.
     virtual TreeNodeRef previous_sibling() const = 0;
     virtual TreeNodeRef next_sibling() const = 0;
 
+    // Moves this node to a different place relative to the given node (which must be in the same tree).
+    virtual void move_node(TreeNodeRef node, bool before) = 0;
+
     // This is a very special function and I'm not sure it should be here.
     // It creates nodes out of the collection's captions and adds the same child nodes to each of those nodes
     // as given in the children member. This works iteratively.
@@ -203,6 +206,7 @@ namespace mforms {
 
     // Primitive check. Use TreeNodeView::can_expand() instead for potentially more sophisticated checks.
     virtual bool can_expand() { return count() > 0; };
+    virtual void toggle();
 
     virtual void set_tag(const std::string &tag) = 0;
     virtual std::string get_tag() const = 0;
