@@ -16,8 +16,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-#ifndef _MFORMS_WIZARD_H_
-#define _MFORMS_WIZARD_H_
+
+#pragma once
 
 #include <mforms/form.h>
 #include <vector>
@@ -120,6 +120,3 @@ namespace mforms {
     boost::signals2::signal<void ()> _extra_signal;
   };
 };
-
-#endif
-
