@@ -43,7 +43,9 @@ typedef int ssize_t;
 #include <sstream>
 #include <vector>
 #include <stack>
-#include <algorithm>
+#include <iosfwd>
+#include <fstream>
+
 #include <errno.h>
 #include <cstdlib>
 
