@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -186,7 +186,7 @@ void TreeNodeWrapper::move_child(mforms::TreeNodeRef node, int new_index)
   if (i == _children.end())
     return;
 
-  int old_index = i - _children.begin();
+  int old_index = int(i - _children.begin());
   if (old_index == new_index)
     return;
 
@@ -284,6 +284,10 @@ void TreeNodeWrapper::remove_children()
     mforms::TreeNode::remove_children();
 }
 
+void TreeNodeWrapper::move_node(mforms::TreeNodeRef node, bool before)
+{
+}
+
 void TreeNodeWrapper::expand()
 {
   _expanded = true;
@@ -299,6 +303,11 @@ bool TreeNodeWrapper::is_expanded()
   return _expanded;
 }
 
+void TreeNodeWrapper::toggle()
+{
+  _expanded = !_expanded;
+}
+
 void TreeNodeWrapper::set_tag(const std::string &tag)
 {
   _tag = tag;
