@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -45,9 +45,6 @@ class AppWrapper : public ObjectWrapper
   }
   static void exit_event_loop(App *app, int result) {}
     
-  static void begin_thread_loop() {}
-  static void end_thread_loop() {}
-
   static base::Color get_system_color(SystemColor type) 
   {
     return base::Color();
