@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,18 +25,18 @@
 
 namespace mforms {
 namespace stub {
-  class ObjectImpl
+  class ObjectWrapper
   {
   protected:
     ::mforms::Object *owner;
     
-    ObjectImpl(::mforms::Object *object)
+    ObjectWrapper(::mforms::Object *object)
       : owner(object)
     {
       object->set_data(this);
     }
 
-    virtual ~ObjectImpl()
+    virtual ~ObjectWrapper()
     {
       puts("FREE OBJECT");
       //TODO: Check if we need to free memory here?
