@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,29 +24,29 @@
 namespace mforms {
 namespace stub {
 
-class CheckBoxImpl : public ButtonImpl
+class CheckBoxWrapper : public ButtonWrapper
 {
  protected:
-  static bool __stdcall create(::mforms::CheckBox *self, bool square)
+  static bool create(::mforms::CheckBox *self, bool square)
   {
     return true;
   }
 
-  static void __stdcall set_active(::mforms::CheckBox *self, bool flag)
+  static void set_active(::mforms::CheckBox *self, bool flag)
   {
   }
 
-  static bool __stdcall get_active(::mforms::CheckBox *self)
+  static bool get_active(::mforms::CheckBox *self)
   {
     return false;
   }
 
-  CheckBoxImpl(::mforms::CheckBox *self)
-    : ButtonImpl(self)
+  CheckBoxWrapper(::mforms::CheckBox *self)
+    : ButtonWrapper(self)
   {
   }
 
-  static void __stdcall callback(::mforms::CheckBox* self)
+  static void callback(::mforms::CheckBox* self)
   {
   }
 
@@ -55,9 +55,9 @@ class CheckBoxImpl : public ButtonImpl
   {
     ::mforms::ControlFactory *f= ::mforms::ControlFactory::get_instance();
 
-    f->_checkbox_impl.create     = &CheckBoxImpl::create;
-    f->_checkbox_impl.set_active = &CheckBoxImpl::set_active;
-    f->_checkbox_impl.get_active = &CheckBoxImpl::get_active;
+    f->_checkbox_impl.create     = &CheckBoxWrapper::create;
+    f->_checkbox_impl.set_active = &CheckBoxWrapper::set_active;
+    f->_checkbox_impl.get_active = &CheckBoxWrapper::get_active;
   }
 };
 
