@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,11 +23,11 @@
 
 namespace mforms { namespace stub
 {  
-  class ContainerImpl : public ViewImpl
+  class ContainerWrapper : public ViewWrapper
   {
   protected:
-    ContainerImpl(::mforms::View *self)
-      : ViewImpl(self)
+    ContainerWrapper(::mforms::View *self)
+      : ViewWrapper(self)
     {
     }
 
