@@ -26,15 +26,15 @@ namespace mforms {
 
 namespace stub {
 
-class DrawBoxImpl : public ViewImpl
+class DrawBoxWrapper : public ViewWrapper
 {
 protected:
-  DrawBoxImpl(::mforms::DrawBox *self);
-  static bool __stdcall create(mforms::DrawBox *self);
-  static void __stdcall set_needs_repaint(mforms::DrawBox *self);
-  static void __stdcall add(mforms::DrawBox *, mforms::View *, mforms::Alignment alignment);
-  static void __stdcall remove(mforms::DrawBox *, mforms::View *);
-  static void __stdcall move(mforms::DrawBox *, mforms::View *, int x, int y);
+  DrawBoxWrapper(::mforms::DrawBox *self);
+  static bool create(mforms::DrawBox *self);
+  static void set_needs_repaint(mforms::DrawBox *self);
+  static void add(mforms::DrawBox *, mforms::View *, mforms::Alignment alignment);
+  static void remove(mforms::DrawBox *, mforms::View *);
+  static void move(mforms::DrawBox *, mforms::View *, int x, int y);
 
  public:
   static void init();
