@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,19 +25,19 @@
 namespace mforms {
 namespace stub
 {
-  class MenuImpl : public ObjectImpl
+  class MenuWrapper : public ObjectWrapper
   {
   public:
-    MenuImpl(Menu* self);
+    MenuWrapper(Menu* self);
 
-    static bool __stdcall create(Menu* self);
-    static void __stdcall remove_item(Menu* self, int i);
-    static int __stdcall add_item(Menu* self, const std::string &caption, const std::string &action);
-    static int __stdcall add_separator(Menu* self);
-    static int __stdcall add_submenu(Menu* self, const std::string &caption, Menu *submenu);
-    static void __stdcall set_item_enabled(Menu* self, int i, bool flag);
-    static void __stdcall popup_at(Menu* self, Object *control, int x, int y);
-    static void __stdcall clear(Menu *self);
+    static bool create(Menu* self);
+    static void remove_item(Menu* self, int i);
+    static int add_item(Menu* self, const std::string &caption, const std::string &action);
+    static int add_separator(Menu* self);
+    static int add_submenu(Menu* self, const std::string &caption, Menu *submenu);
+    static void set_item_enabled(Menu* self, int i, bool flag);
+    static void popup_at(Menu* self, Object *control, int x, int y);
+    static void clear(Menu *self);
 
    public:
     static void init();
