@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,11 +17,9 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
-#include "mforms/mforms.h"
 #include "wf_mforms.h"
 
+#include "wf_base.h"
 #include "wf_view.h"
 #include "wf_button.h"
 #include "wf_form.h"
@@ -52,9 +50,11 @@
 #include "wf_code_editor.h"
 #include "wf_hypertext.h"
 #include "wf_popover.h"
-#include "wf_grid.h"
 #include "wf_treenodeview.h"
 #include "wf_find_panel.h"
+#include "wf_native.h"
+#include "wf_canvas.h"
+#include "wf_record_grid_view.h"
 
 #include "wf_appview.h"
 #include "wf_app.h"
@@ -75,42 +75,41 @@ Manager::Manager()
 
   base::Logger::log(base::Logger::LogInfo, DOMAIN_MFORMS_WRAPPER, "Initializing mforms wrapper\n");
 
-  AppImpl::init(this);
-  ViewImpl::init(this);
-  FormImpl::init(this);
-  ButtonImpl::init(this);
-  CheckBoxImpl::init(this);
-  TextEntryImpl::init(this);
-  TextBoxImpl::init(this);
-  LabelImpl::init(this);
-  SelectorImpl::init(this);
-  PanelImpl::init(this);
-  TabViewImpl::init(this);
-  BoxImpl::init(this);
-  ProgressBarImpl::init(this);
-  ImageBoxImpl::init(this);
-  RadioButtonImpl::init(this);
-  TableImpl::init(this);
-  FileChooserImpl::init(this);
-  ListBoxImpl::init(this);
-  WizardImpl::init(this);
-  ScrollPanelImpl::init(this);
-  UtilitiesImpl::init(this);
-  DrawBoxImpl::init(this);
-  AppViewImpl::init(this);
-  SplitterImpl::init(this);
-  WebBrowserImpl::init(this);
-  PopupImpl::init(this);
-  MenuImpl::init(this);
-  MenuBarImpl::init(this);
-  ToolBarImpl::init(this);
-  CodeEditorImpl::init(this);
-  HyperTextImpl::init(this);
-  PopoverImpl::init(this);
-  GridImpl::init(this);
-  TreeNodeViewImpl::init(this);
-  FindPanelImpl::init(this);
-
+  ViewWrapper::init();
+  LabelWrapper::init();
+  BoxWrapper::init();
+  MenuBarWrapper::init();
+  UtilitiesWrapper::init();
+  AppWrapper::init();
+  ToolBarWrapper::init();
+  AppViewWrapper::init();
+  FormWrapper::init();
+  ButtonWrapper::init();
+  CheckBoxWrapper::init();
+  TextEntryWrapper::init();
+  TextBoxWrapper::init();
+  SelectorWrapper::init();
+  PanelWrapper::init();
+  TabViewWrapper::init();
+  ProgressBarWrapper::init();
+  ImageBoxWrapper::init();
+  RadioButtonWrapper::init();
+  TableWrapper::init();
+  FileChooserWrapper::init();
+  ListBoxWrapper::init();
+  WizardWrapper::init();
+  ScrollPanelWrapper::init();
+  DrawBoxWrapper::init();
+  SplitterWrapper::init();
+  WebBrowserWrapper::init();
+  PopupWrapper::init();
+  MenuWrapper::init();
+  FindPanelWrapper::init();
+  CodeEditorWrapper::init();
+  HyperTextWrapper::init();
+  PopoverWrapper::init();
+  TreeNodeViewWrapper::init();
+  CanvasWrapper::init();
 //  mforms::ControlFactory::get_instance()->check_impl();
 }
 
@@ -118,8 +117,6 @@ Manager::Manager()
 
 Manager::~Manager()
 {
-  callbacks.Clear();
-
   base::Logger::log(base::Logger::LogInfo, DOMAIN_MFORMS_WRAPPER, "Shutting down mforms wrapper\n");
   /* Doesn't really work since on app shutdown many objects are just not regularly freed.
   base::Logger::log(base::Logger::LogDebug2, DOMAIN_MFORMS_WRAPPER,
