@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -298,6 +298,7 @@ public:
   bool alternateRowColors;
   bool canReorderRows;
   bool canBeDragSource;
+  bool headerRightClick;
   Drawing::Rectangle dragBox;
   int freezeCount;
   SortOrder currentSortOrder;
@@ -320,6 +321,7 @@ public:
     canBeDragSource = false;
     canReorderRows = false;
     dragBox = Rectangle::Empty;
+    headerRightClick = false;
 
     hotNode = nullptr;
     overlayInfo = gcnew List<NodeOverlay^>();
@@ -576,7 +578,6 @@ public:
     {
       mforms::TreeNodeView *backend = TreeNodeViewWrapper::GetBackend<mforms::TreeNodeView>(this);
       TreeNodeViewWrapper *wrapper = backend->get_data<TreeNodeViewWrapper>();
-      //int row = backend->row_for_node(mforms::TreeNodeRef(new TreeNodeWrapper(wrapper, args->Node)));
       int column = args->Control->ParentColumn->Index;
       backend->node_activated(mforms::TreeNodeRef(new TreeNodeWrapper(wrapper, args->Node)), column);
     }
@@ -588,6 +589,10 @@ public:
   {
     __super::OnColumnClicked(column, button);
 
+	// Stores the clicked column...
+	mforms::TreeNodeView *backend = TreeNodeViewWrapper::GetBackend<mforms::TreeNodeView>(this);
+	backend->header_clicked(column->Index);
+
     switch (button)
     {
     case ::MouseButtons::Left:
@@ -623,26 +628,8 @@ public:
       break;
 
     case ::MouseButtons::Right:
-      // Update the associated header context menu.
-      mforms::TreeNodeView *backend = TreeNodeViewWrapper::GetBackend<mforms::TreeNodeView>(this);
-      mforms::ContextMenu *header_menu = backend->get_header_menu();
-      if (header_menu != NULL)
-      {
-        ::ContextMenuStrip ^menu = MenuBarWrapper::GetManagedObject<::ContextMenuStrip>(header_menu);
-        if (menu != ContextMenuStrip)
-        {
-          ContextMenuStrip = menu;
-          if (Conversions::UseWin8Drawing())
-            ContextMenuStrip->Renderer = gcnew Win8MenuStripRenderer();
-          else
-            ContextMenuStrip->Renderer = gcnew TransparentMenuStripRenderer();
-
-          backend->header_clicked(column->Index);
-          header_menu->will_show();
-        }
-      }
-      else
-        ContextMenuStrip = nullptr;
+      // Turns ON flag indicating the right click occurred on the table header
+      headerRightClick = true;
       break;
     }
 
@@ -741,9 +728,18 @@ public:
       {
         // Update the associated standard context menu.
         mforms::TreeNodeView *backend = TreeNodeViewWrapper::GetBackend<mforms::TreeNodeView>(this);
-        if (backend->get_context_menu())
+        mforms::ContextMenu *context_menu = nullptr;
+
+        // If the click occurred on the table header and there's aheader context menu
+        // Uses it, if not uses the regulat context menu.
+        if (headerRightClick && backend->get_header_menu())
+          context_menu = backend->get_header_menu();
+        else
+          context_menu = backend->get_context_menu();
+        
+        if (context_menu)
         {
-          ToolStrip ^menu = MenuBarWrapper::GetManagedObject<ToolStrip>(backend->get_context_menu());
+          ToolStrip ^menu = MenuBarWrapper::GetManagedObject<ToolStrip>(context_menu);
           if (menu != ContextMenuStrip)
           {
             ContextMenuStrip = (Windows::Forms::ContextMenuStrip^)menu;
@@ -751,11 +747,14 @@ public:
               ContextMenuStrip->Renderer = gcnew Win8MenuStripRenderer();
             else
               ContextMenuStrip->Renderer = gcnew TransparentMenuStripRenderer();
-            backend->get_context_menu()->will_show();
+            
+            context_menu->will_show();
           }
         }
         else
           ContextMenuStrip = nullptr;
+
+        headerRightClick = false;
         break;
       }
     }
