@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -147,8 +147,8 @@ public:
   {
     std::cout << std::string(level, ' ');
     std::cout << get_type_name();
-    std::cout << " new:" << _v.repr();
-    std::cout << " old:" << _old.repr()<< std::endl;
+    std::cout << " new:" << _v.debugDescription();
+    std::cout << " old:" << _old.debugDescription() << std::endl;
   }
 };
 
