@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,21 +16,23 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
+
 #ifndef _GRT_LIST_DIFF_H
 #define _GRT_LIST_DIFF_H
+
 #include "grtpp_util.h"
 
 namespace grt
 {
 
 class BaseListRef;
-class DiffChange;
+class MultiChange;
 struct Omf;
 
 class GrtListDiff
 {
 public:
-  static boost::shared_ptr<DiffChange> diff(const BaseListRef &source, const BaseListRef &target, const Omf *omf);
+  static boost::shared_ptr<MultiChange> diff(const BaseListRef &source, const BaseListRef &target, const Omf *omf);
 };
 
 }
