@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1158,7 +1158,7 @@ static void dump_value(const grt::ValueRef &value, int level, bool skip_spacing)
     }
 
     default:
-      printf("%*s%s", level, "  ", value.repr().c_str());
+      printf("%*s%s", level, "  ", value.debugDescription().c_str());
       break;
   }
 }
