@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -163,7 +163,8 @@ namespace grt {
           delete this;
       }
 
-      virtual std::string repr() const = 0;
+      virtual std::string debugDescription(const std::string &indentation = "") const = 0;
+      virtual std::string toString() const = 0;
 
       inline base::refcount_t refcount() const
       {
@@ -202,7 +203,8 @@ namespace grt {
 
       static Type static_type() { return IntegerType; }
       virtual Type get_type() const { return IntegerType; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
       
       inline operator storage_type () const { return _value; }
       inline storage_type operator*() const { return _value; }
@@ -227,7 +229,8 @@ namespace grt {
 
       static Type static_type() { return DoubleType; }
       virtual Type get_type() const { return DoubleType; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
       
       inline operator storage_type () const { return _value; }
       inline storage_type operator*() const { return _value; }
@@ -252,7 +255,8 @@ namespace grt {
 
       static Type static_type() { return StringType; }
       virtual Type get_type() const { return StringType; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
       
       inline operator storage_type () const { return _value; }
       inline const storage_type& operator*() const { return _value; }
@@ -287,7 +291,8 @@ namespace grt {
       inline const SimpleTypeSpec &content_type_spec() const { return _content_type; }
       inline Type content_type() const { return _content_type.type; }
       inline const std::string &content_class_name() const { return _content_type.object_class; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
 
       inline const ValueRef &get(size_t index) const
       {
@@ -391,7 +396,8 @@ namespace grt {
 
       static Type static_type() { return DictType; }
       virtual Type get_type() const { return DictType; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
 
       Type content_type() const { return _content_type.type; }
       const std::string &content_class_name() const { return _content_type.object_class; }
@@ -401,9 +407,6 @@ namespace grt {
       const_iterator begin() const;
       const_iterator end() const;
       
-      //iterator begin() { return _content.begin(); }
-      //iterator end() { return _content.end(); }
-      
       bool has_key(const std::string &key) const;
       ValueRef get(const std::string &key) const;
       virtual void set(const std::string &key, const ValueRef &value);
@@ -468,7 +471,8 @@ namespace grt {
 
       static Type static_type() { return ObjectType; }
       virtual Type get_type() const { return ObjectType; }
-      virtual std::string repr() const;
+      virtual std::string debugDescription(const std::string &indentation = "") const;
+      virtual std::string toString() const;
 
       bool is_instance(MetaClass *gclass) const;
       bool is_instance(const std::string &name) const;
