@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,3 +32,7 @@
 #include <glib.h>
 
 #include "grts/structs.h"
+
+#include <iosfwd>
+#include <fstream>
+#include <sstream>
