@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "tut_stdafx.h"
-
 #include "testgrt.h"
 #include "grt_test_utility.h"
 #include "structs.test.h"
@@ -92,7 +90,7 @@ TEST_FUNCTION(10)
 
   ensure("copy", publisher_copy.id() != publisher.id());
   ensure_equals("copy name", *publisher_copy->name(), *publisher->name());
-  ensure_equals("copy book list", publisher_copy->books().count(), 1);
+  ensure_equals("copy book list", publisher_copy->books().count(), 1U);
   ensure_equals("copy book list contents", publisher_copy->books()[0].id(), book.id());
   // The bug was that a shallow_copy would modify the referenced objects that would back-reference the copied object
   ensure_equals("don't modify owned objects Bug #17324160", book->publisher().id(), publisher.id());
