@@ -113,7 +113,7 @@ class DatabaseObjectSelector(mforms.Box):
             text_box = mforms.Box(False)
             group_selector = mforms.newCheckBox()
             group_selector.set_text(self.ui_settings[group]['group_label'])
-            group_selector.set_active(self.ui_settings[group]['group_selected'])
+            group_selector.set_active(bool(self.ui_settings[group]['group_selected']))
             group_selector.add_clicked_callback(functools.partial(self.group_checkbox_clicked, group=group))
             text_box.add(group_selector, False)
             info_label = mforms.newLabel(self.ui_settings[group]['status_text'] % {'total': len(group_objects), 
@@ -126,7 +126,7 @@ class DatabaseObjectSelector(mforms.Box):
             self.ui_settings[group]['_showing_details'] = show_details
             filter_button = mforms.newButton()
             filter_button.set_text('Hide Selection' if show_details else 'Show Selection')
-            filter_button.set_enabled(self.ui_settings[group]['group_selected'])
+            filter_button.set_enabled(bool(self.ui_settings[group]['group_selected']))
             filter_button.add_clicked_callback(functools.partial(self.filter_button_clicked, group=group))
             header_box.add_end(filter_button, False, True)
             
@@ -134,25 +134,27 @@ class DatabaseObjectSelector(mforms.Box):
             
             # The invisible stuff:
             if len(group_objects) > 0:
-                filter_container = mforms.newTable()
-                filter_container.set_row_count(2)
-                filter_container.set_column_count(3)
-                filter_container.set_row_spacing(8)
-                filter_container.set_column_spacing(8)
-                
+                box = mforms.newBox(True)
                 search_entry = mforms.newTextEntry(mforms.SearchEntry)
                 search_entry.set_placeholder_text("Filter objects (wildcards chars * and ? are allowed)")
                 search_entry.add_changed_callback(functools.partial(self.search_entry_changed, group=group))
-                filter_container.add(search_entry, 0, 1, 0, 1)
+                box.add(search_entry, False, True)
+                group_box.add(box, False, True)
+                search_entry.set_size(350, -1)
+
+                filter_container = mforms.newBox(True)
+                filter_container.set_spacing(8)
 
                 available_list = mforms.newTreeNodeView(mforms.TreeFlatList)
-                available_list.add_column(mforms.IconColumnType, 'Available Objects', 200, False)
+                available_list.add_column(mforms.IconColumnType, 'Available Objects', 300, False)
                 available_list.end_columns()
                 available_list.set_selection_mode(mforms.TreeSelectMultiple)
                 available_list.set_allow_sorting(False)
-                filter_container.add(available_list, 0, 1, 1, 2)
+                filter_container.add(available_list, True, True)
 
                 control_box = mforms.newBox(False)
+                control_box.set_padding(0, 30, 0, 30)
+                control_box.set_spacing(4)
                 add_button = mforms.newButton()
                 add_button.set_text('>')
                 add_button.enable_internal_padding(False)
@@ -173,12 +175,11 @@ class DatabaseObjectSelector(mforms.Box):
                 remove_all_button.enable_internal_padding(False)
                 remove_all_button.add_clicked_callback(functools.partial(self.move_button_clicked, group=group, operation='remove_all'))
                 control_box.add(remove_all_button, False)
-                filter_container.add(control_box, 1, 2, 1, 2, mforms.VExpandFlag)
+                filter_container.add(control_box, False, False)
 
 
                 selected_list = mforms.newTreeNodeView(mforms.TreeFlatList)
-                selected_list.set_size(-1, 200)
-                selected_list.add_column(mforms.IconColumnType, 'Objects to Migrate', 200, False)
+                selected_list.add_column(mforms.IconColumnType, 'Objects to Migrate', 300, False)
                 selected_list.end_columns()
                 selected_list.set_selection_mode(mforms.TreeSelectMultiple)
                 selected_list.set_allow_sorting(False)
@@ -186,11 +187,11 @@ class DatabaseObjectSelector(mforms.Box):
                     node = selected_list.add_node()
                     node.set_icon_path(0, self.ui_settings[group]['small_icon'])
                     node.set_string(0, item)
-                filter_container.add(selected_list, 2, 3, 1, 2)
+                filter_container.add(selected_list, True, True)
                 
                 group_box.add(filter_container, True, True)
                 
-                filter_container.show(show_details)
+                filter_container.show(bool(show_details))
             
                 self.ui[group].update( {
                     'filter_container': filter_container,
@@ -220,7 +221,7 @@ class DatabaseObjectSelector(mforms.Box):
         '''Shows/hides the details of the selections for the group'''
 
         if 'filter_container' in self.ui[group]:  # The group is not empty
-            self.ui[group]['filter_container'].show(show_details)
+            self.ui[group]['filter_container'].show(bool(show_details))
         self.ui[group]['filter_button'].set_text('Hide Selection' if show_details else 'Show Selection')
         self.ui_settings[group]['_showing_details'] = show_details
         self.relayout()
@@ -258,8 +259,8 @@ class DatabaseObjectSelector(mforms.Box):
         available_list.thaw_refresh()
 
     def group_checkbox_clicked(self, group):
-        is_active = self.ui[group]['group_selector'].get_active()
-        has_elements = self.ui[group]['has_elements']
+        is_active = bool(self.ui[group]['group_selector'].get_active())
+        has_elements = bool(self.ui[group]['has_elements'])
         should_expand = is_active and self.ui_settings[group]['show_details']
         self._show_selection(group, should_expand)
         self.ui[group]['filter_button'].set_enabled(is_active and has_elements)
