@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -85,6 +85,12 @@ public:
                                               "You must call closeResult() on the returned id once done with it.",
                                               "conn_id the connection id\n"
                                               "query the statement/query to be executed"),
+                  DECLARE_MODULE_FUNCTION_DOC(DbMySQLQueryImpl::executeQueryMultiResult,
+                                              "Executes a query in the server, such as SELECT statements and stored procedures.\n"
+                                              "Returns a list with all the result IDs of the generated resultsets. Use the result* functions to get the results.\n"
+                                              "You must call closeResult() on the returned id once done with it.",
+                                              "conn_id the connection id\n"
+                                              "query the statement/query to be executed"),
                   DECLARE_MODULE_FUNCTION_DOC(DbMySQLQueryImpl::resultNumRows,
                                               "Gets the number of rows returned by the last executeQuery() call.",
                                               "result_id the resultset identifier, returned by executeQuery()"),
@@ -181,7 +187,10 @@ public:
 
   // returns result-id or -1 for error
   int executeQuery(int conn, const std::string &query);
-
+  
+  //  returns a list with all the result ids. On error will return an empty list
+  grt::IntegerListRef executeQueryMultiResult(int conn, const std::string &query);
+  
   size_t resultNumRows(int result);
   int resultNumFields(int result);
   std::string resultFieldType(int result, int field);
@@ -253,7 +262,7 @@ private:
   int _last_error_code;
 
   int _connection_id;
-  int _resultset_id;
+  base::refcount_t _resultset_id;
   int _tunnel_id;
 };
 
@@ -291,7 +300,7 @@ int DbMySQLQueryImpl::openConnectionP(const db_mgmt_ConnectionRef &info, const g
       sql::Authentication::Ref auth = sql::Authentication::create(info, "");
       auth->set_password(password.c_str());
 
-       conn = dm->getConnection(info, boost::shared_ptr<sql::TunnelConnection>(), auth);
+       conn = dm->getConnection(info, dm->getTunnel(info), auth);
     }
     else
         conn = dm->getConnection(info);
@@ -404,12 +413,27 @@ int DbMySQLQueryImpl::executeQuery(int conn, const std::string &query)
   try
   {
     std::auto_ptr<sql::Statement> pstmt(con->createStatement());
-    sql::ResultSet *res = pstmt->executeQuery(query);
+    pstmt->execute(query);
 
-    ++_resultset_id;
+    sql::ResultSet *res;
+    try
+    {
+      res = pstmt->getResultSet();
+    }
+    catch (sql::SQLException &exc)
+    {
+      if (exc.getErrorCode() == 0) // just means there's no resultset
+      {
+        return 0;
+      }
+      throw;
+    }
+
+    g_atomic_int_inc(&_resultset_id);
+    int id = g_atomic_int_get(&_resultset_id);
 
     cinfo->last_update_count = (size_t)pstmt->getUpdateCount();
-    _resultsets[_resultset_id] = res;
+    _resultsets[id] = res;
   }
   catch (sql::SQLException &exc)
   {
@@ -430,6 +454,67 @@ int DbMySQLQueryImpl::executeQuery(int conn, const std::string &query)
 }
 
 
+grt::IntegerListRef DbMySQLQueryImpl::executeQueryMultiResult(int conn, const std::string &query)
+{
+  CLEAR_ERROR();
+  
+  ConnectionInfo::Ref cinfo;
+  sql::Connection *con= 0;
+  {
+    base::MutexLock lock(_mutex);
+    if (_connections.find(conn) == _connections.end())
+      throw std::invalid_argument("Invalid connection");
+    cinfo = _connections[conn];
+    con = cinfo->prepare();
+  }
+
+  grt::IntegerListRef result(get_grt());
+  
+  try
+  {
+    std::auto_ptr<sql::Statement> pstmt(con->createStatement());
+    pstmt->execute(query);
+
+    try
+    {
+      do
+      {
+        int id = g_atomic_int_get(&_resultset_id);
+        g_atomic_int_inc(&_resultset_id);
+        
+        result.insert(grt::IntegerRef(id));
+        _resultsets[id] = pstmt->getResultSet();
+        cinfo->last_update_count = (size_t)pstmt->getUpdateCount();
+      } while (pstmt->getMoreResults());
+    }
+    catch (sql::SQLException &exc)
+    {
+      if (exc.getErrorCode() == 0) // just means there's no resultset
+        return result;
+      
+      throw;
+    }
+
+  }
+  catch (sql::SQLException &exc)
+  {
+    _last_error = exc.what();
+    _last_error_code = exc.getErrorCode();
+    cinfo->last_error = exc.what();
+    cinfo->last_error_code = _last_error_code;
+    return result;
+  }
+  catch (std::exception &e)
+  {
+    _last_error = e.what();
+    cinfo->last_error = e.what();
+    return result;
+  }
+
+  return result;
+}
+
+
 //#ifdef DEFINE_INT_FUNCTIONS
 size_t DbMySQLQueryImpl::lastUpdateCount(int conn)
 {
@@ -473,7 +558,8 @@ size_t DbMySQLQueryImpl::resultNumRows(int result)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return res->rowsCount();
 }
 
@@ -484,7 +570,8 @@ int DbMySQLQueryImpl::resultNumFields(int result)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return res->getMetaData()->getColumnCount();
 }
 
@@ -495,7 +582,8 @@ std::string DbMySQLQueryImpl::resultFieldType(int result, int field)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return res->getMetaData()->getColumnTypeName(field);  
 }
 
@@ -506,8 +594,9 @@ std::string DbMySQLQueryImpl::resultFieldName(int result, int field)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-
-  return res->getMetaData()->getColumnName(field);
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
+  return res->getMetaData()->getColumnLabel(field);
 }
 
 
@@ -517,6 +606,8 @@ int DbMySQLQueryImpl::resultFirstRow(int result)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return res->first() ? 1 : 0;
 }
 
@@ -526,7 +617,9 @@ int DbMySQLQueryImpl::resultNextRow(int result)
   base::MutexLock lock(_mutex);
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
-  sql::ResultSet *res = _resultsets[result];  
+  sql::ResultSet *res = _resultsets[result];
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return res->next() ? 1 : 0;
 }
 
@@ -537,7 +630,8 @@ grt::IntegerRef DbMySQLQueryImpl::resultFieldIntValue(int result, int field)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-
+  if (res == NULL)
+      throw std::invalid_argument("Invalid resultset");
   if (res->isNull(field))
     return grt::IntegerRef(0);
   else
@@ -551,7 +645,8 @@ double DbMySQLQueryImpl::resultFieldDoubleValue(int result, int field)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
   return (double)res->getDouble(field);
 }
 
@@ -562,6 +657,8 @@ grt::StringRef DbMySQLQueryImpl::resultFieldStringValue(int result, int field)
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
 
   if (res->isNull(field))
     return grt::StringRef();
@@ -576,6 +673,8 @@ grt::IntegerRef  DbMySQLQueryImpl::resultFieldIntValueByName(int result, const s
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
 
   if (res->isNull(field))
     return grt::IntegerRef(0);
@@ -590,7 +689,9 @@ double DbMySQLQueryImpl::resultFieldDoubleValueByName(int result, const std::str
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
+
   return (double)res->getDouble(field);
 }
 
@@ -601,7 +702,9 @@ grt::StringRef DbMySQLQueryImpl::resultFieldStringValueByName(int result, const
   if (_resultsets.find(result) == _resultsets.end())
     throw std::invalid_argument("Invalid resultset");
   sql::ResultSet *res = _resultsets[result];
-  
+  if (res == NULL)
+    throw std::invalid_argument("Invalid resultset");
+
   if (res->isNull(field))
     return grt::StringRef();
   else
