@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,12 +17,10 @@
  * 02110-1301  USA
  */
 
-
-#include "stdafx.h"
+#include <glib.h>
+#include <boost/signals2.hpp>
 
 #include "mysql_sql_facade.h"
-//#include "interfaces/plugin.h"
-
 
 using namespace bec;
 using namespace grt;
@@ -39,4 +37,4 @@ grt::ListRef<app_Plugin> MysqlSqlFacadeImpl::getPluginInfo()
   grt::ListRef<app_Plugin> list(get_grt());
   return list;
 }
-*/
\ No newline at end of file
+*/
