@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,6 @@
 
 #include "myx_sql_tree_item.h"
 #include "mysql_sql_parser_public_interface.h"
-#include "grtpp.h"
 
 using namespace mysql_parser;
 
@@ -44,7 +43,7 @@ public:
   static int escape_string(char *out, unsigned long out_size, const char *in, unsigned long in_size);
 
 public:
-  Mysql_sql_parser_fe(grt::GRT *grt);
+  Mysql_sql_parser_fe(const std::string &sql_mode_);
 
   int stop();
   typedef int (* fe_process_sql_statement_callback)(void* user_data, const MyxStatementParser *splitter, const char *sql, const SqlAstNode *tree,
@@ -54,9 +53,6 @@ public:
   int parse_sql_script_file(const std::string &filename, fe_process_sql_statement_callback cb, void *user_data);
   std::string get_first_sql_token(const std::string &sql, const std::string &versioning_comment_subst_token= "");
 
-private:
-  grt::GRT *_grt;
-
 public:
   bool ignore_dml;
   size_t max_insert_statement_size;
