@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
  * 02110-1301  USA
  */
 
-
-#include "stdafx.h"
+#include <glib.h>
+#include <boost/signals2.hpp>
 
 #include "mysql_sql_statement_decomposer.h"
 #include "mysql_sql_parser_utils.h"
@@ -38,6 +38,11 @@ Mysql_sql_statement_decomposer::Null_state_keeper::~Null_state_keeper()
 }
 #define NULL_STATE_KEEPER Null_state_keeper _nsk(this);
 
+void Mysql_sql_statement_decomposer::set_options(grt::DictRef opts)
+{
+  if (opts.is_valid())
+    Sql_parser_base::case_sensitive_identifiers(opts.get_int("case_sensitive_identifiers", grt::IntegerRef(1)) != 0);
+}
 
 Mysql_sql_statement_decomposer::Mysql_sql_statement_decomposer(grt::GRT *grt)
 :
@@ -136,7 +141,14 @@ int Mysql_sql_statement_decomposer::do_process_sql_statement(const SqlAstNode *t
 
 Mysql_sql_parser_base::Parse_result Mysql_sql_statement_decomposer::decompose_query(const SqlAstNode *select_init)
 {
-  const SqlAstNode *select_part2= select_init->subitem(sql::_select_init2, sql::_select_part2);
+  const SqlAstNode *select_part2 = select_init->subitem(sql::_select_init2, sql::_select_part2);
+
+  // Views now have a separate path for their select part.
+  if (select_part2 == NULL)
+    select_part2 = select_init->subitem(sql::_create_view_select, sql::_select_part2);
+
+  if (select_part2 == NULL)
+    return pr_invalid;
 
   // from clause
   {
@@ -238,92 +250,94 @@ Mysql_sql_parser_base::Parse_result Mysql_sql_statement_decomposer::decompose_qu
         select_paren= select_paren_;
       select_item_list= select_paren->subitem(sql::_select_part2, sql::_select_item_list);
     }
-
-    BOOST_FOREACH (const SqlAstNode *select_item, *select_item_list->subitems())
+    else
     {
-      if (select_item->name_equals(sql::_select_item))
+      BOOST_FOREACH (const SqlAstNode *select_item, *select_item_list->subitems())
       {
-        SelectItem select_item_;
+        if (select_item->name_equals(sql::_select_item))
+        {
+          SelectItem select_item_;
 
-        if (const SqlAstNode *table_wild= select_item->subitem(sql::_table_wild))
-        // table wildcard
-        {
-          std::list<std::string> idents;
-          BOOST_FOREACH (const SqlAstNode *ident, *table_wild->subitems())
-            if (ident->name_equals(sql::_ident))
-              idents.push_back(ident->restore_sql_text(_sql_statement));
-          std::list<std::string>::const_reverse_iterator i= idents.rbegin(), end= idents.rend();
-          select_item_.table= *i;
-          if (++i != end)
-            select_item_.schema= *i;
-          select_item_.wildcard= true;
-        }
-        else if (const SqlAstNode *expr= select_item->subitem(sql::_expr))
-        // expression
-        {
-          const SqlAstNode *simple_ident= NULL;
+          if (const SqlAstNode *table_wild= select_item->subitem(sql::_table_wild))
+          // table wildcard
           {
-            const SqlAstNode *simple_expr= expr->subitem(sql::_bool_pri, sql::_predicate, sql::_bit_expr, sql::_simple_expr);
-            while (simple_expr)
-            {
-              if ((simple_ident= simple_expr->subitem(sql::_simple_ident)))
-              {
-                break;
-              }
-
-              if (simple_expr->find_subseq(sql::_40, sql::_expr, sql::_41)) // sql::_40 == ASCII('('); sql::_41 == ASCII(')')
-                simple_expr= simple_expr->subitem(sql::_expr, sql::_bool_pri, sql::_predicate, sql::_bit_expr, sql::_simple_expr);
-              else
-                simple_expr= NULL;
-            }
+            std::list<std::string> idents;
+            BOOST_FOREACH (const SqlAstNode *ident, *table_wild->subitems())
+              if (ident->name_equals(sql::_ident))
+                idents.push_back(ident->restore_sql_text(_sql_statement));
+            std::list<std::string>::const_reverse_iterator i= idents.rbegin(), end= idents.rend();
+            select_item_.table= *i;
+            if (++i != end)
+              select_item_.schema= *i;
+            select_item_.wildcard= true;
           }
-
-          if (simple_ident)
-          // field ref
+          else if (const SqlAstNode *expr= select_item->subitem(sql::_expr))
+          // expression
           {
-            const SqlAstNode *simple_ident_q= simple_ident->subitem(sql::_simple_ident_q);
-            if (simple_ident_q)
+            const SqlAstNode *simple_ident= NULL;
             {
-              std::list<std::string> idents;
-              BOOST_FOREACH (const SqlAstNode *ident, *simple_ident_q->subitems())
-                if (ident->name_equals(sql::_ident))
-                  idents.push_back(ident->restore_sql_text(_sql_statement));
-              std::list<std::string>::const_reverse_iterator i= idents.rbegin(), end= idents.rend();
-              select_item_.field= *i;
-              if (++i != end)
-                select_item_.table= *i;
-              if (++i != end)
-                select_item_.schema= *i;
+              const SqlAstNode *simple_expr= expr->subitem(sql::_bool_pri, sql::_predicate, sql::_bit_expr, sql::_simple_expr);
+              while (simple_expr)
+              {
+                if ((simple_ident= simple_expr->subitem(sql::_simple_ident)))
+                {
+                  break;
+                }
+
+                if (simple_expr->find_subseq(sql::_40, sql::_expr, sql::_41)) // sql::_40 == ASCII('('); sql::_41 == ASCII(')')
+                  simple_expr= simple_expr->subitem(sql::_expr, sql::_bool_pri, sql::_predicate, sql::_bit_expr, sql::_simple_expr);
+                else
+                  simple_expr= NULL;
+              }
+            }
+
+            if (simple_ident)
+            // field ref
+            {
+              const SqlAstNode *simple_ident_q= simple_ident->subitem(sql::_simple_ident_q);
+              if (simple_ident_q)
+              {
+                std::list<std::string> idents;
+                BOOST_FOREACH (const SqlAstNode *ident, *simple_ident_q->subitems())
+                  if (ident->name_equals(sql::_ident))
+                    idents.push_back(ident->restore_sql_text(_sql_statement));
+                std::list<std::string>::const_reverse_iterator i= idents.rbegin(), end= idents.rend();
+                select_item_.field= *i;
+                if (++i != end)
+                  select_item_.table= *i;
+                if (++i != end)
+                  select_item_.schema= *i;
+              }
+              else
+              {
+                select_item_.field= simple_ident->restore_sql_text(_sql_statement);
+              }
             }
             else
+            // complex expression
             {
-              select_item_.field= simple_ident->restore_sql_text(_sql_statement);
+              select_item_.expr= expr->restore_sql_text(_sql_statement);
             }
           }
-          else
-          // complex expression
+
+          // alias
+          const SqlAstNode *select_alias= select_item->subitem(sql::_select_alias);
+          if (select_alias)
           {
-            select_item_.expr= expr->restore_sql_text(_sql_statement);
+            const SqlAstNode *ident= select_alias->subitem(sql::_ident);
+            if (!ident)
+              ident= select_alias->subitem(sql::_TEXT_STRING_sys);
+            select_item_.alias= ident->restore_sql_text(_sql_statement);
           }
-        }
 
-        // alias
-        const SqlAstNode *select_alias= select_item->subitem(sql::_select_alias);
-        if (select_alias)
+          _select_statement->select_items.push_back(select_item_);
+        }
+        else if (select_item->name_equals(sql::_42)) // sql::_42 == ASCII('*')
         {
-          const SqlAstNode *ident= select_alias->subitem(sql::_ident);
-          if (!ident)
-            ident= select_alias->subitem(sql::_TEXT_STRING_sys);
-          select_item_.alias= ident->restore_sql_text(_sql_statement);
+          SelectItem select_item_;
+          select_item_.wildcard= true;
+          _select_statement->select_items.push_back(select_item_);
         }
-
-        _select_statement->select_items.push_back(select_item_);
-      }
-      else if (select_item->name_equals(sql::_42)) // sql::_42 == ASCII('*')
-      {
-        SelectItem select_item_;
-        select_item_.wildcard= true;
-        _select_statement->select_items.push_back(select_item_);
       }
     }
   }
