@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
  * 02110-1301  USA
  */
 
-
-#include "stdafx.h"
+#include <glib.h>
+#include <boost/signals2.hpp>
 
 #include "mysql_sql_syntax_check.h"
 #include "mysql_sql_parser_fe.h"
@@ -72,7 +72,6 @@ Mysql_sql_syntax_check::Statement_type Mysql_sql_syntax_check::determine_stateme
       known_statement_types["SHOW"]= sql_show;
       known_statement_types["USE"]= sql_use;
       known_statement_types["LOAD"]= sql_load;
-      known_statement_types["EDIT"]= sql_edit;
       known_statement_types["SET"]= sql_set;
     }
   };
@@ -85,20 +84,6 @@ Mysql_sql_syntax_check::Statement_type Mysql_sql_syntax_check::determine_stateme
 }
 
 
-bool Mysql_sql_syntax_check::parse_edit_statement(const std::string &sql,
-  std::string &schema_name, std::string &table_name, std::string &statement_tail)
-{
-  NULL_STATE_KEEPER
-  _messages_enabled= false;
-  _use_delimiter= false;
-  Check_sql_statement do_check_slot=
-    boost::bind(&Mysql_sql_syntax_check::do_parse_edit_statement, this, _1,
-                boost::ref(schema_name), boost::ref(table_name), boost::ref(statement_tail));
-  int err_count= check_sql_statement(sql.c_str(), do_check_slot, ot_none);
-  return (0 == err_count);
-}
-
-
 int Mysql_sql_syntax_check::check_sql(const char* sql)
 {
   NULL_STATE_KEEPER
@@ -171,7 +156,7 @@ int Mysql_sql_syntax_check::check_sql_statement(const char* sql, Check_sql_state
   sql_parser_fe.max_insert_statement_size= MAX_INSERT_SQL_LENGTH;
   {
     DictRef options= DictRef::cast_from(_grt->get("/wb/options/options"));
-    sql_parser_fe.max_err_count= options.get_int("SqlEditor::SyntaxCheck::MaxErrCount", 100);    
+    sql_parser_fe.max_err_count= (int)options.get_int("SqlEditor::SyntaxCheck::MaxErrCount", 100);    
   }
 
   const char* actual_sql = sql;
@@ -227,29 +212,6 @@ Mysql_sql_parser_base::Parse_result Mysql_sql_syntax_check::do_check_sql(const S
 }
 
 
-Mysql_sql_parser_base::Parse_result Mysql_sql_syntax_check::do_parse_edit_statement(const SqlAstNode *tree,
-  std::string &schema_name, std::string &table_name, std::string &statement_tail)
-{
-  if (!tree)
-    return pr_invalid;
-  const SqlAstNode *edit_node= tree->subitem(sql::_statement, sql::_edit);
-  if (!edit_node)
-    return pr_invalid;
-
-  process_obj_full_name_item(edit_node->subitem(sql::_table_ident), schema_name, table_name);
-
-  const SqlAstNode *first_tail_node= edit_node->subitem(sql::_where_clause);
-  if (!first_tail_node)
-    first_tail_node= edit_node->subitem(sql::_opt_order_clause);
-  if (first_tail_node)
-    statement_tail= edit_node->restore_sql_text(_sql_statement, first_tail_node);
-  else
-    statement_tail.clear();
-
-  return pr_processed;
-}
-
-
 Mysql_sql_parser_base::Parse_result Mysql_sql_syntax_check::do_check_trigger(const SqlAstNode *tree)
 {
   const SqlAstNode *trigger_tail= NULL;
