@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -305,17 +305,30 @@ void DiffSQLGeneratorBE::generate_create_stmt(db_mysql_TableRef table)
     if(strlen(table->avgRowLength().c_str()))
       callback->create_table_avg_row_length(table->avgRowLength());
 
-    if(table->defaultCharacterSetName().is_valid() && strlen(table->defaultCharacterSetName().c_str()))
-      callback->create_table_charset(table->defaultCharacterSetName());
-
     if(table->checksum() != 0)
       callback->create_table_checksum(table->checksum());
 
-    if(table->defaultCollationName().is_valid() && strlen(table->defaultCollationName().c_str())&&
-        (get_collation_cs(table->defaultCollationName()) == (table->defaultCharacterSetName().c_str())) )
-      callback->create_table_collate(table->defaultCollationName());
+    // Set a collation only if it differs from the default collation for that charset.
+    // Ignore the collation if it doesn't match the charset, however.
+    if (table->defaultCharacterSetName().is_valid())
+    {
+      std::string charset = table->defaultCharacterSetName();
+      if (!charset.empty())
+      {
+        callback->create_table_charset(charset);
 
-    if(strlen(table->comment().c_str()))
+        if (table->defaultCollationName().is_valid())
+        {
+          std::string collation = table->defaultCollationName();
+          if (!collation.empty()
+            && (charsetForCollation(collation) == charset)
+            && (defaultCollationForCharset(table->defaultCharacterSetName()) != collation))
+            callback->create_table_collate(collation);
+        }
+      }
+    }
+
+    if (strlen(table->comment().c_str()))
       callback->create_table_comment(table->comment());
     
     // CONNECTION [=] 'connect_string'
@@ -572,28 +585,25 @@ void DiffSQLGeneratorBE::generate_alter(grt::ListRef<db_mysql_Column> columns, c
   Column_rename_map column_rename_map;
 
   // build a map of column renames
+  // process CHANGE COLUMN (handles content change only)
   for(grt::ChangeSet::const_iterator e= columns_cs->end(), it= columns_cs->begin(); it != e; it++)
   {
-    // process CHANGE COLUMN (handles content change only)
-    for(grt::ChangeSet::const_iterator e= columns_cs->end(), it= columns_cs->begin(); it != e; it++)
-    {
-      const boost::shared_ptr<grt::DiffChange> column_change= *it;
+    const boost::shared_ptr<grt::DiffChange> column_change= *it;
 
-      if(column_change->get_change_type() == grt::ListItemModified)
-      {
-        const grt::ListItemModifiedChange *modified_change= static_cast<const grt::ListItemModifiedChange *>(column_change.get());
-        db_mysql_ColumnRef column= db_mysql_ColumnRef::cast_from(grt::ValueRef(modified_change->get_new_value()));
-        if(strcmp(column->name().c_str(), column->oldName().c_str()))
-          column_rename_map[std::string(column->oldName().c_str())]= std::string(column->name().c_str());
-      }
-      else if(column_change->get_change_type() == grt::ListItemOrderChanged)
-      {
-        const grt::ListItemOrderChange *order_change= static_cast<const grt::ListItemOrderChange *>(column_change.get());
-        db_mysql_ColumnRef org_col= db_mysql_ColumnRef::cast_from(grt::ValueRef(order_change->get_old_value()));
-        db_mysql_ColumnRef mod_col= db_mysql_ColumnRef::cast_from(grt::ValueRef(order_change->get_new_value()));
-        if(strcmp(org_col->name().c_str(), mod_col->oldName().c_str()))
-          column_rename_map[std::string(org_col->oldName().c_str())]= std::string(mod_col->name().c_str());
-      }
+    if(column_change->get_change_type() == grt::ListItemModified)
+    {
+      const grt::ListItemModifiedChange *modified_change= static_cast<const grt::ListItemModifiedChange *>(column_change.get());
+      db_mysql_ColumnRef column= db_mysql_ColumnRef::cast_from(grt::ValueRef(modified_change->get_old_value()));
+      if(strcmp(column->name().c_str(), column->oldName().c_str())!=0)
+        column_rename_map[std::string(column->oldName().c_str())]= std::string(column->name().c_str());
+    }
+    else if(column_change->get_change_type() == grt::ListItemOrderChanged)
+    {
+      const grt::ListItemOrderChange *order_change= static_cast<const grt::ListItemOrderChange *>(column_change.get());
+      db_mysql_ColumnRef org_col= db_mysql_ColumnRef::cast_from(grt::ValueRef(order_change->get_old_value()));
+      db_mysql_ColumnRef mod_col= db_mysql_ColumnRef::cast_from(grt::ValueRef(order_change->get_new_value()));
+      if(strcmp(org_col->name().c_str(), mod_col->oldName().c_str())!=0)
+        column_rename_map[std::string(org_col->oldName().c_str())]= std::string(org_col->name().c_str());
     }
   }
 
