@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+* Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -30,6 +30,12 @@
 #include <map>
 #include <set>
 #include <vector>
+#include <list>
+#include <sstream>
+
+#include <boost/optional.hpp>
+#include <boost/cstdint.hpp>
+#include <boost/shared_ptr.hpp>
 
 #include <pcre.h>
 
