@@ -8,7 +8,8 @@
 
 inline void register_interfaces(grt::GRT *grt)
 {
-  PluginInterfaceImpl::register_interface(grt);
+  if (!grt->get_interface("PluginInterface"))
+    PluginInterfaceImpl::register_interface(grt); // this is already registered in PluginManager
   SQLGeneratorInterfaceImpl::register_interface(grt);
   WbValidationInterfaceImpl::register_interface(grt);
   WbModelReportingInterfaceImpl::register_interface(grt);
