@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include <glib/gstdio.h>
-
 #include "wb_model.h"
 #include "reporting.h"
 
@@ -31,12 +29,13 @@
 #include "base/string_utilities.h"
 #include "base/geometry.h"
 #include "base/log.h"
+#include "base/util_functions.h"
 
 #include "mforms/code_editor.h"
 
 // Support for syntax highlighting in SQL output.
 #ifdef _WIN32
-  #include "ScintillaWR.h"
+  #include "win32/ScintillaWR.h"
   #define SCI_WRAPPER_NS ScintillaWrapper::
 #else
   #include "Scintilla.h"
@@ -56,8 +55,6 @@ using namespace base;
 using ctemplate::Template;
 using ctemplate::TemplateDictionary;
 
-DEFAULT_LOG_DOMAIN("Reporting")
-
 //----------------- LexerDocument ------------------------------------------------------------------
 
 LexerDocument::LexerDocument(const std::string& text)
@@ -66,12 +63,12 @@ LexerDocument::LexerDocument(const std::string& text)
   _style_position = 0;
   _style_buffer = new char[_text.size()];
 
-  // Split the text into lines and store the index where a line starts.
+  // Split the text into lines and store start and length of each.
   std::vector<std::string> lines = base::split(text, "\n");
-  int start = 0;
+  size_t start = 0;
   for (size_t i = 0; i < lines.size(); ++i)
   {
-    _line_starts.push_back(start);
+    _lines.push_back(std::make_pair(start, lines[i].size() + 1));
     start += lines[i].size() + 1;
   }
 }
@@ -104,7 +101,7 @@ void LexerDocument::SetErrorStatus(int status)
 
 int LexerDocument::Length() const
 {
-  return _text.size();
+  return (int)_text.size();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -125,29 +122,33 @@ char LexerDocument::StyleAt(int position) const
 
 int LexerDocument::LineFromPosition(int position) const
 {
-  // Since we always style the full text starting from position 0 this should be the normal case.
-  if (position == 0)
-    return 0;
+  size_t i = 0;
+  while (i < _lines.size())
+  {
+    if ((size_t)position < _lines[i].first + _lines[i].second)
+      break;
+    ++i;
+  }
 
-  throw std::logic_error(std::string("Internal error. Unexpected use of unimplemented function ").
-    append(__FUNCTION__).append(" in LexerDocument (").
-    append(__FILE__).append(")."));
+  if (i < _lines.size())
+    return (int)i;
+  return (int)_lines.size();
 }
 
 //--------------------------------------------------------------------------------------------------
 
 int LexerDocument::LineStart(int line) const
 {
-  if (line < 0 || line > (int)_line_starts.size())
-    return 0;
-  return _line_starts[line];
+  if (line >= (int)_lines.size())
+    return (int)(_lines.back().first + _lines.back().second); // A position after the last one.
+  return (int)_lines[line].first;
 }
 
 //--------------------------------------------------------------------------------------------------
 
 int LexerDocument::GetLevel(int line) const
 {
-  if (line < 0 || line > (int) _level_cache.size() - 1)
+  if (line < 0 || line >= (int) _level_cache.size())
     return SC_FOLDLEVELBASE;
   return _level_cache[line];
 }
@@ -161,11 +162,11 @@ int LexerDocument::SetLevel(int line, int level)
     // Check if we need to make more room in our cache.
     if (line >= (int) _level_cache.size())
     {
-      int last_size= _level_cache.size();
+      size_t last_size = _level_cache.size();
       _level_cache.resize(line + 1);
       
       // Initialize newly added entries.
-      for (int i= last_size - 1; i < (int) _level_cache.size() - 1; i++)
+      for (size_t i= last_size - 1; i < _level_cache.size() - 1; i++)
         _level_cache[i]= SC_FOLDLEVELBASE;
     }
     _level_cache[line]= level;
@@ -312,7 +313,7 @@ void WbModelImpl::initializeReporting()
  * @param templates - a GRT List the available templates will be added to
  * @return 1 on success, 0 on error
  */
-int WbModelImpl::getAvailableReportingTemplates(grt::StringListRef templates)
+ssize_t WbModelImpl::getAvailableReportingTemplates(grt::StringListRef templates)
 {
   // get pointer to the GRT
   grt::GRT *grt= get_grt();
@@ -609,20 +610,14 @@ void fillTriggerDict(const db_mysql_TriggerRef& trigger, const db_mysql_TableRef
 {
   trigger_dict->SetValue(REPORT_TRIGGER_NAME, *trigger->name());
   trigger_dict->SetValue(REPORT_TRIGGER_TIMING, *trigger->timing());
-  trigger_dict->SetValue(REPORT_TRIGGER_CONDITION, *trigger->condition());
   trigger_dict->SetValue(REPORT_TRIGGER_ENABLED, (trigger->enabled() == 1) ? "yes" : "no");
   
   trigger_dict->SetValue(REPORT_TABLE_NAME, table->name().c_str());
   trigger_dict->SetValue(REPORT_TRIGGER_DEFINER, *trigger->definer());
   trigger_dict->SetValue(REPORT_TRIGGER_EVENT, *trigger->event());
-  trigger_dict->SetIntValue(REPORT_TRIGGER_ORDER, *trigger->order());
-  trigger_dict->SetIntValue(REPORT_TRIGGER_CONDITION, *trigger->order());
+  trigger_dict->SetValue(REPORT_TRIGGER_ORDER, *trigger->ordering());
+  trigger_dict->SetValue(REPORT_TRIGGER_OTHER_TRIGGER, *trigger->otherTrigger());
   trigger_dict->SetValue(REPORT_TRIGGER_TIMING, *trigger->timing());
-  trigger_dict->SetValue(REPORT_TRIGGER_ORIENTATION, *trigger->orientation());
-  trigger_dict->SetValue(REPORT_TRIGGER_REFERENCE_NEW_ROW, *trigger->referenceNewRow());
-  trigger_dict->SetValue(REPORT_TRIGGER_REFERENCE_NEW_TABLE, *trigger->referenceNewTable());
-  trigger_dict->SetValue(REPORT_TRIGGER_REFERENCE_OLD_ROW, *trigger->referenceOldRow());
-  trigger_dict->SetValue(REPORT_TRIGGER_REFERENCE_OLD_TABLE, *trigger->referenceOldTable());
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -658,8 +653,8 @@ void fillRoutineDict(const db_mysql_RoutineRef& routine, TemplateDictionary *rou
   assignValueOrNA(routine_dict, REPORT_ROUTINE_RETURN_TYPE, routine->returnDatatype());
   assignValueOrNA(routine_dict, REPORT_ROUTINE_SECURITY, value= routine->security());
 
-  routine_dict->SetIntValue(REPORT_ROUTINE_PARAMETER_COUNT, routine->params().count());
-  for (int j= 0; j < (int)routine->params().count(); j++)
+  routine_dict->SetIntValue(REPORT_ROUTINE_PARAMETER_COUNT, (long)routine->params().count());
+  for (size_t j = 0; j < routine->params().count(); j++)
   {
     db_mysql_RoutineParamRef parameter= routine->params().get(j);
     
@@ -813,7 +808,7 @@ void set_ddl(TemplateDictionary *target, SQLGeneratorInterfaceImpl* sqlgenModule
       SCI_WRAPPER_NS PropSetSimple property_set;
       SCI_WRAPPER_NS Accessor* accessor= new SCI_WRAPPER_NS Accessor(document, &property_set);
       
-      lexer->Lex(0, sql.size(), 0, keywordLists, *accessor);
+      lexer->Lex(0, (int)sql.size(), 0, keywordLists, *accessor);
       
       int currentStyle= SCE_MYSQL_DEFAULT;
       int tokenStart= 0;
@@ -882,7 +877,7 @@ static int count_template_files(const string template_dir)
  * @param options - various options that customize the output, including output template, output path etc.
  * @return 1 on success, 0 on error
  */
-int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::DictRef& options)
+ssize_t WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::DictRef& options)
 {
   // get pointer to the GRT
   grt::GRT *grt= model.get_grt();
@@ -1000,7 +995,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
   // Set some global project info.
   main_dict.SetValue(REPORT_TITLE, title);
 
-  string time= bec::fmttime(0, DATETIME_FMT);
+  string time= base::fmttime(0, DATETIME_FMT);
   main_dict.SetValue(REPORT_GENERATED, time);
 
   workbench_DocumentRef document= workbench_DocumentRef::cast_from(model->owner());
@@ -1082,12 +1077,12 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
 
       if (columns_show)
       {
-        TemplateDictionary *columns_list_dict;
-        schema_dict->SetIntValue(REPORT_COLUMN_COUNT, table->columns().count());
+        TemplateDictionary *columns_list_dict = NULL;
+        schema_dict->SetIntValue(REPORT_COLUMN_COUNT, (long)table->columns().count());
 
         for (int k= 0; k < (int)table->columns().count(); k++)
         {
-          // Create the dict for the outer section (inluding header)
+          // Create the dict for the outer section (including header)
           if (k == 0)
             columns_list_dict= table_dict->AddSectionDictionary(REPORT_COLUMNS_LISTING);
 
@@ -1108,18 +1103,18 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
 
       if (indices_show)
       {
-        TemplateDictionary *idx_list_dict;
-        schema_dict->SetIntValue(REPORT_INDEX_COUNT, table->indices().count());
+        TemplateDictionary *idx_list_dict = NULL;
+        schema_dict->SetIntValue(REPORT_INDEX_COUNT, (long)table->indices().count());
 
         for (int k= 0; k < (int)table->indices().count(); k++)
         {
-          // Create the dict for the outer section (inluding header)
+          // Create the dict for the outer section (including header)
           if (k == 0)
             idx_list_dict= table_dict->AddSectionDictionary(REPORT_INDICES_LISTING);
 
           db_mysql_IndexRef idx= table->indices().get(k);
 
-          TemplateDictionary *idx_dict= idx_list_dict->AddSectionDictionary(REPORT_INDICES);
+          TemplateDictionary *idx_dict = idx_list_dict->AddSectionDictionary(REPORT_INDICES);
           fillIndexDict(idx, table, idx_dict, false);
 
           idx_dict= schema_dict->AddSectionDictionary(REPORT_INDICES);
@@ -1133,7 +1128,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
       if (fks_show)
       {
         TemplateDictionary *fk_list_dict= NULL;
-        schema_dict->SetIntValue(REPORT_FOREIGN_KEY_COUNT, table->foreignKeys().count());
+        schema_dict->SetIntValue(REPORT_FOREIGN_KEY_COUNT, (long)table->foreignKeys().count());
 
         for (int k= 0; k < (int)table->foreignKeys().count(); k++)
         {
@@ -1179,7 +1174,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
         }
         
         // Triggers.
-        schema_dict->SetIntValue(REPORT_TRIGGER_COUNT, table->triggers().count());
+        schema_dict->SetIntValue(REPORT_TRIGGER_COUNT, (long)table->triggers().count());
 
         for (int k= 0; k < (int)table->triggers().count(); k++)
         {
@@ -1196,7 +1191,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
     }
     
     // View section.
-    schema_dict->SetIntValue(REPORT_VIEW_COUNT, schema->views().count());
+    schema_dict->SetIntValue(REPORT_VIEW_COUNT, (long)schema->views().count());
     for (int j= 0; j < (int)schema->views().count(); j++)
     {
       db_mysql_ViewRef view= schema->views().get(j);
@@ -1210,7 +1205,7 @@ int WbModelImpl::generateReport(workbench_physical_ModelRef model, const grt::Di
     }
 
     // Routine section.
-    schema_dict->SetIntValue(REPORT_ROUTINE_COUNT, schema->routines().count());
+    schema_dict->SetIntValue(REPORT_ROUTINE_COUNT, (long)schema->routines().count());
     for (int j= 0; j < (int)schema->routines().count(); j++)
     {
       db_mysql_RoutineRef routine= schema->routines().get(j);
