@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -28,10 +28,13 @@
 #include <set>
 #include <map>
 #include <list>
+#include <sstream>
 
 #include <glib.h>
 
 #include <boost/enable_shared_from_this.hpp>
+#include <boost/optional.hpp>
+#include <boost/cstdint.hpp>
 
 #include "grts/structs.db.mgmt.h"
 #include "grts/structs.db.mysql.h"
