@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -41,7 +41,5 @@ typedef std::map<std::string, GrtNamedObjectRef> CatalogMap;
 
 WBPLUGINDBMYSQLBE_PUBLIC_FUNC void update_all_old_names(db_mysql_CatalogRef cat, bool update_only_empty, CatalogMap& map);
 WBPLUGINDBMYSQLBE_PUBLIC_FUNC void build_catalog_map(db_mysql_CatalogRef catalog, CatalogMap& map);
-WBPLUGINDBMYSQLBE_PUBLIC_FUNC void apply_old_names(GrtObjectRef obj, grt::DictRef profile);
-WBPLUGINDBMYSQLBE_PUBLIC_FUNC void load_old_names(GrtObjectRef obj, grt::DictRef result);
 
 #endif // _MYSQL_DB_PUBLIC_INTERFACE_H_
