@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -42,7 +42,8 @@ class WBPLUGINDBMYSQLBE_PUBLIC_FUNC DbMySQLSQLExport : public DbMySQLValidationP
   bool _no_FK_for_inserts;
   bool _triggers_after_inserts;
   std::string _output_filename;
-  bool _tables_are_selected, _triggers_are_selected, 
+  std::string _output_header;
+  bool _tables_are_selected, _triggers_are_selected,
       _routines_are_selected, _views_are_selected, 
       _users_are_selected;
   bool _omit_schemata;
@@ -50,6 +51,8 @@ class WBPLUGINDBMYSQLBE_PUBLIC_FUNC DbMySQLSQLExport : public DbMySQLValidationP
   bool _skip_foreign_keys;
   bool _skip_fk_indexes;
   bool _case_sensitive;
+  bool _gen_doc_props;
+  bool _gen_attached_scripts;
 
   boost::shared_ptr<bec::GrtStringListModel> _users_model;
   boost::shared_ptr<bec::GrtStringListModel> _users_exc_model;
@@ -80,7 +83,6 @@ protected:
   virtual db_mysql_CatalogRef get_model_catalog();
   virtual grt::DictRef get_options_as_dict(grt::GRT*);
   //bec::MessageListBE messages_list;
-
 public:
 
   DbMySQLSQLExport(bec::GRTManager *grtm, db_mysql_CatalogRef catalog = db_mysql_CatalogRef());
@@ -92,7 +94,8 @@ public:
   
   void set_option(const std::string& name, bool value);
   void set_option(const std::string& name, const std::string& value);
-  void set_db_options(const grt::DictRef& db_options){_db_options = db_options;};
+  void set_db_options_for_version(const GrtVersionRef &version);
+  void set_db_options(grt::DictRef &db_options);
 
   void start_export(bool wait_finish);
   //void run_validation();
