@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,8 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
 #include "grtdb/db_object_helpers.h"
 
 #include "grts/structs.h"
@@ -48,9 +46,11 @@ DbMySQLValidationPage::~DbMySQLValidationPage()
   delete messages_list;
 }
 
+//--------------------------------------------------------------------------------------------------
+
 void DbMySQLValidationPage::run_validation()
 {
-  bec::GRTTask *task= new bec::GRTTask("Catalog validation", 
+  bec::GRTTask::Ref task = bec::GRTTask::create_task("Catalog validation", 
     _manager->get_dispatcher(), 
     boost::bind(&DbMySQLSQLExport::validation_task, this, _1, grt::StringRef()));
 
@@ -59,6 +59,8 @@ void DbMySQLValidationPage::run_validation()
   _manager->get_dispatcher()->add_task(task);
 }
 
+//--------------------------------------------------------------------------------------------------
+
 void DbMySQLValidationPage::validation_finished(grt::ValueRef res)
 {
   if (_validation_finished_cb)
@@ -107,7 +109,7 @@ ValueRef DbMySQLValidationPage::validation_task(grt::GRT* grt, grt::StringRef)
       {
         grt->send_info("Starting "+caption);
 
-        int validation_res= (*module)->validate("All", catalog);
+        int validation_res= (int)(*module)->validate("All", catalog);
 
         _manager->get_dispatcher()->call_from_main_thread<int>(
 			boost::bind(_validation_step_finished_cb, validation_res), true, false);
