@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -133,10 +133,6 @@ void DiffNode::dump(int depth)
 
 DiffNode *DiffNode::find_child_by_db_part_name(const std::string& name)
 {
-
-    if(this == NULL)
-        throw std::logic_error("invalid object name");
-
     DiffNodeVector::const_iterator b= children.begin();
     DiffNodeVector::const_iterator e= children.end();
     DiffNodeVector::const_iterator it= std::find_if(b, e, CompareName(name, true));
