@@ -21,7 +21,7 @@
 
 #include "converter.h"
 #include "base/log.h"
-
+#include "base/string_utilities.h"
 #include <string>
 #include <cstdlib>
 
@@ -68,13 +68,9 @@ void BaseConverter::convert_date(const char* source, MYSQL_TIME* target)
     return;
   }
 
-  std::string year  = time.substr(0, 4);
-  std::string month = time.substr(5, 2);
-  std::string day   = time.substr(8, 2);
-
-  target->year  = atoi(year.data());
-  target->month = atoi(month.data());
-  target->day   = atoi(day.data());
+  target->year  = base::atoi<int>(time.substr(0, 4).c_str(), 0);
+  target->month = base::atoi<int>(time.substr(5, 2).c_str(), 0);
+  target->day   = base::atoi<int>(time.substr(8, 2).c_str(), 0);
 
   target->time_type = MYSQL_TIMESTAMP_DATE;
 }
@@ -94,9 +90,6 @@ void BaseConverter::convert_time(const char* source, MYSQL_TIME* target)
     return;
   }
 
-  std::string hour = time.substr(0, 2);
-  std::string min  = time.substr(3, 2);
-  std::string sec  = time.substr(6, 2);
   std::string msec = "0";
 
   // Get the milliseconds if present
@@ -106,10 +99,10 @@ void BaseConverter::convert_time(const char* source, MYSQL_TIME* target)
     msec.resize(6, '0');
   }
 
-  target->hour = atoi(hour.data());
-  target->minute = atoi(min.data());
-  target->second = atoi(sec.data());
-  target->second_part = atoi(msec.data());
+  target->hour = base::atoi<int>(time.substr(0, 2).c_str(), 0);
+  target->minute = base::atoi<int>(time.substr(3, 2).c_str(), 0);
+  target->second = base::atoi<int>(time.substr(6, 2).c_str(), 0);
+  target->second_part = base::atoi<int>(msec.c_str(), 0);
 
   target->time_type = MYSQL_TIMESTAMP_TIME;
 }
@@ -144,13 +137,6 @@ void BaseConverter::convert_timestamp(const char* source, MYSQL_TIME* target)
     return;
   }
 
-  std::string year  = time.substr(0, 4);
-  std::string month = time.substr(5, 2);
-  std::string day   = time.substr(8, 2);
-
-  std::string hour    = time.substr(11, 2);
-  std::string minute  = time.substr(14, 2);
-  std::string second  = time.substr(17, 2);
   std::string msecond = "0";
 
   // Get the milliseconds if present
@@ -160,14 +146,14 @@ void BaseConverter::convert_timestamp(const char* source, MYSQL_TIME* target)
     msecond.resize(6, '0');
   }
 
-  target->year  = atoi(year.data());
-  target->month = atoi(month.data());
-  target->day   = atoi(day.data());
+  target->year  = base::atoi<int>(time.substr(0, 4).c_str(), 0);
+  target->month = base::atoi<int>(time.substr(5, 2).c_str(), 0);
+  target->day   = base::atoi<int>(time.substr(8, 2).c_str(), 0);
 
-  target->hour        = atoi(hour.data());
-  target->minute      = atoi(minute.data());
-  target->second      = atoi(second.data());
-  target->second_part = atoi(msecond.data());
+  target->hour        = base::atoi<int>(time.substr(11, 2).c_str(), 0);
+  target->minute      = base::atoi<int>(time.substr(14, 2).c_str(), 0);
+  target->second      = base::atoi<int>(time.substr(17, 2).c_str(), 0);
+  target->second_part = base::atoi<int>(msecond.c_str(), 0);
 
   target->time_type = MYSQL_TIMESTAMP_DATETIME;
 }
