@@ -1,4 +1,4 @@
-# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -103,7 +103,7 @@ class SetupMainView(WizardPage):
         else:
             self._add_script_radiobutton_option(box, "copy_script", "Create a shell script to copy the data from outside Workbench", "Shell Script File:", "Save As", "You should edit this file to add the source and target server passwords before running it.", rid)
 
-        self._add_script_radiobutton_option(box, "bulk_copy_script", "Create a shell script to use native server dump and load abilities for fast migration", "Bulk Data Copy Script:", "Save As", "Edit the generated file and change passwords at the top of the generated script.\nRun it on the source server to create a zip package containing a data dump as well as a load script.\nCopy this to the target server, extract it and run the import script. See the script output for further details.", rid)
+        self._add_script_radiobutton_option(box, "bulk_copy_script", "Create a shell script to use native server dump and load abilities for fast migration", "Bulk Data Copy Script:", "Save As", "Edit the generated file and change passwords at the top of the generated script.\nRun it on the source server to create a zip package containing a data dump as well as a load script.\nCopy this to the target server, extract it, and run the import script. See the script output for further details.", rid)
 
         panel = mforms.newPanel(mforms.TitledBoxPanel)
         panel.set_title("Options")
@@ -115,7 +115,7 @@ class SetupMainView(WizardPage):
         panel.add(self.options_box)
 
         self._truncate_db = mforms.newCheckBox()
-        self._truncate_db.set_text("Truncate target tables (ie. delete contents) before copying data")
+        self._truncate_db.set_text("Truncate target tables (i.e. delete contents) before copying data")
         self.options_box.add(self._truncate_db, False, True)
 
         hbox = mforms.newBox(True)
@@ -128,13 +128,17 @@ class SetupMainView(WizardPage):
         l = mforms.newImageBox()
         l.set_image(mforms.App.get().get_resource_path("mini_notice.png"))
         l.set_tooltip("Number of tasks to use for data transfer. Each task will open a "+
-          "connection to both source and target RDBMSs to copy table rows.\nDefault value 2.")
+          "connection to both source and target RDBMSes to copy table rows.\nDefault value 2.")
         hbox.add(l, False, True)
         self.options_box.add(hbox, False, True)
 
         self._debug_copy = mforms.newCheckBox()
         self._debug_copy.set_text("Enable debug output for table copy")
         self.options_box.add(self._debug_copy, False, True)
+        
+        self._driver_sends_utf8 = mforms.newCheckBox()
+        self._driver_sends_utf8.set_text("Driver sends data already encoded as UTF-8.")
+        self.options_box.add(self._driver_sends_utf8, False, True)
 
 
         ###
@@ -196,6 +200,7 @@ All tables are copied by default.""")
 
         self.main.plan.state.dataBulkTransferParams["LiveDataCopy"] = 1 if self._copy_db.get_active() else 0
         self.main.plan.state.dataBulkTransferParams["DebugTableCopy"] = 1 if self._debug_copy.get_active() else 0
+        self.main.plan.state.dataBulkTransferParams["DriverSendsDataAsUTF8"] = 1 if self._driver_sends_utf8.get_active() else 0
         self.main.plan.state.dataBulkTransferParams["TruncateTargetTables"] = 1 if self._truncate_db.get_active() else 0
 
         for key in self.main.plan.state.dataBulkTransferParams.keys():
@@ -266,6 +271,7 @@ All tables are copied by default.""")
             if not source_os:
                 self.bulk_copy_script_radiobutton.set_enabled(False)
                 bulk_copy_filename = ''
+                grt.send_warning('Cannot get operating system of source server.')
             elif source_os == "windows":
                 bulk_copy_filename = os.path.join(mforms.Utilities.get_special_folder(mforms.Desktop), 'bulk_copy_tables.cmd')
             else:
@@ -412,7 +418,7 @@ class TransferMainView(WizardProgressPage):
                           self.main.plan.migrationSource.connection, source_password,
                           self.main.plan.migrationTarget.connection, target_password)
 
-            self._transferer.copytable_path = self.main.plan.wbcopytables_path
+            self._transferer.copytable_path = self.main.plan.wbcopytables_path_bin
         WizardProgressPage.page_activated(self, advancing)
 
 
@@ -479,6 +485,8 @@ class TransferMainView(WizardProgressPage):
             source_pk_list = []
             target_pk_list = []
             for column in table.columns:
+                if column.generated:
+                    continue
                 if table.isPrimaryKeyColumn(column):
                     source_pk_list.append(source_db_module.quoteIdentifier(column.oldName))
                     target_pk_list.append(target_db_module.quoteIdentifier(column.name))
@@ -488,8 +496,8 @@ class TransferMainView(WizardProgressPage):
                 else:
                     select_expression.append(source_db_module.quoteIdentifier(column.oldName))
 
-            self._working_set[schema_name+"."+table_name]["source_primary_key"] = ",".join(source_pk_list)
-            self._working_set[schema_name+"."+table_name]["target_primary_key"] = ",".join(target_pk_list)
+            self._working_set[schema_name+"."+table_name]["source_primary_key"] = ",".join(source_pk_list) if len(source_pk_list) > 0 else "-"
+            self._working_set[schema_name+"."+table_name]["target_primary_key"] = ",".join(target_pk_list) if len(target_pk_list) > 0 else "-"
             self._working_set[schema_name+"."+table_name]["select_expression"] = ", ".join(select_expression)
 #            source_db_module = self.main.plan.migrationSource.module_db()
  #           source_table = source_db_module.fullyQualifiedObjectName(stable)
