@@ -44,7 +44,6 @@ layout = [ ( 'General',
           'init-file',
           'lock_wait_timeout',
           'max_long_data_size',
-          'max_statement_time',
           'old',
           'one-thread',
           'session_track_gtids',
@@ -120,6 +119,8 @@ layout = [ ( 'General',
           'log-queries-not-using-indexes',
           'log-raw',
           'log-short-format',
+          'log_backward_compatible_user_definitions',
+          'log_builtin_as_identified_by_password',
           'log_error_verbosity',
           'log_slave_updates',
           'log_syslog',
@@ -164,6 +165,7 @@ layout = [ ( 'General',
           'innodb_file_format_max']),
       ( 'Buffer pool',
         [ 'innodb_buffer_pool_awe_mem_mb',
+          'innodb_buffer_pool_chunk_size',
           'innodb_buffer_pool_dump_at_shutdown',
           'innodb_buffer_pool_dump_now',
           'innodb_buffer_pool_filename',
@@ -176,9 +178,12 @@ layout = [ ( 'General',
         [ 'innodb_flush_log_at_trx_commit',
           'innodb_flush_method',
           'innodb_flush_neighbors',
+          'innodb_flush_sync',
           'innodb_log_arch_dir',
           'innodb_log_archive',
           'innodb_log_buffer_size',
+          'innodb_log_checksum_algorithm',
+          'innodb_log_checksums',
           'innodb_log_compressed_pages',
           'innodb_log_file_size',
           'innodb_log_files_in_group',
@@ -187,12 +192,13 @@ layout = [ ( 'General',
           'innodb_mirrored_log_groups',
           'innodb_online_alter_log_max_size',
           'innodb_undo_directory',
+          'innodb_undo_log_truncate',
           'innodb_undo_logs']),
       ('Various', ['innodb_fast_shutdown']),
       ( 'Memory',
-        [ 'innodb_additional_mem_pool_size',
-          'innodb_buffer_pool_instances',
+        [ 'innodb_buffer_pool_instances',
           'innodb_buffer_pool_size',
+          'innodb_additional_mem_pool_size',
           'innodb_page_cleaners',
           'innodb_page_size',
           'innodb_sort_buffer_size']),
@@ -217,6 +223,7 @@ layout = [ ( 'General',
           'innodb_adaptive_flushing',
           'innodb_adaptive_flushing_lwm',
           'innodb_adaptive_hash_index',
+          'innodb_adaptive_hash_index_parts',
           'innodb_adaptive_max_sleep_delay',
           'innodb_api_bk_commit_interval',
           'innodb_api_disable_rowlock',
@@ -225,19 +232,24 @@ layout = [ ( 'General',
           'innodb_api_trx_level',
           'innodb_autoextend_increment',
           'innodb_autoinc_lock_mode',
+          'innodb_background_drop_list_empty',
           'innodb_buffer_pool_dump_pct',
           'innodb_change_buffer_max_size',
           'innodb_change_buffering',
+          'innodb_change_buffering_debug',
           'innodb_checksum_algorithm',
           'innodb_checksums',
           'innodb_cmp_per_index_enabled',
           'innodb_commit_concurrency',
+          'innodb_compress_debug',
           'innodb_compression_failure_threshold_pct',
           'innodb_compression_level',
           'innodb_compression_pad_pct_max',
           'innodb_concurrency_tickets',
           'innodb_create_intrinsic',
+          'innodb_default_row_format',
           'innodb_disable_sort_file_cache',
+          'innodb_disable_resize_buffer_pool_debug',
           'innodb_doublewrite',
           'innodb_extra_dirty_writes',
           'innodb_file_io_threads',
@@ -249,6 +261,7 @@ layout = [ ( 'General',
           'innodb_io_capacity',
           'innodb_io_capacity_max',
           'innodb_large_prefix',
+          'innodb_limit_optimistic_insert_debug',
           'innodb_lock_wait_timeout',
           'innodb_locks_unsafe_for_binlog',
           'innodb_lru_scan_depth',
@@ -262,13 +275,16 @@ layout = [ ( 'General',
           'innodb_monitor_enable',
           'innodb_monitor_reset',
           'innodb_monitor_reset_all',
+          'innodb_numa_interleave',
           'innodb_old_blocks_pct',
           'innodb_old_blocks_time',
           'innodb_online_alter_log_max_size',
           'innodb_open_files',
           'innodb_optimize_fulltext_only',
+          'innodb_optimize_point_storage',
           'innodb_print_all_deadlocks',
           'innodb_purge_batch_size',
+          'innodb_purge_rseg_truncate_frequency',
           'innodb_purge_threads',
           'innodb_random_read_ahead',
           'innodb_read_ahead_threshold',
@@ -277,6 +293,7 @@ layout = [ ( 'General',
           'innodb_replication_delay',
           'innodb_rollback_on_timeout',
           'innodb_rollback_segments',
+          'innodb_saved_page_number_debug',
           'innodb_sort_buffer_size',
           'innodb_spin_wait_delay',
           'innodb_stats_auto_recalc',
@@ -292,12 +309,17 @@ layout = [ ( 'General',
           'innodb_support_xa',
           'innodb_sync_array_size',
           'innodb_sync_spin_loops',
+          'innodb_sync_debug',
           'innodb_table_locks',
           'innodb_temp_data_file_path',
+          'innodb_tmpdir',
           'innodb_thread_concurrency',
           'innodb_thread_concurrency_timer_based',
           'innodb_thread_sleep_delay',
+          'innodb_trx_purge_view_update_only_debug',
+          'innodb_trx_rseg_n_slots_debug',
           'innodb_undo_directory',
+          'innodb_undo_log_truncate',
           'innodb_undo_logs',
           'innodb_undo_tablespaces',
           'innodb_use_legacy_cardinality_algorithm',
@@ -362,9 +384,11 @@ layout = [ ( 'General',
           'group_concat_max_len',
           'key_cache_block_size',
           'key_cache_division_limit',
+          'max_execution_time',
           'max_heap_table_size',
           'max_join_size',
           'max_length_for_sort_data',
+          'max_points_in_geometry',
           'max_seeks_for_key',
           'max_sort_length',
           'max_write_lock_count',
@@ -374,6 +398,7 @@ layout = [ ( 'General',
           'query_alloc_block_size',
           'query_prealloc_size',
           'range_alloc_block_size',
+          'range_optimizer_max_mem_size',
           'read_buffer_size',
           'read_rnd_buffer_size',
           'tmp_table_size']),
@@ -385,14 +410,18 @@ layout = [ ( 'General',
       ( 'General',
         [ 'bootstrap',
           'chroot',
+          'daemonize',
           'debug',
           'debug-sync-timeout',
           'div_precision_increment',
+          'early-plugin-load',
           'exit-info',
           'flush',
           'flush_time',
           'init_connect',
           'init_slave',
+          'initialize',
+          'initialize-insecure',
           'max_digest_length',
           'max_error_count',
           'max_prepared_stmt_count',
@@ -419,6 +448,7 @@ layout = [ ( 'General',
           'ndb-blob-read-batch-bytes',
           'ndb-blob-write-batch-bytes',
           'ndb-cluster-connection-pool',
+          'ndb-cluster-connection-pool-nodeids',
           'ndb-connectstring',
           'ndb-log-transaction-id',
           'ndb-log-update-as-write',
@@ -428,6 +458,7 @@ layout = [ ( 'General',
           'ndb-recv-thread-cpu-mask',
           'ndb-wait-connected',
           'ndb-wait-setup',
+          'ndb-allow-copying-alter-table',
           'ndb_autoincrement_prefetch_sz',
           'ndb_cache_check_time',
           'ndb_deferred_constraints',
@@ -464,6 +495,7 @@ layout = [ ( 'General',
         [ 'allow-suspicious-udfs',
           'authentication_windows_log_level',
           'authentication_windows_use_principal_name',
+          'auto_generate_certs',
           'block_encryption_mode',
           'des-key-file',
           'read_only',
@@ -471,6 +503,7 @@ layout = [ ( 'General',
           'safe-show-database',
           'safe-user-create',
           'safemalloc-mem-limit',
+          'schema_definition_cache',
           'secure-auth',
           'secure-backup-file-priv',
           'secure-file-priv',
@@ -479,8 +512,7 @@ layout = [ ( 'General',
       ( 'Authentication',
         [ 'default_authentication_plugin',
           'default_password_lifetime',
-          'disconnect_on_expired_password',
-          'old_passwords'])]),
+          'disconnect_on_expired_password'])]),
   ( 'Replication',
     [ ( 'Relay Log',
         [ 'max_relay_log_size',
@@ -618,6 +650,7 @@ layout = [ ( 'General',
           'performance_schema_hosts_size',
           'performance_schema_max_cond_classes',
           'performance_schema_max_cond_instances',
+          'performance_schema_max_digest_length',
           'performance_schema_max_file_classes',
           'performance_schema_max_file_handles',
           'performance_schema_max_file_instances',
