@@ -1,4 +1,20 @@
-variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
+variable_groups = [ ('mysqlx_port', []),
+  ('mysqlx_max_connections', []),
+  ('mysqlx_initial_incoming_queue_bytes', []),
+  ('mysqlx_max_incoming_queue_bytes', []),
+  ('mysqlx_max_outgoing_queue_bytes', []),
+  ('mysqlx_min_worker_threads', []),
+  ('mysqlx_idle_worker_thread_timeout', []),
+  ('mysqlx_max_allowed_packet', []),
+  ('mysqlx_connect_timeout', []),
+  ('mysqlx_ssl_key', []),
+  ('mysqlx_ssl_ca', []),
+  ('mysqlx_ssl_capath', []),
+  ('mysqlx_ssl_cert', []),
+  ('mysqlx_ssl_cipher', []),
+  ('mysqlx_ssl_crl', []),
+  ('mysqlx_ssl_crlpath', []),
+  ('abort-slave-event-count', ['Replication/Slave']),
   ('allow-suspicious-udfs', ['Security/Security']),
   ('ansi', ['General/SQL']),
   ('audit-log', ['Logging/Audit']),
@@ -14,6 +30,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('audit_log_strategy', ['Logging/Audit']),
   ('authentication_windows_log_level', ['Security/Security']),
   ('authentication_windows_use_principal_name', ['Security/Security']),
+  ('auto_generate_certs', ['Security/Security']),
   ('autocommit', ['General/Transactions']),
   ('avoid_temporal_upgrade', []),
   ('backup_elevation', ['General/Backup']),
@@ -54,13 +71,14 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('connect_timeout', ['Networking/Timeout Settings']),
   ('console', ['Logging/General']),
   ('core-file', ['General/System']),
+  ('create_old_temporals', []),
   ('daemon_memcached_enable_binlog', ['Other/Memcached']),
   ('daemon_memcached_engine_lib_name', ['Other/Memcached']),
   ('daemon_memcached_engine_lib_path', ['Other/Memcached']),
   ('daemon_memcached_option', ['Other/Memcached']),
   ('daemon_memcached_r_batch_size', ['Other/Memcached']),
   ('daemon_memcached_w_batch_size', ['Other/Memcached']),
-  ('daemonize', []),
+  ('daemonize', ['Advanced/General']),
   ('datadir', ['General/Directories']),
   ('debug', ['Advanced/General']),
   ('debug-sync-timeout', ['Advanced/General']),
@@ -79,9 +97,11 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('delayed_queue_size', ['Advanced/Insert delayed settings']),
   ('des-key-file', ['Security/Security']),
   ('disable_gtid_unsafe_statements', ['Replication/General']),
+  ('disabled_storage_engines', []),
   ('disconnect-slave-event-count', ['Replication/Slave']),
   ('disconnect_on_expired_password', ['Security/Authentication']),
   ('div_precision_increment', ['Advanced/General']),
+  ('early-plugin-load', ['Advanced/General']),
   ('enable-locking', ['General/Features']),
   ('enable-named-pipe', ['Networking/General']),
   ('enable-pstack', ['General/Features']),
@@ -113,15 +133,15 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('init-rpl-role', ['Replication/General']),
   ('init_connect', ['Advanced/General']),
   ('init_slave', ['Advanced/General', 'Replication/Slave']),
-  ('initialize', []),
-  ('initialize-insecure', []),
+  ('initialize', ['Advanced/General']),
+  ('initialize-insecure', ['Advanced/General']),
   ('innodb-safe-binlog', ['InnoDB/General']),
   ('innodb-status-file', ['InnoDB/General']),
   ('innodb_adaptive_flushing', ['InnoDB/General']),
   ('innodb_adaptive_flushing_lwm', ['InnoDB/General']),
   ('innodb_adaptive_hash_index', ['InnoDB/General']),
+  ('innodb_adaptive_hash_index_parts', ['InnoDB/General']),
   ('innodb_adaptive_max_sleep_delay', ['InnoDB/General']),
-  ('innodb_additional_mem_pool_size', ['InnoDB/Memory']),
   ('innodb_api_bk_commit_interval', ['InnoDB/General']),
   ('innodb_api_disable_rowlock', ['InnoDB/General']),
   ('innodb_api_enable_binlog', ['InnoDB/General']),
@@ -129,8 +149,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_api_trx_level', ['InnoDB/General']),
   ('innodb_autoextend_increment', ['InnoDB/General']),
   ('innodb_autoinc_lock_mode', ['InnoDB/General']),
+  ('innodb_background_drop_list_empty', ['InnoDB/General']),
   ('innodb_buffer_pool_awe_mem_mb', ['InnoDB/Buffer pool']),
-  ('innodb_buffer_pool_chunk_size', []),
+  ('innodb_buffer_pool_chunk_size', ['InnoDB/Buffer pool']),
   ('innodb_buffer_pool_dump_at_shutdown', ['InnoDB/Buffer pool']),
   ('innodb_buffer_pool_dump_now', ['InnoDB/Buffer pool']),
   ('innodb_buffer_pool_dump_pct', ['InnoDB/General']),
@@ -142,10 +163,12 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_buffer_pool_size', ['InnoDB/Buffer pool', 'InnoDB/Memory']),
   ('innodb_change_buffer_max_size', ['InnoDB/General']),
   ('innodb_change_buffering', ['InnoDB/General']),
+  ('innodb_change_buffering_debug', ['InnoDB/General']),
   ('innodb_checksum_algorithm', ['InnoDB/General']),
   ('innodb_checksums', ['InnoDB/General']),
   ('innodb_cmp_per_index_enabled', ['InnoDB/General']),
   ('innodb_commit_concurrency', ['InnoDB/General']),
+  ('innodb_compress_debug', ['InnoDB/General']),
   ('innodb_compression_failure_threshold_pct', ['InnoDB/General']),
   ('innodb_compression_level', ['InnoDB/General']),
   ('innodb_compression_pad_pct_max', ['InnoDB/General']),
@@ -153,10 +176,13 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_create_intrinsic', ['InnoDB/General']),
   ('innodb_data_file_path', ['InnoDB/Datafiles']),
   ('innodb_data_home_dir', ['InnoDB/Datafiles']),
+  ('innodb_default_row_format', ['InnoDB/General']),
   ('innodb_disable_sort_file_cache', ['InnoDB/General']),
+  ('innodb_disable_resize_buffer_pool_debug', ['InnoDB/General']),
   ('innodb_doublewrite', ['InnoDB/General']),
   ('innodb_extra_dirty_writes', ['InnoDB/General']),
   ('innodb_fast_shutdown', ['InnoDB/Various']),
+  ('innodb_fil_make_page_dirty_debug', []),
   ('innodb_file_format', ['InnoDB/Datafiles']),
   ('innodb_file_format_check', ['InnoDB/Datafiles']),
   ('innodb_file_format_max', ['InnoDB/Datafiles']),
@@ -166,7 +192,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_flush_log_at_trx_commit', ['InnoDB/Logfiles']),
   ('innodb_flush_method', ['InnoDB/Logfiles']),
   ('innodb_flush_neighbors', ['InnoDB/Logfiles']),
-  ('innodb_flush_sync', []),
+  ('innodb_flush_sync', ['InnoDB/Logfiles']),
   ('innodb_flushing_avg_loops', ['InnoDB/General']),
   ('innodb_force_load_corrupted', ['InnoDB/General']),
   ('innodb_force_recovery', ['InnoDB/General']),
@@ -185,12 +211,14 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_io_capacity', ['InnoDB/General']),
   ('innodb_io_capacity_max', ['InnoDB/General']),
   ('innodb_large_prefix', ['InnoDB/General']),
+  ('innodb_limit_optimistic_insert_debug', ['InnoDB/General']),
   ('innodb_lock_wait_timeout', ['InnoDB/General']),
   ('innodb_locks_unsafe_for_binlog', ['InnoDB/General']),
   ('innodb_log_arch_dir', ['InnoDB/Logfiles']),
   ('innodb_log_archive', ['InnoDB/Logfiles']),
   ('innodb_log_buffer_size', ['InnoDB/Logfiles']),
-  ('innodb_log_checksum_algorithm', []),
+  ('innodb_log_checksum_algorithm', ['InnoDB/Logfiles']),
+  ('innodb_log_checksums', ['InnoDB/Logfiles']),
   ('innodb_log_compressed_pages', ['InnoDB/Logfiles']),
   ('innodb_log_file_size', ['InnoDB/Logfiles']),
   ('innodb_log_files_in_group', ['InnoDB/Logfiles']),
@@ -203,23 +231,26 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_max_purge_lag', ['InnoDB/General']),
   ('innodb_max_purge_lag_delay', ['InnoDB/General']),
   ('innodb_max_undo_log_size', ['InnoDB/General']),
+  ('innodb_additional_mem_pool_size', ['InnoDB/Memory']),
+  ('innodb_merge_threshold_set_all_debug', []),
   ('innodb_mirrored_log_groups', ['InnoDB/Logfiles']),
   ('innodb_monitor_disable', ['InnoDB/General']),
   ('innodb_monitor_enable', ['InnoDB/General']),
   ('innodb_monitor_reset', ['InnoDB/General']),
   ('innodb_monitor_reset_all', ['InnoDB/General']),
+  ('innodb_numa_interleave', ['InnoDB/General']),
   ('innodb_old_blocks_pct', ['InnoDB/General']),
   ('innodb_old_blocks_time', ['InnoDB/General']),
   ('innodb_online_alter_log_max_size', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_open_files', ['InnoDB/General']),
   ( 'innodb_optimize_fulltext_only',
     ['InnoDB/Fulltext search', 'InnoDB/General']),
-  ('innodb_optimize_point_storage', []),
+  ('innodb_optimize_point_storage', ['InnoDB/General']),
   ('innodb_page_cleaners', ['InnoDB/Memory']),
   ('innodb_page_size', ['InnoDB/Memory']),
   ('innodb_print_all_deadlocks', ['InnoDB/General']),
   ('innodb_purge_batch_size', ['InnoDB/General']),
-  ('innodb_purge_rseg_truncate_frequency', []),
+  ('innodb_purge_rseg_truncate_frequency', ['InnoDB/General']),
   ('innodb_purge_threads', ['InnoDB/General']),
   ('innodb_random_read_ahead', ['InnoDB/General']),
   ('innodb_read_ahead_threshold', ['InnoDB/General']),
@@ -228,6 +259,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_replication_delay', ['InnoDB/General']),
   ('innodb_rollback_on_timeout', ['InnoDB/General']),
   ('innodb_rollback_segments', ['InnoDB/General']),
+  ('innodb_saved_page_number_debug', ['InnoDB/General']),
   ('innodb_sort_buffer_size', ['InnoDB/General', 'InnoDB/Memory']),
   ('innodb_spin_wait_delay', ['InnoDB/General']),
   ('innodb_stats_auto_recalc', ['InnoDB/General']),
@@ -243,13 +275,17 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('innodb_support_xa', ['InnoDB/General']),
   ('innodb_sync_array_size', ['InnoDB/General']),
   ('innodb_sync_spin_loops', ['InnoDB/General']),
+  ('innodb_sync_debug', ['InnoDB/General']),
   ('innodb_table_locks', ['InnoDB/General']),
   ('innodb_temp_data_file_path', ['InnoDB/General']),
+  ('innodb_tmpdir', ['InnoDB/General']),
   ('innodb_thread_concurrency', ['InnoDB/General']),
   ('innodb_thread_concurrency_timer_based', ['InnoDB/General']),
   ('innodb_thread_sleep_delay', ['InnoDB/General']),
+  ('innodb_trx_purge_view_update_only_debug', ['InnoDB/General']),
+  ('innodb_trx_rseg_n_slots_debug', ['InnoDB/General']),
   ('innodb_undo_directory', ['InnoDB/General', 'InnoDB/Logfiles']),
-  ('innodb_undo_log_truncate', []),
+  ('innodb_undo_log_truncate', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_undo_logs', ['InnoDB/General', 'InnoDB/Logfiles']),
   ('innodb_undo_tablespaces', ['InnoDB/General']),
   ('innodb_use_legacy_cardinality_algorithm', ['InnoDB/General']),
@@ -266,6 +302,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('key_cache_age_threshold', ['MyISAM/General']),
   ('key_cache_block_size', ['Advanced/Various']),
   ('key_cache_division_limit', ['Advanced/Various']),
+  ('keyring_file_data', []),
   ('language', ['General/International']),
   ('large-pages', ['General/Memory usage']),
   ('lc-messages', ['General/International']),
@@ -290,8 +327,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('log-tc', ['Logging/Advanced log options']),
   ('log-tc-size', ['Logging/Advanced log options']),
   ('log-warnings', ['Logging/Advanced log options']),
-  ('log_backward_compatible_user_definitions', []),
+  ('log_backward_compatible_user_definitions', ['Logging/General']),
   ('log_bin_use_v1_row_events', ['Logging/Binlog Options']),
+  ('log_builtin_as_identified_by_password', ['Logging/General']),
   ('log_error_verbosity', ['Logging/General']),
   ('log_slave_updates', ['Logging/General']),
   ('log_syslog', ['Logging/General']),
@@ -327,16 +365,17 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('max_delayed_threads', ['Advanced/Insert delayed settings']),
   ('max_digest_length', ['Advanced/General']),
   ('max_error_count', ['Advanced/General']),
+  ('max_execution_time', ['Advanced/Various']),
   ('max_heap_table_size', ['Advanced/Various']),
   ('max_join_size', ['Advanced/Various']),
   ('max_length_for_sort_data', ['Advanced/Various']),
   ('max_long_data_size', ['General/General']),
+  ('max_points_in_geometry', ['Advanced/Various']),
   ('max_prepared_stmt_count', ['Advanced/General']),
   ('max_relay_log_size', ['Replication/Relay Log']),
   ('max_seeks_for_key', ['Advanced/Various']),
   ('max_sort_length', ['Advanced/Various']),
   ('max_sp_recursion_depth', ['Advanced/General']),
-  ('max_statement_time', ['General/General']),
   ('max_user_connections', ['Networking/Advanced']),
   ('max_write_lock_count', ['Advanced/Various']),
   ('mecab_rc_file', []),
@@ -364,6 +403,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ndb-blob-read-batch-bytes', ['Other/NDB']),
   ('ndb-blob-write-batch-bytes', ['Other/NDB']),
   ('ndb-cluster-connection-pool', ['Other/NDB']),
+  ('ndb-cluster-connection-pool-nodeids', ['Other/NDB']),
   ('ndb-connectstring', ['Other/NDB']),
   ('ndb-log-transaction-id', ['Other/NDB']),
   ('ndb-log-update-as-write', ['Other/NDB']),
@@ -373,6 +413,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ndb-recv-thread-cpu-mask', ['Other/NDB']),
   ('ndb-wait-connected', ['Other/NDB']),
   ('ndb-wait-setup', ['Other/NDB']),
+  ('ndb-allow-copying-alter-table', ['Other/NDB']),
   ('ndb_autoincrement_prefetch_sz', ['Other/NDB']),
   ('ndb_cache_check_time', ['Other/NDB']),
   ('ndb_deferred_constraints', ['Other/NDB']),
@@ -408,13 +449,13 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('old-alter-table', ['Advanced/Deprecated']),
   ('old-protocol', ['Advanced/Deprecated']),
   ('old-style-user-limits', ['Advanced/General']),
-  ('old_passwords', ['Security/Authentication']),
   ('one-thread', ['General/General']),
   ('open-files-limit', ['Advanced/General']),
   ('optimizer_join_cache_level', ['Performance/Optimizer']),
   ('optimizer_prune_level', ['Performance/Optimizer']),
   ('optimizer_search_depth', ['Performance/Optimizer']),
   ('optimizer_switch', ['Performance/Optimizer']),
+  ('parser_max_mem_size', []),
   ('partition', []),
   ( 'performance-schema-consumer-events-stages-current',
     ['Performance/Performance Schema']),
@@ -470,6 +511,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('performance_schema_max_cond_classes', ['Performance/Performance Schema']),
   ( 'performance_schema_max_cond_instances',
     ['Performance/Performance Schema']),
+  ('performance_schema_max_digest_length', ['Performance/Performance Schema']),
   ('performance_schema_max_file_classes', ['Performance/Performance Schema']),
   ('performance_schema_max_file_handles', ['Performance/Performance Schema']),
   ( 'performance_schema_max_file_instances',
@@ -533,6 +575,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('query_cache_wlock_invalidate', ['Performance/Query cache']),
   ('query_prealloc_size', ['Advanced/Various']),
   ('range_alloc_block_size', ['Advanced/Various']),
+  ('range_optimizer_max_mem_size', ['Advanced/Various']),
   ('read_buffer_size', ['Advanced/Various']),
   ('read_only', ['Security/Security']),
   ('read_rnd_buffer_size', ['Advanced/Various']),
@@ -555,6 +598,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('report-password', ['Replication/General']),
   ('report-port', ['Replication/General']),
   ('report-user', ['Replication/General']),
+  ('require_secure_transport', []),
   ('restore_disables_events', ['Advanced/General']),
   ('restore_elevation', ['Advanced/General']),
   ('restore_precheck', ['Advanced/General']),
@@ -563,6 +607,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('safe-show-database', ['Security/Security']),
   ('safe-user-create', ['Security/Security']),
   ('safemalloc-mem-limit', ['Security/Security']),
+  ('schema_definition_cache', ['Security/Security']),
   ('secure-auth', ['Security/Security']),
   ('secure-backup-file-priv', ['Security/Security']),
   ('secure-file-priv', ['Security/Security']),
@@ -573,8 +618,10 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('session_track_state_change', ['General/General']),
   ('session_track_system_variables', ['General/General']),
   ('set-variable', ['Advanced/Deprecated']),
+  ('sha256_password_auto_generate_rsa_keys', []),
   ('sha256_password_proxy_users', []),
   ('shared_memory', []),
+  ('shared_memory_base_name', []),
   ('show-slave-auth-info', ['Replication/Slave']),
   ('show_compatibility_56', []),
   ('show_old_temporals', []),
@@ -632,7 +679,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('ssl-key', ['Networking/SSL']),
   ('standalone', ['Advanced/General']),
   ('stored_program_cache', ['General/General']),
+  ('stored_program_definition_cache', []),
   ('super-large-pages', ['General/General']),
+  ('super_read_only', []),
   ('symbolic-links', ['General/System']),
   ('sync_binlog', ['Logging/Binlog Options']),
   ('sync_frm', ['Advanced/General']),
@@ -640,6 +689,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('sync_relay_log', ['Replication/Relay Log']),
   ('sync_relay_log_info', ['Replication/Relay Log']),
   ('sysdate-is-now', ['General/System']),
+  ('tablespace_definition_cache', []),
   ('table_cache', []),
   ('table_lock_wait_timeout', []),
   ('tc-heuristic-recover', []),
@@ -656,6 +706,7 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('thread_pool_stall_limit', ['Advanced/Thread specific settings']),
   ('thread_stack', ['Advanced/Thread specific settings']),
   ('timed_mutexes', ['InnoDB/General']),
+  ('tls_version', []),
   ('tmp_table_size', ['Advanced/Various']),
   ('tmpdir', ['General/Directories']),
   ('transaction-isolation', ['Advanced/Transactions']),
@@ -666,13 +717,9 @@ variable_groups = [ ('abort-slave-event-count', ['Replication/Slave']),
   ('use-symbolic-links', ['General/System']),
   ('user', ['General/System']),
   ('validate-password', []),
-  ('validate_password_dictionary_file', []),
-  ('validate_password_length', []),
-  ('validate_password_mixed_case_count', []),
-  ('validate_password_number_count', []),
-  ('validate_password_policy', []),
-  ('validate_password_special_char_count', []),
   ('verbose', []),
+  ('version_tokens_session', []),
+  ('version_tokens_session_number', []),
   ('wait_timeout', ['Networking/Timeout Settings']),
   ('warnings', ['Advanced/Deprecated']),
   ('skip-innodb', ['InnoDB/General'])]
