@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2016, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -25,9 +25,9 @@ import traceback
 
 from workbench.utils import Version
 from wb_admin_ssh import SSHDownException
-from workbench.db_utils import MySQLConnection, MySQLError, QueryError, strip_password
+from workbench.db_utils import MySQLConnection, MySQLError, QueryError, strip_password, escape_sql_string
 
-from wb_common import OperationCancelledError, Users, PermissionDeniedError, InvalidPasswordError
+from wb_common import OperationCancelledError, Users, PermissionDeniedError, InvalidPasswordError, SSHFingerprintNewError
 
 from wb_server_control import PasswordHandler, ServerControlShell, ServerControlWMI
 from wb_server_management import ServerManagementHelper, SSH, wbaOS
@@ -41,6 +41,7 @@ from workbench.log import log_info, log_warning, log_error, log_debug
 
 MYSQL_ERR_ACCESS_DENIED = 1045
 MYSQL_ERR_PASSWORD_EXPIRED = 1820
+MYSQL_ERR_OFFLINE_MODE = 3032
 
 #===============================================================================
 #
@@ -48,7 +49,7 @@ MYSQL_ERR_PASSWORD_EXPIRED = 1820
 # Handling object should have corresponding method if the object wants to receive
 # events. For event shutdown method name must be shutdown_event
 class EventManager(object):
-    valid_events = ['server_started_event', 'server_stopped_event', 'shutdown_event']
+    valid_events = ['server_offline_event', 'server_started_event', 'server_stopped_event', 'shutdown_event']
 
     def __init__(self):
         self.events = {}
@@ -69,7 +70,6 @@ class EventManager(object):
             handlers_list.append(handler)
             log_debug("Added " + handler.__class__.__name__ + " for event " + event_name + '\n')
         else:
-            print "Error! ", handler.__class__, " does not have method", event_name
             log_error(handler.__class__.__name__ + " does not have method " + event_name + '\n')
 
     def defer_events(self):
@@ -85,10 +85,8 @@ class EventManager(object):
         if self.defer:
             self.deferred_events.append(name)
             return
-
         name += "_event"
         if name not in self.valid_events:
-            print "EventManager: invalid event", name
             log_error('EventManager: invalid event: ' + name + '\n')
         elif name in self.events:
             log_debug("Found event " + name + " in list" + '\n')
@@ -134,6 +132,17 @@ class SQLQueryExecutor(object):
             self.mtx.release()
         return result
 
+    def exec_query_multi_result(self, query):
+        result = None
+        self.mtx.acquire()
+        try:
+            if self.is_connected():
+                log_debug("Executing query multi result %s\n" % strip_password(query))
+                result = self.dbconn.executeQueryMultiResult(query)
+        finally:
+            self.mtx.release()
+        return result
+
     def execute(self, query):
         result = None
         self.mtx.acquire()
@@ -145,6 +154,8 @@ class SQLQueryExecutor(object):
             self.mtx.release()
         return result
 
+    def updateCount(self):
+        return self.dbconn.updateCount()
 
 #===============================================================================
 
@@ -160,8 +171,8 @@ class WbAdminControl(object):
     target_version = None
     raw_version = "unknown"
     
-    def __init__(self, server_profile, editor, connect_sql=True):
-
+    def __init__(self, server_profile, editor, connect_sql=True, test_only = False):
+        self.test_only = test_only
         self.server_control = None
         self.events   = EventManager()
         self.defer_events() # continue events should be called when all listeners are registered, that happens later in the caller code
@@ -181,10 +192,16 @@ class WbAdminControl(object):
 
         self.add_me_for_event("server_started", self)
         self.add_me_for_event("server_stopped", self)
+        self.add_me_for_event("server_offline", self)
 
         self.editor = editor
         if editor:
-            self.last_known_server_running_status = ("running" if editor.isConnected else "stopped", None) # (status, timestamp)
+            if editor.isConnected == 1:
+                self.last_known_server_running_status = ("running", None) # (status, timestamp)
+            elif editor.isConnected == -1:
+                self.last_known_server_running_status = ("offline", None) # (status, timestamp)
+            else:
+                self.last_known_server_running_status = ("stopped", None) # (status, timestamp)
         else:
             self.last_known_server_running_status = ("unknown", None)
 
@@ -205,13 +222,43 @@ class WbAdminControl(object):
     def admin_access_available(self):
         return self.server_control is not None
 
+    def _confirm_server_fingerprint(self, host, port, fingerprint_exception):
+        msg = { 'msg': "The authenticity of host '%(0)s (%(0)s)' can't be established.\n%(1)s key fingerprint is %(2)s\nAre you sure you want to continue connecting?"  % {'0': "%s:%s" % (host, port), '1': fingerprint_exception.key.get_name(), '2': fingerprint_exception.fingerprint}, 'obj': fingerprint_exception}
+        if mforms.Utilities.show_message("SSH Server Fingerprint Missing", msg['msg'], "Continue", "Cancel", "") == mforms.ResultOk:
+            msg['obj'].client._host_keys.add(msg['obj'].hostname, msg['obj'].key.get_name(), msg['obj'].key)
+            if msg['obj'].client._host_keys_filename is not None:
+                try:
+                    if os.path.isdir(os.path.dirname(msg['obj'].client._host_keys_filename)) == False:
+                        log_warning("Host_keys directory is missing, recreating it\n")
+                        os.makedirs(os.path.dirname(msg['obj'].client._host_keys_filename))
+                    if os.path.exists(msg['obj'].client._host_keys_filename) == False:
+                        log_warning("Host_keys file is missing, recreating it\n")
+                        open(msg['obj'].client._host_keys_filename, 'a').close()
+                    msg['obj'].client.save_host_keys(msg['obj'].client._host_keys_filename)
+                    log_warning("Successfully saved host_keys file.\n")
+                    return True
+                except IOError, e:
+                    error = str(e)
+                    raise e
+        else:
+            return False
+
     def acquire_admin_access(self):
         """Make sure we have access to the instance for admin (for config file, start/stop etc)"""
         if self.server_control or not self.server_profile.admin_enabled:
             return
         if self.server_profile.uses_ssh:
             try:
-                self.ssh = SSH(self.server_profile, self.password_handler)
+                while True:
+                    try:
+                        self.ssh = SSH(self.server_profile, self.password_handler)
+                        break
+                    except SSHFingerprintNewError, exc:
+                        if self._confirm_server_fingerprint(self.server_profile.ssh_hostname, self.server_profile.ssh_port, exc):
+                            continue;
+                        else:
+                            raise OperationCancelledError("user cancel")
+                    
             except OperationCancelledError:
                 self.ssh = None
                 raise OperationCancelledError("SSH connection cancelled")
@@ -285,7 +332,7 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                     if not self.server_profile.admin_enabled:  # We have neither sql connection nor management method
                         raise Exception('Could not connect to MySQL Server and no management method is available')
 
-        if not self.worker_thread:
+        if not self.worker_thread and not self.test_only:
             # start status variable check thread
             self.worker_thread = threading.Thread(target=self.server_polling_thread)
             self.worker_thread.start()
@@ -303,16 +350,23 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
     def force_check_server_state(self, verbose = False):
         # Check the current state of the server and cause the SQL Editor to reconnect/update if the state
         # changed. Returns None if no state change was detected or the new state if it did change.
-        
+        old_state = self.last_known_server_running_status[0]
         new_state = self.is_server_running(verbose=verbose, force_hard_check=True)
         log_debug("Force check server state returned %s\n" % new_state)
-        if new_state != self.last_known_server_running_status[0]:
-            info = { "state" : 1 if new_state == "running" else 0, "connection" : self.server_profile.db_connection_params }
+        if new_state != old_state:
+            info = { "state" : -1, "connection" : self.server_profile.db_connection_params }
+            if new_state == "running":
+                info['state'] = 1 
+            elif new_state == "offline":
+                info['state'] = -1;
+            else:
+                info['state'] = 0;
+            
             # this will notify the rest of the App that the server state has changed, giving them a chance
             # to reconnect or formally disconnect
             nc.send("GRNServerStateChanged", self.editor, info)
             
-            if new_state == "stopped":
+            if new_state == "stopped" or new_state == "offline":
                 self.server_variables = {}
                 self.status_variables_time = None
                 self.status_variables = {}
@@ -326,7 +380,6 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         # Check recent information from query runs. If last query (not older than 4 secs)
         # was performed successfully, then we imply that server is up.
         ret = "unknown"
-
         status, stime = self.last_known_server_running_status
         if not force_hard_check:
             ret = status
@@ -336,7 +389,9 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                 # do a ping on the connection to make sure it's still up
                 if self.sql_ping():
                     self.log_cb("MySQL server is currently running")
-                    ret = "running"
+                    self.query_server_info() #query_server_info do update server status
+                    status, stime = self.last_known_server_running_status
+                    ret = status
             if ret != "running":
                 self.log_cb("Trying to connect to MySQL...")
 
@@ -350,10 +405,15 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                     self.log_cb("Connection succeeded")
                 else:
                     self.log_cb("%s (%i)" % (err, code))
+
                 if code in (2002, 2003, 2013):
                     ret = "stopped"
                     self.log_cb("Assuming server is not running")
+                elif code == MYSQL_ERR_OFFLINE_MODE:
+                    ret = "offline"
+                    self.log_cb("Server is in offline mode")
                 else:
+                    self.query_server_info()
                     ret = "running"
                     self.log_cb("Assuming server is running")
 
@@ -431,6 +491,10 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
     def server_stopped_event(self):
         self.disconnect_sql()
         self.last_known_server_running_status = ("stopped", time.time())
+        
+    #---------------------------------------------------------------------------
+    def server_offline_event(self):
+        self.last_known_server_running_status = ("offline", time.time())
 
     #---------------------------------------------------------------------------
     """
@@ -440,14 +504,24 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
     """
     def sql_status_callback(self, code, error, connect_info):
         if code == 0:
-            self.last_known_server_running_status = ("running", time.time())
+            if "offline_mode" in self.server_variables and self.server_variables["offline_mode"] == "ON":
+                self.last_known_server_running_status = ("offline", time.time()) 
+            else:
+                self.last_known_server_running_status = ("running", time.time())
 
 
     #---------------------------------------------------------------------------
     def connect_sql(self): # from GUI thread only, throws MySQLError
         if not self.is_sql_connected():
-            connection = MySQLConnection(self.server_profile.db_connection_params, self.sql_status_callback)
-            connection.connect()
+            password = self.get_mysql_password()
+
+            connection = MySQLConnection(self.server_profile.db_connection_params, self.sql_status_callback,
+                                        password=password)
+            try:
+                connection.connect()
+            except grt.UserInterrupt:
+                log_info("Cancelled connection\n")
+                return
 
             self.sql = SQLQueryExecutor(connection)
 
@@ -478,7 +552,8 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
     #---------------------------------------------------------------------------
     def server_polling_thread(self):
         try:
-            self.poll_connection = MySQLConnection(self.server_profile.db_connection_params)
+            password = self.get_mysql_password()
+            self.poll_connection = MySQLConnection(self.server_profile.db_connection_params, password=password)
             self.poll_connection.connect()
         except MySQLError, err:
             log_error("Error creating SQL connection for monitoring: %r\n" % err)
@@ -552,11 +627,29 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
 
         return ret
 
-    def exec_sql(self, q, auto_reconnect=True):
+    def exec_query_multi_result(self, q, auto_reconnect=True):
         ret = None
+        if self.sql is not None:
+            try:
+                ret = self.sql.exec_query_multi_result(q)
+            except QueryError, e:
+                log_warning("Error executing query multi result %s: %s\n"%(q, strip_password(str(e))))
+                if auto_reconnect and e.is_connection_error():
+                    log_warning("exec_query_multi_result: Loss of connection to mysql server was detected.\n")
+                    self.handle_sql_disconnection(e)
+                else: # if exception is not handled, give a chance to the caller do it
+                    raise e
+        else:
+            log_info("sql connection is down\n")
+
+        return ret
+
+    def exec_sql(self, q, auto_reconnect=True):
         if self.sql is not None:
             try:
                 ret = self.sql.execute(q)
+                cnt = self.sql.updateCount()
+                return ret, cnt
             except QueryError, e:
                 log_warning("Error executing SQL %s: %s\n"%(strip_password(q), strip_password(str(e))))
                 if auto_reconnect and e.is_connection_error():
@@ -567,7 +660,7 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         else:
             log_info("sql connection is down\n")
 
-        return ret
+        return None, -1
 
     def handle_sql_disconnection(self, e):
         self.disconnect_sql()
@@ -609,7 +702,7 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         result = self.exec_query("SHOW GLOBAL STATUS")
         while result and result.nextRow():
             self.status_variables[result.stringByName("Variable_name")] = result.stringByName("Value")
-
+            
         # check version
         if self.server_variables:
             self.raw_version = self.server_variables["version"]
@@ -633,6 +726,11 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                 plugin_type = result.stringByName("Type")
                 if status == "ACTIVE":
                     self.server_active_plugins.add((name, plugin_type))
+        if "offline_mode" in self.server_variables and self.server_variables["offline_mode"] == "ON":
+            #We're in offline mode, need to change server status
+            self.last_known_server_running_status = ("offline", time.time())
+        else:
+            self.last_known_server_running_status = ("running", time.time())
 
 
     def query_server_installation_info(self):
@@ -856,5 +954,3 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                 else:
                     log_error("Could not execute uname command on remote server, system type is unknown\n")
         return None
-
-
