@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,16 +17,16 @@
  * 02110-1301  USA
  */
 
-#ifndef _STDAFX_H_
-#define _STDAFX_H_
+#pragma once
 
-#ifdef _WIN32
 #define NOMINMAX
 #define WIN32_LEAN_AND_MEAN 
 #include <windows.h>
-#endif // _WIN32
 
-#include "base/string_utilities.h"
-#include "base/geometry.h"
+#include <glib.h>
 
-#endif // _STDAFX_H_
+#include "grts/structs.db.mgmt.h"
+#include "grts/structs.db.mysql.h"
+#include "grts/structs.db.query.h"
+#include "grts/structs.model.h"
+#include "grts/structs.workbench.physical.h"
