@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,9 +17,6 @@
  * 02110-1301  USA
  */
 
-#include "stdafx.h"
-
-
 #include "grtpp.h"
 #include "interfaces/plugin.h"
 
@@ -63,6 +60,8 @@ public:
     args.ginsert(grt::StringRef(path));
 
     workbench_DocumentRef doc(workbench_DocumentRef::cast_from(module->call_function("openModelFile", args)));
+    if (!doc.is_valid())
+      return grt::IntegerRef(0);
 
     //Merge catalog
     db_CatalogRef source_catalog = doc->physicalModels()[0]->catalog();
