@@ -1,4 +1,4 @@
-# Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2015, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -40,6 +40,8 @@ import sqlide_catalogman_ext
 import sqlide_tableman_ext
 import sqlide_schematree_ext
 import sqlide_import_spatial
+import sqlide_power_import_wizard
+import sqlide_power_export_wizard
 
 # define this Python module as a GRT module
 ModuleInfo = DefineModule(name= "SQLIDEUtils", author= "Oracle Corp.", version="1.1")
@@ -57,6 +59,8 @@ def initialize0():
     nc.add_observer(sqlide_catalogman_ext.handleLiveTreeContextMenu, name = "GRNLiveDBObjectMenuWillShow")
     nc.add_observer(sqlide_tableman_ext.handleLiveTreeContextMenu, name = "GRNLiveDBObjectMenuWillShow")
     nc.add_observer(sqlide_import_spatial.handleContextMenu, name = "GRNLiveDBObjectMenuWillShow")
+    nc.add_observer(sqlide_power_import_wizard.handleContextMenu, name = "GRNLiveDBObjectMenuWillShow")
+    nc.add_observer(sqlide_power_export_wizard.handleContextMenu, name = "GRNLiveDBObjectMenuWillShow")
 
 
 
@@ -208,7 +212,7 @@ def verticalOutput(editor):
         dock = mforms.fromgrt(editor.resultDockingPoint)
         dock.dock_view(view, '', 0)
         dock.select_view(view)
-        dock.set_view_title(view, 'Vertical Output')
+        view.set_title('Vertical Output')
 
 
     return 0
@@ -615,6 +619,11 @@ def showInspector(editor, selection):
 @ModuleInfo.export(grt.INT, grt.classes.db_query_Editor)
 def runSQLScript(editor):
     form = RunScriptForm(editor)
-    form.run()
-    return 0
+    return form.run()
+
+
+@ModuleInfo.export(grt.INT, grt.classes.db_query_Editor, grt.STRING)
+def runSQLScriptFile(editor, path):
+    form = RunScriptForm(editor)
+    return form.run_file(path)
 
