@@ -1,4 +1,4 @@
-# Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -18,7 +18,7 @@
 
 import mforms
 import grt
-
+import sys
 from workbench.log import log_error
 
 from sqlide_catalogman_ext import MaintenanceResultForm
@@ -190,6 +190,9 @@ class TableInfoPanel(mforms.Box):
         self.table_comment = mforms.newLabel("")
         self.table_comment.set_style(mforms.BoldStyle)
         self.table_comment.set_wrap_text(True)
+        if sys.platform.lower() == "win32": # We need this so Win will recompute the dimensions.
+            self.table_comment.set_size(1, -1)
+
         self.table.add(self.table_comment,                      1, 2, 18 + offset, 19 + offset, mforms.HFillFlag|mforms.HExpandFlag)
         
         scroll = mforms.ScrollPanel()
@@ -229,7 +232,7 @@ class TableInfoPanel(mforms.Box):
         return self._table_engine
 
     def analyze_table(self):
-        result = self.editor.executeManagementQuery("ANALYZE TABLE %s.%s" % (self._schema, self._table), 1)
+        result = self.editor.executeManagementQuery("ANALYZE TABLE `%s`.`%s`" % (self._schema, self._table), 1)
         form = MaintenanceResultForm(result, False)
         form.set_title("ANALYZE TABLE")
         form.run()
@@ -527,7 +530,7 @@ class TableIndexInfoPanel(mforms.Box):
         self.index_list.add_column(mforms.StringColumnType, "Columns", 200, False)
         self.index_list.end_columns()
         self.index_list.add_changed_callback(self.index_selected)
-        self.index_list.set_size(500, -1)
+        self.index_list.set_size(450, -1)
         table.add(self.index_list, 0, 1, 1, 2, mforms.HFillFlag|mforms.VFillFlag)
 
         dhbox = mforms.newBox(True)
@@ -852,9 +855,9 @@ class PartitionManager(TableManDefs, ObjectManager):
                ("data_length", IntegerColumnType, "Data length", 100, None),
                ("max_data_length", IntegerColumnType, "max data length", 100, None),
                ("index_length", IntegerColumnType, "Index length", 100, None),
-               ("create_time", StringColumnType, "Create time", 100, None),
-               ("update_time", StringColumnType, "Update time", 100, None),
-               ("check_time", StringColumnType, "Check time", 100, None)]
+               ("create_time", StringColumnType, "Create time", 150, None),
+               ("update_time", StringColumnType, "Update time", 150, None),
+               ("check_time", StringColumnType, "Check time", 150, None)]
     def __init__(self, editor):
         ObjectManager.__init__(self, editor, None)
         self.set_managed()
